@@ -1,12 +1,12 @@
 <?php
-/* $Id: catalan-iso-8859-1.inc.php,v 2.62 2005/01/09 20:27:06 lem9 Exp $ */
+/* $Id: catalan-iso-8859-1.inc.php,v 2.82.2.1 2005/06/30 19:06:30 lem9 Exp $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
 $left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
 $right_font_family = 'arial, helvetica, geneva, sans-serif';
-$number_thousands_separator = ',';
-$number_decimal_separator = '.';
+$number_thousands_separator = '.';
+$number_decimal_separator = ',';
 // abreviatures de Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 $timespanfmt = '%s dies, %s hores, %s minuts i %s segons';
@@ -45,7 +45,7 @@ $strAdministration = 'Administraci';
 $strAffectedRows = 'Files afectades:';
 $strAfter = 'Desprs %s';
 $strAfterInsertBack = 'Tornar';
-$strAfterInsertNewInsert = 'Inserta un nou registre';
+$strAfterInsertNewInsert = 'Insereix un nou registre';
 $strAfterInsertNext = 'Editar el segent registre'; 
 $strAfterInsertSame = 'Tornar a aquesta plana';
 $strAll = 'Tot';
@@ -80,17 +80,20 @@ $strBinLogServerId = 'ID de Servidor';
 $strBinary = ' Binari ';
 $strBinaryDoNotEdit = ' Binari - no editeu ';
 $strBinaryLog = 'Registre binari';
-$strBookmarkAllUsers = 'Deixa accedir a cada usuari a aquesta consulta arxivada';
-$strBookmarkDeleted = 'S\'ha esborrat la consulta arxivada.';
+$strBookmarkAllUsers = 'Deixar accedir a cada usuari a aquesta consulta desada';
+$strBookmarkDeleted = 'S\'ha esborrat la consulta desada.';
 $strBookmarkLabel = 'Etiqueta';
-$strBookmarkOptions = 'Opcions de consulta arxivada';
-$strBookmarkQuery = 'Consulta SQL arxivada';
-$strBookmarkThis = 'Arxiva aquesta consulta SQL';
+$strBookmarkOptions = 'Opcions de consulta desada';
+$strBookmarkQuery = 'Consulta SQL desada';
+$strBookmarkThis = 'Desa aquesta consulta SQL';
 $strBookmarkView = 'Noms mirar';
 $strBrowse = 'Navega';
 $strBrowseForeignValues = 'Navega valors externs';
+$strBufferPool = 'Grup de memries intermitges';
+$strBufferPoolUsage = 's del grup de memries intermitges';
 $strBulgarian = 'Blgar';
-$strBzError = 'phpMyAdmin s incapa de comprimir el volcat degut a una extensi Bz2 incorrecta en aquesta versi de php. s molt recomenable posar a la directiva <code>$cfg[\'BZipDump\']</code> el valor <code>FALSE</code> al fitxer de configuraci de phpMyAdmin. Si vol utilitzar les facilitats de compresi Bz2, s necessari actualitzar el php a la darrera versi disponible. Es pot consultar el informe d\'errada %s de php per a ms detalls.';
+$strBusyPages = 'Planes ocupades';
+$strBzError = 'phpMyAdmin s incapa de comprimir el volcat degut a una extensi Bz2 incorrecta en aquesta versi de php. s molt recomenable posar a la directiva <code>$cfg[\'BZipDump\']</code> el valor <code>FALSE</code> al fitxer de configuraci de phpMyAdmin. Si vols utilitzar les facilitats de compresi Bz2, s necessari actualitzar el php a la darrera versi disponible. Es pot consultar el informe d\'errada %s de php per a ms detalls.';
 $strBzip = '"comprimit amb bzip"';
 
 $strCSVOptions = 'Opcions CSV';
@@ -119,7 +122,7 @@ $strCharsetOfFile = 'Joc de carcters de l\'arxiu:';
 $strCharsets = 'Jocs de caracters';
 $strCharsetsAndCollations = 'Jocs de Caracters i ordenacions';
 $strCheckAll = 'Verificar-ho tot';
-$strCheckOverhead = 'Comprova desfragmentades';
+$strCheckOverhead = 'Comprovar taules desfragmentades';
 $strCheckPrivs = 'Comprova els Permissos';
 $strCheckPrivsLong = 'Comprova els Permissos per la Base de dades &quot;%s&quot;.';
 $strCheckTable = 'Verifica la taula';
@@ -141,12 +144,14 @@ $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Restriccions per taules volcades';
 $strConstraintsForTable = 'Restriccions per la taula';
 $strCookiesRequired = 'A partir d\'aquest punt s necessari tenir les galetes (cookies) activades.';
+$strCopy = 'Copiar'; 
 $strCopyDatabaseOK = 'La Base de dades %s s\'ha copiat a %s';
 $strCopyTable = 'Copia taula a (base-de-dades<b>.</b>taula):';
-$strCopyTableOK = 'La taula %s ha estat copiada a %s.';
+$strCopyTableOK = 'La taula %s s\'ha copiat a %s.';
 $strCopyTableSameNames = 'No es pot copiar la taula sobre ella mateixa';
 $strCouldNotKill = 'phpMyAdmin no pot cancel.lar el fil %s. Probablement, ja s tancat.';
 $strCreate = 'Crear';
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE abans de copiar';
 $strCreateIndex = 'Crea un ndex a la columna:&nbsp;%s';
 $strCreateIndexTopic = 'Crea un nou ndex';
 $strCreateNewDatabase = 'Crea una nova base de dades';
@@ -176,6 +181,7 @@ $strDanish = 'Dans';
 $strData = 'Dades';
 $strDataDict = 'Diccionari de Dades';
 $strDataOnly = 'Noms dades';
+$strDataPages = 'Planes contenint dades';
 $strDatabase = 'Base de dades';
 $strDatabaseEmpty = 'El nom de la base de dades s buit!';
 $strDatabaseExportOptions = 'Opcions d\'exportaci de Bases de Dades';
@@ -190,6 +196,7 @@ $strDatabasesStatsHeavyTraffic = 'Nota: Activant les estadstiques de Base de Dad
 $strDbPrivileges = 'Permissos especifics de Base de dades';
 $strDbSpecific = 'especfic de la base de dades';
 $strDefault = 'Defecte';
+$strDefaultEngine = '%s s el motor d\'emmagatzematge per defecte en aquest servidor MySQL.';
 $strDefaultValueHelp = 'Per a valors per defecte, noms entra un valor, sense barres invertides ni cometes, fent servir aquest format: a';
 $strDefragment = 'Desfragmentar taula';
 $strDelOld = 'La plana actual t referncies a taules que no existeixen. Vols esborrar aquestes referncies?';
@@ -203,6 +210,7 @@ $strDeleting = 'Esborrant %s';
 $strDescending = 'Descendent';
 $strDescription = 'Descripci';
 $strDictionary = 'diccionari';
+$strDirtyPages = 'Planes brutes';
 $strDisableForeignChecks = 'Desactivar comprovacions de claus externes';
 $strDisabled = 'Desactivat';
 $strDisplayFeat = 'Mostrar caracterstiques';
@@ -231,14 +239,18 @@ $strEncloseInTransaction = 'Incloure exportaci en la transacci';
 $strEnd = 'Final';
 $strEndCut = 'FI DEL TALL';
 $strEndRaw = 'FI DEL VOLCAT';
+$strEngineAvailable = '%s est disponible en aquest servidor MySQL.';
+$strEngineDisabled = '%s s\'ha desactivat en aquest servidor MySQL.';
+$strEngineUnsupported = 'Aquest servidor MySQL no soporta el motor d\'emmagatzematge %s.';
+$strEngines = 'Motors';
 $strEnglish = 'Angls';
 $strEnglishPrivileges = ' Nota: Els noms dels privilegis del MySQL sn en llengua anglesa ';
 $strError = 'Errada';
-$strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-las literalment';
+$strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-los literalment';
 $strEstonian = 'Estoni ';
 $strExcelEdition = 'Edici per Excel';
 $strExcelOptions = 'Opcions d\'Excel';
-$strExecuteBookmarked = 'Executa una consulta arxivada';
+$strExecuteBookmarked = 'Executa una consulta desada';
 $strExplain = 'Explicaci de l\'SQL';
 $strExport = 'Exportar';
 $strExtendedInserts = 'Insercions ampliades';
@@ -252,7 +264,7 @@ $strFieldsEmpty = ' El comptador de camps s buit! ';
 $strFieldsEnclosedBy = 'Camps englobats per';
 $strFieldsEscapedBy = 'Camps amb marca d\'escapada';
 $strFieldsTerminatedBy = 'Camps acabats per';
-$strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca la opci de sobreescriure.';
+$strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca l\'opci de sobreescriure.';
 $strFileCouldNotBeRead = 'No es pot llegir el fitxer';
 $strFileNameTemplate = 'Nom de fitxer de plantilla';
 $strFileNameTemplateHelp = 'Utilitza __DB__ per a nom de base de dades, __TABLE__ per a nom de taula i opcions %sany strftime%s per especificacions horaries, la extensi s\'afegir automgicament. Qualsevol altre text es mantindr.';
@@ -262,12 +274,15 @@ $strFlushPrivilegesNote = 'Nota: phpMyAdmin obt els permissos de l\'usuari direc
 $strFlushTable = 'Buidar la memria cau de la taula ("FLUSH")';
 $strFormEmpty = 'Falta un valor al formulari !';
 $strFormat = 'Format';
+$strFreePages = 'Planes lliures';
 $strFullText = 'Textos sencers';
 $strFunction = 'Funci';
 
 $strGenBy = 'Generat per';
 $strGenTime = 'Temps de generaci';
 $strGeneralRelationFeat = 'Caracterstiques generals de relacions';
+$strGenerate = 'Generar'; 
+$strGeneratePassword = 'Generar Contrasenya'; 
 $strGeorgian = 'Georgi';
 $strGerman = 'Alemany';
 $strGlobal = 'global';
@@ -309,6 +324,11 @@ $strIndexWarningPrimary = 'Les claus PRIMARY i INDEX no es poden establir alhora
 $strIndexWarningTable = 'Problemes amb els index de la taula `%s`';
 $strIndexWarningUnique = 'Les claus UNIQUE i INDEX no es poden establir alhora per a la columna `%s`';
 $strIndexes = 'Indexos';
+$strInnoDBAutoextendIncrement = 'Increment d\'autoextensi';
+$strInnoDBAutoextendIncrementDesc = ' La quantitat a incrementar per ampliar el tamany d\'una taula autoextensible quan estigui a punt d\'omplir-se.';
+$strInnoDBDataFilePath = 'Arxius de dades';
+$strInnoDBDataHomeDir = 'Directori local de dades';
+$strInnoDBDataHomeDirDesc = 'La part comuna de la ruta al directori per tots els arxius de dades InnoDB.';
 $strInnodbStat = 'Estat InnoDB';
 $strInsecureMySQL = 'El vostre fitxer de configuraci t parmetres (root sense contrasenya) que corresponen al compte privilegiat predetermitat de MySQL. El servidor MySQL est funcionant amb aquests valors, el que significa un forat de seguretat, i s\'exposa a intrusions, pel que recomanem la reparaci urgent d\'aquest forat de seguretat.';
 $strInsert = 'Insereix';
@@ -335,6 +355,7 @@ $strKorean = 'Core';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'Opcions LaTeX';
 $strLandscape = 'Horitzontal';
+$strLatchedPages = 'Planes inalterables';
 $strLatexCaption = 'Titol de Taula';
 $strLatexContent = 'Contingut de la taula __TABLE__';
 $strLatexContinued = '(contina)';
@@ -346,8 +367,8 @@ $strLatvian = 'Let';
 $strLengthSet = 'Longitud/Valors*';
 $strLimitNumRows = 'registres per plana';
 $strLineFeed = 'Salt de lnia: \\n';
-$strLinesTerminatedBy = 'Lnies terminades per';
-$strLinkNotFound = 'L\'enlla no s\'ha trobat';
+$strLinesTerminatedBy = 'Lnies acabades amb';
+$strLinkNotFound = 'No s\'ha trobat l\'enlla ';
 $strLinksTo = 'Enllaos a';
 $strLithuanian = 'Litu ';
 $strLoadExplanation = 'El millor metode es comprova per defecte, pero es pot canviar si falla.';
@@ -360,6 +381,7 @@ $strLogUsername = 'Nom d\'Usuari:';
 $strLogin = 'Identificaci';
 $strLoginInformation = 'Informaci d\'Identificaci';
 $strLogout = 'Sortir';
+$strLongOperation = 'Aquesta operaci pot ser bastant llarga. Procedim igualment?';
 
 $strMIMETypesForTable = 'TIPUS MIME PER LA TAULA';
 $strMIME_MIMEtype = 'Tipus MIME';
@@ -384,6 +406,18 @@ $strMoveTableOK = 'Taula %s moguda a %s.';
 $strMoveTableSameNames = 'No es pot moure la taula sobre ella mateixa!';
 $strMultilingual = 'multilinge';
 $strMustSelectFile = 'Has de sel.leccionar l\'arxiu que vols inserir.';
+$strMyISAMDataPointerSize = 'Tamany de l\'apuntador de dades';
+$strMyISAMDataPointerSizeDesc = 'El tamany per defecte de l\'apuntador en bytes, usat en CREATE TABLE per a taules MyISAM quan no s\'especifica l\'opci MAX_ROWS.';
+$strMyISAMMaxExtraSortFileSize = 'Mxim tamany per arxius temporals en creaci d\'ndex';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Si l\'arxiu temporal usat per creaci rpida d\'un ndex MyISAM pot ser ms gran que usant el cau principal per la quantitat especificada aqu, es recomana fer servir el cau principal.';
+$strMyISAMMaxSortFileSize = 'Tamany mxim per arxius temporals de classificaci';
+$strMyISAMMaxSortFileSizeDesc = 'El tamany mxim per arxius temporals de MySQL es permet usar-lo mentre es torna acrear un ndex MyISAM (mentre es fa un REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Modus de recuperaci automtic';
+$strMyISAMRecoverOptionsDesc = 'El modus per a recuperaci automtica en taules MyISAM corruptes, com s\'estableix via l\'opci d\'inici del servidor --myisam-recover.';
+$strMyISAMRepairThreads = 'Reparar fils';
+$strMyISAMRepairThreadsDesc = 'Si aquest valor s ms gran que 1, els ndexos de taules  MyISAM es creen en paralel (cada ndex en el seu propi fil) mentre s\'executa el procs de reparaci per classificaci.';
+$strMyISAMSortBufferSize = 'Tamany de l\'rea de classificaci';
+$strMyISAMSortBufferSizeDesc = 'rea assignada per classificar ndexos MyISAM mentre es fa un REPAIR TABLE o mentre es creen ndexos amb CREATE INDEX o ALTER TABLE.';
 $strMySQLCharset = 'Joc de carcters de MySQL';
 $strMySQLConnectionCollation = 'Ordenaci de la connexi MySQL'; 
 $strMySQLReloaded = 'MySQL reiniciat.';
@@ -401,6 +435,7 @@ $strNoActivity = 'Sense activitat des de fa %s segons o ms, entra de nou';
 $strNoDatabases = 'No hi ha Bases de Dades';
 $strNoDatabasesSelected = 'No hi han Bases de dades sel.leccionades.';
 $strNoDescription = 'Sense Descripci';
+$strNoDetailsForEngine = 'No hi ha informaci detallada de l\'estat disponible per a aquest motor d\'emmagatzematge.';
 $strNoDropDatabases = 'Instrucci "DROP DATABASE" desactivada.';
 $strNoExplain = 'Saltar l\'explicaci de l\'SQL';
 $strNoFrames = 'phpMyAdmin s ms fcil amb un navegador que <b>suporti marcs (frames)</b>.';
@@ -444,6 +479,7 @@ $strOverwriteExisting = 'Sobreescriure arxiu(s) existent(s)';
 $strPHP40203 = 'S\'esta fent servir la versi 4.2.3 de PHP, que t un serios error amb cadenes de multi-byte (mbstring). Mira l\'informe d\'error 19404 de PHP. No es recomana aquesta versi de PHP per treballar amb phpMyAdmin.';
 $strPHPVersion = 'PHP versi';
 $strPageNumber = 'Nmero de pgina:';
+$strPagesToBeFlushed = 'Planes per a purgar';
 $strPaperSize = 'Tamany de paper';
 $strPartialText = 'Textos Parcials';
 $strPassword = 'Contrasenya';
@@ -475,13 +511,19 @@ $strPrintView = 'Imprimir vista';
 $strPrintViewFull = 'Vista d\'impresi (amb texts sencers)';
 $strPrivDescAllPrivileges = 'Inclou tots els permissos excepte GRANT (atorgar).';
 $strPrivDescAlter = 'Permet alterar l\'estructura de taules existents.';
+$strPrivDescAlterDb = 'Permet alterar l\'estructura de taules existents aix com canviar el joc de caracters i ordenacions de les bases de dades.'; 
+$strPrivDescAlterRoutine = 'Permet alterar i esborrar rutines enmagatzemades.'; 
 $strPrivDescCreateDb = 'Permet crear noves bases de dades i taules.';
+$strPrivDescCreateRoutine = 'Permet crear rutines enmgatzemades.';  
 $strPrivDescCreateTbl = 'Permet crear noves taules.';
 $strPrivDescCreateTmpTable = 'Permet crear taules temporals.';
+$strPrivDescCreateUser = 'Permet crear, esborrar i reanomenar comptes d\'usuari.'; 
+$strPrivDescCreateView = 'Permet crear noves vistes.';  
 $strPrivDescDelete = 'Permet esborrar dades.';
 $strPrivDescDropDb = 'Permet eliminar bases de dades i taules.';
 $strPrivDescDropTbl = 'Permet eliminar taules.';
 $strPrivDescExecute = 'Permet executar processos enmagatzemats (stored procedures); No t efecte en aquesta versi de MySQL.';
+$strPrivDescExecute5 = 'Permet executar rutines enmagatzemades.'; 
 $strPrivDescFile = 'Permet importar i exportar dades amb fitxers externs.';
 $strPrivDescGrant = 'Permet afegir usuaris i permissos sense tenir que recarregar les taules de permissos.';
 $strPrivDescIndex = 'Permet crear i eliminar indexos.';
@@ -498,6 +540,7 @@ $strPrivDescReplClient = 'Dona el dret a l\'usuari de preguntar quins servidors
 $strPrivDescReplSlave = 'Es necessari per a la replicaci en servidors esclaus.';
 $strPrivDescSelect = 'Permet llegir dades.';
 $strPrivDescShowDb = 'Dona accs a la llista completa de bases de dades.';
+$strPrivDescShowView = 'Permet fer consultes de tipus SHOW CREATE VIEW.'; 
 $strPrivDescShutdown = 'Permet parar el servidor.';
 $strPrivDescSuper = 'Permet connectar, encara que s\'hagi arribat al mxim numero de connexions perms; Es necessari per moltes operacions d\'administraci com ara establir variables globals o b cancel.lar fils d\'execuci d\'altres usuaris.';
 $strPrivDescUpdate = 'Permet canviar dades.';
@@ -546,6 +589,7 @@ $strRevokeAndDelete = 'Denega tots els permissos actius dels usuaris i els esbor
 $strRevokeAndDeleteDescr = 'Els usuaris encara tindran el perms USAGE fins que es recarreguin els permissos.';
 $strRevokeMessage = 'Has tret els permissos per %s';
 $strRomanian = 'Romans';
+$strRoutines = 'Rutines'; 
 $strRowLength = 'Longitud de fila';
 $strRowSize = 'Mida de fila ';
 $strRows = 'Fila';
@@ -621,6 +665,7 @@ $strSingly = '(noms)';
 $strSize = 'Mida';
 $strSlovak = 'Eslovac';
 $strSlovenian = 'Eslov';
+$strSocketProblem = '(o el scol del servidor local MySQL no est configurat correctament)';
 $strSort = 'Classificaci';
 $strSortByKey = 'Classifica per la clau';
 $strSpaceUsage = 'Utilitzaci d\'espai';
@@ -631,6 +676,8 @@ $strStatCreateTime = 'Creaci';
 $strStatUpdateTime = 'Darrera actualitzaci';
 $strStatement = 'Sentncies';
 $strStatus = 'Estat';
+$strStorageEngine = 'Motor d\'emmagatzematge';
+$strStorageEngines = 'Motors d\'emmagatzematge';
 $strStrucCSV = 'dades CSV ';
 $strStrucData = 'Estructura i dades';
 $strStrucDrop = 'Afegir DROP TABLE';
@@ -677,6 +724,7 @@ $strTraditionalChinese = 'Xins Tradicional';
 $strTraditionalSpanish = 'Espanyol Tradicional';
 $strTraffic = 'Trfic';
 $strTransformation_application_octetstream__download = 'Mostra un enlla per descarregar les dades binries d\'un camp. La primera dada s el nom d\'arxiu binari. La segona dada s un possible nom de camp d\'una taula que contingui el nom d\'arxiu. Si es facilita la segona dada s necessari tenir la primera dada buida';
+$strTransformation_application_octetstream__hex = 'Mostra la representaci hexadecimal de les dades.'; 
 $strTransformation_image_jpeg__inline = 'Mostra una miniatura am enlla; opcions: ample,alt en pixels (respecta la proporci original)';
 $strTransformation_image_jpeg__link = 'Es mostra com a enlla a la imatge.';
 $strTransformation_image_png__inline = 'Veure image/jpeg: en linia';
@@ -685,8 +733,7 @@ $strTransformation_text_plain__external = 'NOMS LINUX: Llena una aplicaci extern
 $strTransformation_text_plain__formatted = 'Conserva el format original del camp. No es fa cap canvi.';
 $strTransformation_text_plain__imagelink = 'Mostra una imatge i un enlla, el camp cont el nom del fitxer; la primera opci s un prefixe com "http://domini.com/", la segona opci s l\'amplada en pixels, la tercera s l\'alada.';
 $strTransformation_text_plain__link = 'Mostra un enlla, el camp cont el nom del fitxer; la primera opci s un prefixe com "http://domini.com/", la segona opci s el titol del enlla.';
-$strTransformation_text_plain__substr = 'Noms mostra part de la cadena. La primera opci marca el desplaament on comena el teu text (Per defecte 0). La segona opci indica la quantitat de caracters a retornar. Si s buit, retorna tot el texte restant. La tercera opci defineix els caracters que s\'han d\'afegir a la sortida quan es retorna la cadena (Defecte: ...) .';
-$strTransformation_text_plain__unformatted = 'Mostra codi HTML com entitats HTML. No es mostra en format HTML.';
+$strTransformation_text_plain__substr = 'Mostra una part d\'una cadena de text. La primera opci s el nombre de caracters a saltar des de l\'inici de la cadena (Per defecte 0). La segona opci s el nombre de caracters a retornar (Per defecte: fins al final de la cadena). La tercera opci s la cadena a afegir a l\'inici o al final quan hi ha truncament (Per defecte: "...").';
 $strTruncateQueries = 'Talla les consultes mostrades';
 $strTurkish = 'Turc';
 $strType = 'Tipus';
@@ -722,9 +769,12 @@ $strValidateSQL = 'Validar l\'SQL';
 $strValidatorError = 'No s\'ha pogut iniciar el validador SQL. Si us plau, comproveu que teniu installats els mduls de PHP necessaris tal i com s\'indica a la %sdocumentaci%s.';
 $strValue = 'Valor';
 $strVar = 'Variable';
+$strVersionInformation = 'Informaci de Versi';
+$strView = 'Vista';
 $strViewDump = 'Veure un esquema de la taula';
 $strViewDumpDB = 'Veure l\'esquema de la base de dades';
 $strViewDumpDatabases = 'Veure volcat (esquema) de les bases de dades';
+$strViewHasBeenDropped = 'Vista %s esborrada';
 
 $strWebServerUploadDirectory = 'Directori de pujada d\'arxius del servidor web';
 $strWebServerUploadDirectoryError = 'No est disponible el directori indicat per pujar arxius';
