@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_traditional-big5.inc.php,v 2.20 2004/12/28 16:34:45 nijel Exp $ */
+/* $Id: chinese_traditional-big5.inc.php,v 2.40.2.1 2005/06/30 17:03:17 lem9 Exp $ */
 
 /**
  * Last translation by: Siu Sun <siusun@best-view.net>
@@ -52,6 +52,7 @@ $strAffectedRows = 'vTC: ';
 $strAfter = 'b %s ';
 $strAfterInsertBack = '^';
 $strAfterInsertNewInsert = 'sW@O';
+$strAfterInsertNext = 'ss@C';
 $strAfterInsertSame = '^o';
 $strAll = '';
 $strAllTableSameWidth = 'HۦPeܩҦƪ?';
@@ -94,11 +95,18 @@ $strBookmarkThis = 'N SQL yk[J';
 $strBookmarkView = 'd';
 $strBrowse = 's';
 $strBrowseForeignValues = 's~ӭ';
+$strBufferPool = 'wİ';
+$strBufferPoolActivity = 'wİϬʲv';
+$strBufferPoolUsage = 'wİϨϥΪŶ';
+$strBufferReadMisses = 'Ū|';
+$strBufferReadMissesInPercent = 'Ū| %';
+$strBufferWriteWaits = 'gJ';
+$strBufferWriteWaitsInPercent = 'gJ %';
 $strBulgarian = 'O[QȻy';
+$strBusyPages = 'c';
 $strBzError = 'phpMyAdmin LkY]o php  Bz2 Ҳտ~. jCnD phpMyAdmin ]wɳ]w <code>$cfg[\'BZipDump\']</code> <code>FALSE</code>. pGQϥ Bz2 Y\,Чs php ̷s. ԱаѬ php ~ %s .';
 $strBzip = '"bzipped"';
 
-$strCSVOptions = 'CSV ﶵ';
 $strCalendar = '';
 $strCannotLogin = 'LknJ MySQL A';
 $strCantLoad = 'LkŪ %s Ҳ,<br />ˬd PHP ]w';
@@ -119,12 +127,12 @@ $strChangeCopyModeRevoke = ' ... oҦ¨ϥΪ̦ĤvçR.';
 $strChangeCopyUser = 'nJT / ƻsϥΪ';
 $strChangeDisplay = 'ܤ';
 $strChangePassword = 'KX';
-$strCharset = 'r榡 (Charset)';
-$strCharsetOfFile = 'rɮ:';
-$strCharsets = 'r';
-$strCharsetsAndCollations = 'rήչ';
+$strCharset = 'rsX (Charset)';
+$strCharsetOfFile = 'rsXɮ:';
+$strCharsets = 'rsX';
+$strCharsetsAndCollations = 'rsXήչ';
 $strCheckAll = '';
-$strCheckOverhead = 'ˬdB~O (overheaded)'; // nor sure yet.
+$strCheckOverhead = 'ˬdB~O (overhead)'; // nor sure yet.
 $strCheckPrivs = 'dv';
 $strCheckPrivsLong = 'd߸Ʈw &quot;%s&quot; v.';
 $strCheckTable = 'ˬdƪ';
@@ -146,12 +154,14 @@ $strConnections = 'su';
 $strConstraintsForDumped = 'ƥƪ';
 $strConstraintsForTable = 'ƪ';
 $strCookiesRequired = 'Cookies Ұʤ~nJ.';
+$strCopy = 'ƻs';
 $strCopyDatabaseOK = 'Ʈw %s wƻs %s';
 $strCopyTable = 'ƻsƪG (榡 ƮwW<b>.</b>ƪW):';
 $strCopyTableOK = 'wgNƪ %s ƻs %s.';
 $strCopyTableSameNames = 'LkƻsۦPƪ!';
 $strCouldNotKill = 'phpMyAdmin Lk_O %s. ioOwg.';
 $strCreate = 'إ';
+$strCreateDatabaseBeforeCopying = 'ƻseإ߸Ʈw (CREATE DATABASE)';
 $strCreateIndex = 'sW &nbsp;%s&nbsp; կ';
 $strCreateIndexTopic = 'sW@կ';
 $strCreateNewDatabase = 'إ߷sƮw';
@@ -161,6 +171,7 @@ $strCreatePdfFeat = 'إ PDF';
 $strCreationDates = 'إ/s/ˬd ';
 $strCriteria = 'z';
 $strCroatian = 'JùȻy';
+$strCSVOptions = 'CSV ﶵ';
 $strCyrillic = '訽y';
 $strCzech = 'Jy';
 $strCzechSlovak = 'Jy';
@@ -181,6 +192,7 @@ $strDanish = 'y';
 $strData = '';
 $strDataDict = 'ƾڦr';
 $strDataOnly = 'u';
+$strDataPages = ']tƭ';
 $strDatabase = 'Ʈw';
 $strDatabaseEmpty = 'ƮwW٨åJ!!';
 $strDatabaseExportOptions = 'ƮwXﶵ';
@@ -195,6 +207,7 @@ $strDatabasesStatsHeavyTraffic = ': ҰʸƮwέpƾڥi|ͤjq Web A MySQL yq.';
 $strDbPrivileges = 'wƮwv';
 $strDbSpecific = 'wƮw';
 $strDefault = 'w]';
+$strDefaultEngine = 'o MySQL Aw]xsO %s ';
 $strDefaultValueHelp = 'w]: ХuJӹw], Lݥ[Wϱ׽uΤ޸';
 $strDefragment = 'zƪ';
 $strDelOld = 'ѦҨƪwsb. zƱRoǰѦҶ?';
@@ -208,6 +221,7 @@ $strDeleting = 'R %s';
 $strDescending = '';
 $strDescription = '';
 $strDictionary = 'r';
+$strDirtyPages = 'D';
 $strDisableForeignChecks = 'ȩw~ (Foreign Key) ˬd';
 $strDisabled = 'Ұ';
 $strDisplayFeat = '\';
@@ -236,6 +250,10 @@ $strEncloseInTransaction = 'ϥΨưȶ (Transaction) 覡';
 $strEnd = '̫@';
 $strEndCut = ' Ũ';
 $strEndRaw = ' l';
+$strEngineAvailable = '%s w䴩o MySQL A.';
+$strEngineDisabled = '%s vo MySQL A.';
+$strEngineUnsupported = 'o MySQL ä %s xs.';
+$strEngines = ''; 
 $strEnglish = '^y';
 $strEnglishPrivileges = '`N: MySQL vWٷ|H^y';
 $strError = '~';
@@ -267,12 +285,15 @@ $strFlushPrivilegesNote = ': phpMyAdmin  MySQL vƪoϥΪv. pGϥΪ̦ۦƪ, ƪeNiPڨ
 $strFlushTable = 'jsƪ ("FLUSH")';
 $strFormEmpty = '椺|@Ǹ!';
 $strFormat = '榡';
+$strFreePages = 'm';
 $strFullText = 'ܧr';
 $strFunction = '';
 
 $strGenBy = 'إ';
-$strGenTime = 'إߤ';
 $strGeneralRelationFeat = '@p\';
+$strGenerate = '';
+$strGeneratePassword = 'ͱKX';
+$strGenTime = 'إߤ';
 $strGeorgian = '|NȻy';
 $strGerman = 'wy';
 $strGlobal = '';
@@ -283,6 +304,10 @@ $strGrantOption = 'v';
 $strGreek = 'þy';
 $strGzip = '"gzipped"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Microsoft Excel 2000 Xﶵ';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Microsoft Word 2000 Xﶵ';
 $strHasBeenAltered = 'wgק';
 $strHasBeenCreated = 'wgإ';
 $strHaveToShow = 'zݭn̤ܳܤ@';
@@ -314,6 +339,14 @@ $strIndexWarningPrimary = 'D PRIMARY   INDEX Pɶ]w `%s` ';
 $strIndexWarningTable = 'ƪ `%s` ްD';
 $strIndexWarningUnique = 'ߤ@ UNIQUE   INDEX Pɶ]w `%s` ';
 $strIndexes = '';
+$strInnoDBAutoextendIncrement = '۰ʦjp';
+$strInnoDBAutoextendIncrementDesc = 'ƪeq񺡮, ۰ʼWjeqjp.';
+$strInnoDBBufferPoolSize = 'wİϤjp';
+$strInnoDBBufferPoolSizeDesc = 'InnoDB ƪΩ֨ƤίޮɨϥΪOwĤjp.';
+$strInnoDBDataFilePath = 'ɮ';
+$strInnoDBDataHomeDir = 'ƥDؿ';
+$strInnoDBDataHomeDirDesc = 'Ҧ InnoDB ɮתDƥؿm.';
+$strInnoDBPages = '';
 $strInnodbStat = 'InnoDB A';
 $strInsecureMySQL = ']wɤ]w (rootnJΨSKX) Pw] MySQL vfۦPC MySQL Abow]]wB檺ܷ|ܮeQJIAz靈]whw|}C';
 $strInsert = 'sW';
@@ -340,6 +373,7 @@ $strKorean = 'y';
 $strLaTeX = 'LaTeX';  // use eng
 $strLaTeXOptions = 'LaTeX ﶵ';
 $strLandscape = 'V';
+$strLatchedPages = 'W';
 $strLatexCaption = 'ƪD';
 $strLatexContent = 'ƪ __TABLE__ e';
 $strLatexContinued = '(s)';
@@ -365,6 +399,7 @@ $strLogUsername = 'nJW:';
 $strLogin = 'nJ';
 $strLoginInformation = 'nJT';
 $strLogout = 'nXt';
+$strLongOperation = 'oӧ@~ҥήɶ|, ~?';
 
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
 $strMIME_MIMEtype = 'MIME ';
@@ -378,6 +413,8 @@ $strMIME_transformation_options = 'ഫ覡ﶵ';
 $strMIME_transformation_options_note = 'ХΥHU榡Jഫﶵ: \'a\',\'b\',\'c\'...<br />pzݭnJϱ׽u ("\") γ޸ ("\'") ЦA[Wϱ׽u (Ҧp \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'MIME HܬOSjഫ\';
 $strMaximumSize = '̤jeq: %s%s'; 
+$strMbExtensionMissing = '䤣 PHP  mbstring sXҲ, SoӼҲ, phpMyAdmin LkǽTarr, ӥiಣͰD.';
+$strMbOverloadWarning = 'Ab PHP ]wҰʤF mbstring.func_overload ﶵ, oӿﶵȮɤݮe phpMyAdmin , Ai|l!';
 $strModifications = 'קwxs';
 $strModify = 'ק';
 $strModifyIndexTopic = 'ק';
@@ -387,6 +424,18 @@ $strMoveTableOK = 'ƪ %s wgʨ %s.';
 $strMoveTableSameNames = 'LkʨۦPƪ!';
 $strMultilingual = 'hy';
 $strMustSelectFile = 'zܻݭnsWɮ.';
+$strMyISAMDataPointerSize = 'ƫФjp';
+$strMyISAMDataPointerSizeDesc = 'w]ƫФjpɷH CREATE TABLE إ MyISAM ƪ, ӨõL]w̤jC (MAX_ROWS) , N|H짹լ]wjp';
+$strMyISAMMaxExtraSortFileSize = '{ɮ׫إ߯ޮɳ̤jeq';
+$strMyISAMMaxExtraSortFileSizeDesc = 'p{ɮץΧ@ֳt MyISAM ޮɤjoӳ]weq, ĳϥW֨覡.';
+$strMyISAMMaxSortFileSize = '{ɱƧɮ׳̤jeq';
+$strMyISAMMaxSortFileSizeDesc = 'MySQL Ω󭫫 MyISAM  (REPAIR TABLE, ALTER TABLE,  LOAD DATA INFILE) ɪ{ɮפjp.';
+$strMyISAMRecoverOptions = '۰ʭ״_Ҧ';
+$strMyISAMRecoverOptionsDesc = 'oӼҦN|۰ʭ״_la MyISAM ƪ, pPAҰʳ]w[J --myisam-recover ﶵ.';
+$strMyISAMRepairThreads = '״_u@';
+$strMyISAMRepairThreadsDesc = 'pƭȤj 1 , MyISAM ƪ״_ɤޱN|HPBإ.';
+$strMyISAMSortBufferSize = 'ƧǽwĤjp';
+$strMyISAMSortBufferSizeDesc = 'oӽwĤjpOtb״_ƪO (REPAIR TABLE) B CREATE INDEX  ALTER TABLE O, ΩƧ MyISAM ޤ';
 $strMySQLCharset = 'MySQL rsX';
 $strMySQLConnectionCollation = 'MySQL suչ';
 $strMySQLReloaded = 'MySQL sJ';
@@ -404,6 +453,7 @@ $strNoActivity = 'ѩwmFF %s , ЭsnJ';
 $strNoDatabases = 'SƮw';
 $strNoDatabasesSelected = 'SƮw.';
 $strNoDescription = 'S';
+$strNoDetailsForEngine = 'oxsõLԲӪA.';
 $strNoDropDatabases = '"DROP DATABASE" Owg.';
 $strNoExplain = 'L SQL';
 $strNoFrames = 'phpMyAdmin AXϥΦb䴩<b></b>s.';
@@ -447,6 +497,7 @@ $strOverwriteExisting = 'мgwsbɮ';
 $strPHP40203 = 'zϥ PHP  4.2.3, o@r`rY~(mbstring). аѾ\ PHP γis 19404. phpMyAdmin äĳϥγoӪ PHP .';
 $strPHPVersion = 'PHP ';
 $strPageNumber = 'X:';
+$strPagesToBeFlushed = 'js';
 $strPaperSize = 'ȱijp';
 $strPartialText = 'ܳr';
 $strPassword = 'KX';
@@ -478,13 +529,19 @@ $strPrintView = 'CL˵';
 $strPrintViewFull = 'CL˵ (ܧr)';
 $strPrivDescAllPrivileges = ']AҦvFv (GRNANT).';
 $strPrivDescAlter = 'e\ק{ƪc.';
+$strPrivDescAlterDb = 'e\{ƪcBrsXήչ.';
+$strPrivDescAlterRoutine = 'e\קΧRxs{.';
 $strPrivDescCreateDb = 'e\إ߷sƮwθƪ.';
+$strPrivDescCreateRoutine = 'e\إxs{';
 $strPrivDescCreateTbl = 'e\إ߷sƪ.';
 $strPrivDescCreateTmpTable = 'e\إ߼Ȯɩʸƪ.';
+$strPrivDescCreateUser = 'e\إߡBRέsRWϥΪ̤f.';
+$strPrivDescCreateView = 'e\إ߷s˵.';
 $strPrivDescDelete = 'e\RO.';
 $strPrivDescDropDb = 'e\RƮwθƪ.';
 $strPrivDescDropTbl = 'e\Rƪ.';
 $strPrivDescExecute = 'e\ wxs{.  MySQL L.';
+$strPrivDescExecute5 = 'e\xs{.';
 $strPrivDescFile = 'e\JοXƾڨɮ.';
 $strPrivDescGrant = 'e\sWϥΪ̤vӵLݭsŪvƪ.';
 $strPrivDescIndex = 'e\إߤΧR.';
@@ -501,6 +558,7 @@ $strPrivDescReplClient = 'e\Τd slaves / masters bB.';
 $strPrivDescReplSlave = 'ݭnƻs slaves.';
 $strPrivDescSelect = 'e\Ūƾ.';
 $strPrivDescShowDb = 'iŪӸƮwM.';
+$strPrivDescShowView = 'e\ SHOW CREATE VIEW d.'; 
 $strPrivDescShutdown = 'e\A.';
 $strPrivDescSuper = 'e\su, NWLF̤jsu; Ω̰tκ޲zp]wvΤLϥΪ̫O.';
 $strPrivDescUpdate = 'e\sƾ.';
@@ -522,6 +580,7 @@ $strQueryType = 'dߤ覡';
 $strQueryWindowLock = 'nNoykл\쥻~SQLyk';
 
 $strReType = 'T{KX';
+$strReadRequests = 'ŪnD';
 $strReceived = '';
 $strRecords = 'O';
 $strReferentialIntegrity = 'ˬdܧ:';
@@ -549,6 +608,7 @@ $strRevokeAndDelete = 'oϥΪ̩ҦĤvçR.';
 $strRevokeAndDeleteDescr = 'ϥΪ̤M USAGE vvƪsŪ.';
 $strRevokeMessage = 'zwoϥΪ̪v: %s';
 $strRomanian = 'ùȻy';
+$strRoutines = '{ (Routines)';
 $strRowLength = 'ƦC';
 $strRowSize = 'ƦCjp';
 $strRows = 'ƦCC';
@@ -564,6 +624,7 @@ $strRunning = 'b %s ';
 $strRussian = 'Xy';
 
 $strSQL = 'SQL'; // should express in english
+$strSQLExportCompatibility = 'SQL Xݮe';
 $strSQLExportType = 'X覡';
 $strSQLOptions = 'SQL ﶵ';
 $strSQLParserBugMessage = 'oiOzF SQL R{@ǵ{~AвӤ߬dݱzykAˬd@U޸OTΨS|ALiX]iӦ۱zWɮ׮ɦb޸~aϥΤFGiXCziHզb MySQL ROCӻykCp MySQL AoX~HAoiUzhXDҦbCpzMѨMDAΦbR{X{~AbROCҦॿ`AбNӥyX{~ SQL ykXAñNHU"Ũ"@P:';
@@ -623,6 +684,7 @@ $strSingly = '(u|Ƨǲ{ɪO)';
 $strSize = 'jp';
 $strSlovak = 'Jy';
 $strSlovenian = '奧Ȼy';
+$strSocketProblem = '( Ϊ̥ MySQL A socket åT]w)';
 $strSort = 'Ƨ';
 $strSortByKey = 'WƧ';
 $strSpaceUsage = 'wϥΪŶ';
@@ -633,6 +695,8 @@ $strStatCreateTime = 'إ';
 $strStatUpdateTime = '̫s';
 $strStatement = 'ԭz';
 $strStatus = 'A';
+$strStorageEngine = 'xs';
+$strStorageEngines = 'xs';
 $strStrucCSV = 'CSV ';
 $strStrucData = 'cP';
 $strStrucDrop = '[J \'Rƪ\' yk';
@@ -688,7 +752,6 @@ $strTransformation_text_plain__formatted = 'Os쥻e榡. i Escaping Bz.';
 $strTransformation_text_plain__imagelink = 'ܹϹγs, ƾڤeOɮצW; Ĥ@ӿﶵO}eq ( "http://domain.com/" ), ĤGӿﶵOeת,ĤTӿﶵOת.';
 $strTransformation_text_plain__link = 'ܳs, ƾڤeOɮצW; Ĥ@ӿﶵO}eq ( "http://domain.com/" ), ĤGﶵOsD.';
 $strTransformation_text_plain__substr = 'uܳr. Ĥ@ӿﶵr}lXm (offset)  (w]: 0). ĤGӿﶵh֭ӦrX. dŬXlUҦr. ĤTӿﶵr^ܤr󵲧 (w]: ...) .';
-$strTransformation_text_plain__unformatted = 'H HTML X HTML . |ܥ HTML 榡.';
 $strTruncateQueries = 'Rwܬd';
 $strTurkish = 'gըy';
 $strType = 'A';
@@ -724,9 +787,12 @@ $strValidateSQL = 'ˬd SQL';
 $strValidatorError = 'SQL R{ҰʡAˬdO_wN %s%s  PHP ɮצwˡC';
 $strValue = '';
 $strVar = 'T';
+$strVersionInformation = 'T';
+$strView = '˵';
 $strViewDump = '˵ƪƥn (dump schema)';
 $strViewDumpDB = '˵Ʈwƥn (dump schema)';
 $strViewDumpDatabases = 'ܸƮwn (schema)';
+$strViewHasBeenDropped = '˵ %s vQR.';
 
 $strWebServerUploadDirectory = 'Web AWؿ';
 $strWebServerUploadDirectoryError = ']wWؿ~Aϥ';
@@ -735,6 +801,7 @@ $strWestEuropean = 'ڻy';
 $strWildcard = 'UΦr';
 $strWindowNotFound = 'ئaLks. iAwΧAsw]wҰʤFLks';
 $strWithChecked = 'ܪƪG';
+$strWriteRequests = 'gJnD';
 $strWritingCommentNotPossible = 'LkxsѤr';
 $strWritingRelationNotPossible = 'Lkxsp';
 $strWrongUser = '~ϥΪ̦W٩αKXAڵs';
@@ -746,8 +813,5 @@ $strYes = ' O ';
 $strZeroRemovesTheLimit = ': ]woǿﶵ 0 (s) iѰ.';
 $strZip = '"zipped"';
 
-$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
-$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
-$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
-$strAfterInsertNext = 'Edit next row';  //to translate
+$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
 ?>
