@@ -1,7 +1,7 @@
 <?php
-/* $Id: english-iso-8859-1.inc.php,v 2.59 2004/12/29 14:30:21 nijel Exp $ */
+/* $Id: english-iso-8859-15.inc.php,v 2.5 2005/06/12 10:09:57 swix Exp $ */
 
-$charset = 'iso-8859-1';
+$charset = 'iso-8859-15';
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
 $left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
 $right_font_family = 'arial, helvetica, geneva, sans-serif';
@@ -19,7 +19,7 @@ $timespanfmt = '%s days, %s hours, %s minutes and %s seconds';
 
 $strAPrimaryKey = 'A primary key has been added on %s';
 $strAbortedClients = 'Aborted';
-$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on webserver to docSQL directory';
+$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on the web server to the docSQL directory';
 $strAccessDenied = 'Access denied';
 $strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.';
 $strAction = 'Action';
@@ -49,7 +49,7 @@ $strAfterInsertNewInsert = 'Insert another new row';
 $strAfterInsertNext = 'Edit next row';
 $strAfterInsertSame = 'Go back to this page';
 $strAll = 'All';
-$strAllTableSameWidth = 'display all Tables with same width?';
+$strAllTableSameWidth = 'display all tables with same width?';
 $strAlterOrderBy = 'Alter table order by';
 $strAnIndex = 'An index has been added on %s';
 $strAnalyzeTable = 'Analyze table';
@@ -84,22 +84,30 @@ $strBookmarkAllUsers = 'Let every user access this bookmark';
 $strBookmarkDeleted = 'The bookmark has been deleted.';
 $strBookmarkLabel = 'Label';
 $strBookmarkOptions = 'Bookmark options';
-$strBookmarkQuery = 'Bookmarked SQL-query';
-$strBookmarkThis = 'Bookmark this SQL-query';
+$strBookmarkQuery = 'Bookmarked SQL query';
+$strBookmarkThis = 'Bookmark this SQL query';
 $strBookmarkView = 'View only';
 $strBrowse = 'Browse';
 $strBrowseForeignValues = 'Browse foreign values';
+$strBufferPool = 'Buffer Pool';
+$strBufferPoolActivity = 'Buffer Pool Activity';
+$strBufferPoolUsage = 'Buffer Pool Usage';
+$strBufferReadMisses = 'Read misses';
+$strBufferReadMissesInPercent = 'Read misses in %';
+$strBufferWriteWaits = 'Write waits';
+$strBufferWriteWaitsInPercent = 'Write waits in %';
 $strBulgarian = 'Bulgarian';
-$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.';
+$strBusyPages = 'Busy pages';
+$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this PHP version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a newer PHP version. See PHP bug report %s for details.';
 $strBzip = '"bzipped"';
 
 $strCSVOptions = 'CSV options';
 $strCalendar = 'Calendar';
 $strCannotLogin = 'Cannot login to MySQL server';
-$strCantLoad = 'cannot load %s extension,<br />please check PHP Configuration';
-$strCantLoadRecodeIconv = 'Can not load iconv or recode extension needed for charset conversion, configure php to allow using these extensions or disable charset conversion in phpMyAdmin.';
+$strCantLoad = 'cannot load %s extension;<br />please check PHP configuration';
+$strCantLoadRecodeIconv = 'Couldn\'t load the iconv or recode extension needed for charset conversion. Either configure PHP to enable these extensions or disable charset conversion in phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Can\'t rename index to PRIMARY!';
-$strCantUseRecodeIconv = 'Can not use iconv nor libiconv nor recode_string function while extension reports to be loaded. Check your php configuration.';
+$strCantUseRecodeIconv = 'Couldn\'t use either the iconv, libiconv or recode_string functions, although the necessary extensions appear to be loaded. Check your PHP configuration.';
 $strCardinality = 'Cardinality';
 $strCarriage = 'Carriage return: \\r';
 $strCaseInsensitive = 'case-insensitive';
@@ -112,18 +120,18 @@ $strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user table
 $strChangeCopyModeJustDelete = ' ... delete the old one from the user tables.';
 $strChangeCopyModeRevoke = ' ... revoke all active privileges from the old one and delete it afterwards.';
 $strChangeCopyUser = 'Change Login Information / Copy User';
-$strChangeDisplay = 'Choose Field to display';
+$strChangeDisplay = 'Choose field to display';
 $strChangePassword = 'Change password';
 $strCharset = 'Charset';
 $strCharsetOfFile = 'Character set of the file:';
 $strCharsets = 'Charsets';
 $strCharsetsAndCollations = 'Character Sets and Collations';
 $strCheckAll = 'Check All';
-$strCheckOverhead = 'Check overheaded';
+$strCheckOverhead = 'Check tables having overhead';
 $strCheckPrivs = 'Check Privileges';
 $strCheckPrivsLong = 'Check privileges for database &quot;%s&quot;.';
 $strCheckTable = 'Check table';
-$strChoosePage = 'Please choose a Page to edit';
+$strChoosePage = 'Please choose a page to edit';
 $strColComFeat = 'Displaying Column Comments';
 $strCollation = 'Collation';
 $strColumnNames = 'Column names';
@@ -131,27 +139,29 @@ $strColumnPrivileges = 'Column-specific privileges';
 $strCommand = 'Command';
 $strComments = 'Comments';
 $strCommentsForTable = 'COMMENTS FOR TABLE';
-$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible'; 
+$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';
 $strCompleteInserts = 'Complete inserts';
 $strCompression = 'Compression';
-$strConfigFileError = 'phpMyAdmin was unable to read your configuration file!<br />This might happen if php finds a parse error in it or php cannot find the file.<br />Please call the configuration file directly using the link below and read the php error message(s) that you receive. In most cases a quote or a semicolon is missing somewhere.<br />If you receive a blank page, everything is fine.';
+$strConfigFileError = 'phpMyAdmin was unable to read your configuration file!<br />This might happen if PHP finds a parse error in it or PHP cannot find the file.<br />Please call the configuration file directly using the link below and read the PHP error message(s) that you receive. In most cases a quote or a semicolon is missing somewhere.<br />If you receive a blank page, everything is fine.';
 $strConfigureTableCoord = 'Please configure the coordinates for table %s';
 $strConnectionError = 'Cannot connect: invalid settings.';
 $strConnections = 'Connections';
 $strConstraintsForDumped = 'Constraints for dumped tables';
 $strConstraintsForTable = 'Constraints for table';
 $strCookiesRequired = 'Cookies must be enabled past this point.';
+$strCopy = 'Copy';
 $strCopyDatabaseOK = 'Database %s has been copied to %s';
 $strCopyTable = 'Copy table to (database<b>.</b>table):';
 $strCopyTableOK = 'Table %s has been copied to %s.';
 $strCopyTableSameNames = 'Can\'t copy table to same one!';
 $strCouldNotKill = 'phpMyAdmin was unable to kill thread %s. It probably has already been closed.';
 $strCreate = 'Create';
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';
 $strCreateIndex = 'Create an index on&nbsp;%s&nbsp;columns';
 $strCreateIndexTopic = 'Create a new index';
 $strCreateNewDatabase = 'Create new database';
 $strCreateNewTable = 'Create new table on database %s';
-$strCreatePage = 'Create a new Page';
+$strCreatePage = 'Create a new page';
 $strCreatePdfFeat = 'Creation of PDFs';
 $strCreationDates = 'Creation/Update/Check dates';
 $strCriteria = 'Criteria';
@@ -176,6 +186,7 @@ $strDanish = 'Danish';
 $strData = 'Data';
 $strDataDict = 'Data Dictionary';
 $strDataOnly = 'Data only';
+$strDataPages = 'Pages containing data';
 $strDatabase = 'Database';
 $strDatabaseEmpty = 'The database name is empty!';
 $strDatabaseExportOptions = 'Database export options';
@@ -186,13 +197,14 @@ $strDatabasesDropped = '%s databases have been dropped successfully.';
 $strDatabasesStats = 'Databases statistics';
 $strDatabasesStatsDisable = 'Disable Statistics';
 $strDatabasesStatsEnable = 'Enable Statistics';
-$strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here might cause heavy traffic between the webserver and the MySQL one.';
+$strDatabasesStatsHeavyTraffic = 'Note: Enabling the database statistics here might cause heavy traffic between the web server and the MySQL server.';
 $strDbPrivileges = 'Database-specific privileges';
 $strDbSpecific = 'database-specific';
 $strDefault = 'Default';
+$strDefaultEngine = '%s is the default storage engine on this MySQL server.';
 $strDefaultValueHelp = 'For default values, please enter just a single value, without backslash escaping or quotes, using this format: a';
 $strDefragment = 'Defragment table';
-$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?';
+$strDelOld = 'The current page has references to tables that no longer exist. Would you like to delete those references?';
 $strDelayedInserts = 'Use delayed inserts';
 $strDelete = 'Delete';
 $strDeleteAndFlush = 'Delete the users and reload the privileges afterwards.';
@@ -203,6 +215,7 @@ $strDeleting = 'Deleting %s';
 $strDescending = 'Descending';
 $strDescription = 'Description';
 $strDictionary = 'dictionary';
+$strDirtyPages = 'Dirty pages';
 $strDisableForeignChecks = 'Disable foreign key checks';
 $strDisabled = 'Disabled';
 $strDisplayFeat = 'Display Features';
@@ -231,6 +244,10 @@ $strEncloseInTransaction = 'Enclose export in a transaction';
 $strEnd = 'End';
 $strEndCut = 'END CUT';
 $strEndRaw = 'END RAW';
+$strEngineAvailable = '%s is available on this MySQL server.';
+$strEngineDisabled = '%s has been disabled for this MySQL server.';
+$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';
+$strEngines = 'Engines';
 $strEnglish = 'English';
 $strEnglishPrivileges = ' Note: MySQL privilege names are expressed in English ';
 $strError = 'Error';
@@ -260,14 +277,17 @@ $strFileNameTemplateRemember = 'remember template';
 $strFixed = 'fixed';
 $strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of these tables may differ from the privileges the server uses, if they have been changed manually. In this case, you should %sreload the privileges%s before you continue.';
 $strFlushTable = 'Flush the table ("FLUSH")';
-$strFormEmpty = 'Missing value in the form !';
+$strFormEmpty = 'Missing value in the form!';
 $strFormat = 'Format';
+$strFreePages = 'Free pages';
 $strFullText = 'Full Texts';
 $strFunction = 'Function';
 
 $strGenBy = 'Generated by';
 $strGenTime = 'Generation Time';
 $strGeneralRelationFeat = 'General relation features';
+$strGenerate = 'Generate';
+$strGeneratePassword = 'Generate Password';
 $strGeorgian = 'Georgian';
 $strGerman = 'German';
 $strGlobal = 'global';
@@ -278,9 +298,13 @@ $strGrantOption = 'Grant';
 $strGreek = 'Greek';
 $strGzip = '"gzipped"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';
 $strHasBeenAltered = 'has been altered.';
 $strHasBeenCreated = 'has been created.';
-$strHaveToShow = 'You have to choose at least one Column to display';
+$strHaveToShow = 'You have to choose at least one column to display';
 $strHebrew = 'Hebrew';
 $strHexForBinary = 'Use hexadecimal for binary fields';
 $strHome = 'Home';
@@ -292,7 +316,7 @@ $strHungarian = 'Hungarian';
 $strIcelandic = 'Icelandic';
 $strId = 'ID';
 $strIdxFulltext = 'Fulltext';
-$strIfYouWish = 'If you wish to load only some of a table\'s columns, specify a comma separated field list.';
+$strIfYouWish = 'If you wish to load only some of a table\'s columns, specify a comma-separated field list.';
 $strIgnore = 'Ignore';
 $strIgnoreInserts = 'Use ignore inserts';
 $strIgnoringFile = 'Ignoring file %s';
@@ -302,20 +326,28 @@ $strImportFinished = 'Import finished';
 $strInUse = 'in use';
 $strIndex = 'Index';
 $strIndexHasBeenDropped = 'Index %s has been dropped';
-$strIndexName = 'Index name&nbsp;:';
-$strIndexType = 'Index type&nbsp;:';
+$strIndexName = 'Index name:';
+$strIndexType = 'Index type:';
 $strIndexWarningMultiple = 'More than one %s key was created for column `%s`';
 $strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';
 $strIndexWarningTable = 'Problems with indexes of table `%s`';
 $strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';
 $strIndexes = 'Indexes';
+$strInnoDBAutoextendIncrement = 'Autoextend increment';
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';
+$strInnoDBBufferPoolSize = 'Buffer pool size';
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';
+$strInnoDBDataFilePath = 'Data files';
+$strInnoDBDataHomeDir = 'Data home directory';
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';
+$strInnoDBPages = 'pages';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Your configuration file contains settings (root with no password) that correspond to the default MySQL privileged account. Your MySQL server is running with this default, is open to intrusion, and you really should fix this security hole.';
 $strInsert = 'Insert';
 $strInsertAsNewRow = 'Insert as a new row';
 $strInsertBookmarkTitle = 'Please insert bookmark title';
 $strInsertNewRow = 'Insert new row';
-$strInsertTextfiles = 'Insert data from a textfile into table';
+$strInsertTextfiles = 'Insert data from a text file into the table';
 $strInsertedRowId = 'Inserted row id:';
 $strInsertedRows = 'Inserted rows:';
 $strInstructions = 'Instructions';
@@ -335,6 +367,7 @@ $strKorean = 'Korean';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'LaTeX options';
 $strLandscape = 'Landscape';
+$strLatchedPages = 'Latched pages';
 $strLatexCaption = 'Table caption';
 $strLatexContent = 'Content of table __TABLE__';
 $strLatexContinued = '(continued)';
@@ -353,28 +386,29 @@ $strLithuanian = 'Lithuanian';
 $strLoadExplanation = 'The best method is checked by default, but you can change if it fails.';
 $strLoadMethod = 'LOAD method';
 $strLocalhost = 'Local';
-$strLocationTextfile = 'Location of the textfile';
+$strLocationTextfile = 'Location of the text file';
 $strLogPassword = 'Password:';
 $strLogServer = 'Server';
 $strLogUsername = 'Username:';
 $strLogin = 'Login';
 $strLoginInformation = 'Login Information';
 $strLogout = 'Log out';
+$strLongOperation = 'This operation could take a long time. Proceed anyway?';
 
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';
-$strMIME_MIMEtype = 'MIME-type';
-$strMIME_available_mime = 'Available MIME-types';
+$strMIME_MIMEtype = 'MIME type';
+$strMIME_available_mime = 'Available MIME types';
 $strMIME_available_transform = 'Available transformations';
 $strMIME_description = 'Description';
-$strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.';
+$strMIME_nodescription = 'No description is available for this transformation.<br />Please ask the author what %s does.';
 $strMIME_transformation = 'Browser transformation';
-$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';
+$strMIME_transformation_note = 'For a list of available transformation options and their MIME type transformations, click on %stransformation descriptions%s';
 $strMIME_transformation_options = 'Transformation options';
-$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslash it (for example \'\\\\xyz\' or \'a\\\'b\').';
-$strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function';
+$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, preceed it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_without = 'MIME types printed in italics do not have a separate transformation function';
 $strMaximumSize = 'Max: %s%s';
-$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';
-$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';
+$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using a multibyte charset. Without the mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';
+$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause some data to be corrupted!';
 $strModifications = 'Modifications have been saved';
 $strModify = 'Modify';
 $strModifyIndexTopic = 'Modify an index';
@@ -384,6 +418,18 @@ $strMoveTableOK = 'Table %s has been moved to %s.';
 $strMoveTableSameNames = 'Can\'t move table to same one!';
 $strMultilingual = 'multilingual';
 $strMustSelectFile = 'You should select file which you want to insert.';
+$strMyISAMDataPointerSize = 'Data pointer size';
+$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';
+$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';
+$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';
+$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Automatic recovery mode';
+$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';
+$strMyISAMRepairThreads = 'Repair threads';
+$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the repair by sorting process.';
+$strMyISAMSortBufferSize = 'Sort buffer size';
+$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';
 $strMySQLCharset = 'MySQL charset';
 $strMySQLConnectionCollation = 'MySQL connection collation';
 $strMySQLReloaded = 'MySQL reloaded.';
@@ -397,10 +443,11 @@ $strName = 'Name';
 $strNeedPrimaryKey = 'You should define a primary key for this table.';
 $strNext = 'Next';
 $strNo = 'No';
-$strNoActivity = 'No activity since %s seconds or more, please login again';
+$strNoActivity = 'No activity within %s seconds; please log in again';
 $strNoDatabases = 'No databases';
 $strNoDatabasesSelected = 'No databases selected.';
-$strNoDescription = 'no Description';
+$strNoDescription = 'no description';
+$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';
 $strNoDropDatabases = '"DROP DATABASE" statements are disabled.';
 $strNoExplain = 'Skip Explain SQL';
 $strNoFrames = 'phpMyAdmin is more friendly with a <b>frames-capable</b> browser.';
@@ -413,11 +460,11 @@ $strNoPermission = 'The web server does not have permission to save the file %s.
 $strNoPhp = 'Without PHP Code';
 $strNoPrivileges = 'No Privileges';
 $strNoQuery = 'No SQL query!';
-$strNoRights = 'You don\'t have enough rights to be here right now!';
+$strNoRights = 'You don\'t have sufficient privileges to be here right now!';
 $strNoRowsSelected = 'No rows selected';
 $strNoSpace = 'Insufficient space to save the file %s.';
 $strNoTablesFound = 'No tables found in database.';
-$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';
+$strNoThemeSupport = 'No themes support; please check your configuration and/or your themes in directory %s.';
 $strNoUsersFound = 'No user(s) found.';
 $strNoValidateSQL = 'Skip Validate SQL';
 $strNone = 'None';
@@ -429,6 +476,7 @@ $strNull = 'Null';
 $strNumSearchResultsInTable = '%s match(es) inside table <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> match(es)';
 $strNumTables = 'Tables';
+$strNumberOfFields = 'Number of fields';
 
 $strOK = 'OK';
 $strOftenQuotation = 'Often quotation marks. OPTIONALLY means that only char and varchar fields are enclosed by the "enclosed by"-character.';
@@ -444,12 +492,13 @@ $strOverwriteExisting = 'Overwrite existing file(s)';
 $strPHP40203 = 'You are using PHP 4.2.3, which has a serious bug with multi-byte strings (mbstring). See PHP bug report 19404. This version of PHP is not recommended for use with phpMyAdmin.';
 $strPHPVersion = 'PHP Version';
 $strPageNumber = 'Page number:';
+$strPagesToBeFlushed = 'Pages to be flushed';
 $strPaperSize = 'Paper size';
 $strPartialText = 'Partial Texts';
 $strPassword = 'Password';
-$strPasswordChanged = 'The Password for %s was changed successfully.';
+$strPasswordChanged = 'The password for %s was changed successfully.';
 $strPasswordEmpty = 'The password is empty!';
-$strPasswordHashing = 'Password Hashing'; 
+$strPasswordHashing = 'Password Hashing';
 $strPasswordNotSame = 'The passwords aren\'t the same!';
 $strPdfDbSchema = 'Schema of the the "%s" database - Page %s';
 $strPdfInvalidTblName = 'The "%s" table doesn\'t exist!';
@@ -468,20 +517,26 @@ $strPos1 = 'Begin';
 $strPrevious = 'Previous';
 $strPrimary = 'Primary';
 $strPrimaryKeyHasBeenDropped = 'The primary key has been dropped';
-$strPrimaryKeyName = 'The name of the primary key must be... PRIMARY!';
+$strPrimaryKeyName = 'The name of the primary key must be "PRIMARY"!';
 $strPrimaryKeyWarning = '("PRIMARY" <b>must</b> be the name of and <b>only of</b> a primary key!)';
 $strPrint = 'Print';
 $strPrintView = 'Print view';
 $strPrintViewFull = 'Print view (with full texts)';
 $strPrivDescAllPrivileges = 'Includes all privileges except GRANT.';
 $strPrivDescAlter = 'Allows altering the structure of existing tables.';
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';
 $strPrivDescCreateDb = 'Allows creating new databases and tables.';
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';
 $strPrivDescCreateTbl = 'Allows creating new tables.';
 $strPrivDescCreateTmpTable = 'Allows creating temporary tables.';
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';
+$strPrivDescCreateView = 'Allows creating new views.';
 $strPrivDescDelete = 'Allows deleting data.';
 $strPrivDescDropDb = 'Allows dropping databases and tables.';
 $strPrivDescDropTbl = 'Allows dropping tables.';
-$strPrivDescExecute = 'Allows running stored procedures; Has no effect in this MySQL version.';
+$strPrivDescExecute = 'Allows running stored procedures; has no effect in this MySQL version.';
+$strPrivDescExecute5 = 'Allows executing stored routines.';
 $strPrivDescFile = 'Allows importing data from and exporting data into files.';
 $strPrivDescGrant = 'Allows adding users and privileges without reloading the privilege tables.';
 $strPrivDescIndex = 'Allows creating and dropping indexes.';
@@ -494,12 +549,13 @@ $strPrivDescProcess3 = 'Allows killing processes of other users.';
 $strPrivDescProcess4 = 'Allows viewing the complete queries in the process list.';
 $strPrivDescReferences = 'Has no effect in this MySQL version.';
 $strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.';
-$strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.';
+$strPrivDescReplClient = 'Allows the user to ask where the slaves / masters are.';
 $strPrivDescReplSlave = 'Needed for the replication slaves.';
 $strPrivDescSelect = 'Allows reading data.';
 $strPrivDescShowDb = 'Gives access to the complete list of databases.';
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';
 $strPrivDescShutdown = 'Allows shutting down the server.';
-$strPrivDescSuper = 'Allows connecting, even if maximum number of connections is reached; Required for most administrative operations like setting global variables or killing threads of other users.';
+$strPrivDescSuper = 'Allows connecting, even if maximum number of connections is reached; required for most administrative operations like setting global variables or killing threads of other users.';
 $strPrivDescUpdate = 'Allows changing data.';
 $strPrivDescUsage = 'No privileges.';
 $strPrivileges = 'Privileges';
@@ -511,19 +567,20 @@ $strQBE = 'Query';
 $strQBEDel = 'Del';
 $strQBEIns = 'Ins';
 $strQueryFrame = 'Query window';
-$strQueryOnDb = 'SQL-query on database <b>%s</b>:';
-$strQuerySQLHistory = 'SQL-history';
+$strQueryOnDb = 'SQL query on database <b>%s</b>:';
+$strQuerySQLHistory = 'SQL history';
 $strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
 $strQueryTime = 'Query took %01.4f sec';
 $strQueryType = 'Query type';
 $strQueryWindowLock = 'Do not overwrite this query from outside the window';
 
 $strReType = 'Re-type';
+$strReadRequests = 'Read requests';
 $strReceived = 'Received';
 $strRecords = 'Records';
 $strReferentialIntegrity = 'Check referential integrity:';
 $strRefresh = 'Refresh';
-$strRelationNotWorking = 'The additional Features for working with linked Tables have been deactivated. To find out why click %shere%s.';
+$strRelationNotWorking = 'The additional features for working with linked tables have been deactivated. To find out why click %shere%s.';
 $strRelationView = 'Relation view';
 $strRelationalSchema = 'Relational schema';
 $strRelations = 'Relations';
@@ -546,6 +603,7 @@ $strRevokeAndDelete = 'Revoke all active privileges from the users and delete th
 $strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.';
 $strRevokeMessage = 'You have revoked the privileges for %s';
 $strRomanian = 'Romanian';
+$strRoutines = 'Routines';
 $strRowLength = 'Row length';
 $strRowSize = ' Row size ';
 $strRows = 'Rows';
@@ -554,19 +612,19 @@ $strRowsModeFlippedHorizontal = 'horizontal (rotated headers)';
 $strRowsModeHorizontal = 'horizontal';
 $strRowsModeOptions = 'in %s mode and repeat headers after %s cells';
 $strRowsModeVertical = 'vertical';
-$strRowsStatistic = 'Row Statistic';
+$strRowsStatistic = 'Row Statistics';
 $strRunQuery = 'Submit Query';
 $strRunSQLQuery = 'Run SQL query/queries on database %s';
 $strRunning = 'running on %s';
 $strRussian = 'Russian';
 
 $strSQL = 'SQL';
-$strSQLExportCompatibility = 'SQL export compatibility'; 
+$strSQLExportCompatibility = 'SQL export compatibility';
 $strSQLExportType = 'Export type';
 $strSQLOptions = 'SQL options';
 $strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:';
 $strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem';
-$strSQLQuery = 'SQL-query';
+$strSQLQuery = 'SQL query';
 $strSQLResult = 'SQL result';
 $strSQPBugInvalidIdentifer = 'Invalid Identifer';
 $strSQPBugUnclosedQuote = 'Unclosed quote';
@@ -604,7 +662,7 @@ $strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network t
 $strServerVars = 'Server variables and settings';
 $strServerVersion = 'Server version';
 $strSessionValue = 'Session value';
-$strSetEnumVal = 'If field type is "enum" or "set", please enter the values using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslash it (for example \'\\\\xyz\' or \'a\\\'b\').';
+$strSetEnumVal = 'If field type is "enum" or "set", please enter the values using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, preceed it with a backslash (for example \'\\\\xyz\' or \'a\\\'b\').';
 $strShow = 'Show';
 $strShowAll = 'Show all';
 $strShowColor = 'Show color';
@@ -621,6 +679,7 @@ $strSingly = '(singly)';
 $strSize = 'Size';
 $strSlovak = 'Slovak';
 $strSlovenian = 'Slovenian';
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';
 $strSort = 'Sort';
 $strSortByKey = 'Sort by key';
 $strSpaceUsage = 'Space usage';
@@ -631,6 +690,8 @@ $strStatCreateTime = 'Creation';
 $strStatUpdateTime = 'Last update';
 $strStatement = 'Statements';
 $strStatus = 'Status';
+$strStorageEngine = 'Storage Engine';
+$strStorageEngines = 'Storage Engines';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Structure and data';
 $strStrucDrop = 'Add DROP TABLE';
@@ -640,7 +701,7 @@ $strStrucOnly = 'Structure only';
 $strStructPropose = 'Propose table structure';
 $strStructure = 'Structure';
 $strSubmit = 'Submit';
-$strSuccess = 'Your SQL-query has been executed successfully';
+$strSuccess = 'Your SQL query has been executed successfully';
 $strSum = 'Sum';
 $strSwedish = 'Swedish';
 $strSwitchToDatabase = 'Switch to copied database';
@@ -676,17 +737,16 @@ $strTotalUC = 'Total';
 $strTraditionalChinese = 'Traditional Chinese';
 $strTraditionalSpanish = 'Traditional Spanish';
 $strTraffic = 'Traffic';
-$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';
-$strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)';
-$strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).';
+$strTransformation_application_octetstream__download = 'Displays a link to download the binary data of the field. You can use the first option to specify the filename, or use the second option as the name of a field which contains the filename. If you use the second option, you need to set the first option to the empty string.';
+$strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail. The options are the maximum width and height in pixels. The original aspect ratio is preserved.';
+$strTransformation_image_jpeg__link = 'Displays a link to download this image.';
 $strTransformation_image_png__inline = 'See image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';
-$strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';
-$strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';
-$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';
-$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';
-$strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .';
-$strTransformation_text_plain__unformatted = 'Displays HTML code as HTML entities. No HTML formatting is shown.';
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP or DATETIME field according to your local date/time format. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string; see the documentation for PHP\'s strftime() function.';
+$strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds it the field data via standard input. Returns the standard output of the application. The default is Tidy, to pretty-print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and list the tools you want to make available. The first option is then the number of the program you want to use and the second option is the parameters for the program. The third option, if set to 1, will convert the output using htmlspecialchars() (Default 1). The fourth option, if set to 1, will prevent wrapping and ensure that the output appears all on one line (Default 1).';
+$strTransformation_text_plain__formatted = 'Displays the contents of the field as-is, without running it through htmlspecialchars(). That is, the field is assumed to contain valid HTML.';
+$strTransformation_text_plain__imagelink = 'Displays an image and a link; the field contains the filename. The first option is a URL prefix like "http://www.example.com/". The second and third options are the width and the height in pixels.';
+$strTransformation_text_plain__link = 'Displays a link; the field contains the filename. The first option is a URL prefix like "http://www.example.com/". The second option is a title for the link.';
+$strTransformation_text_plain__substr = 'Displays a part of a string. The first option is the number of characters to skip from the beginning of the string (Default 0). The second option is the number of characters to return (Default: until end of string). The third option is the string to append and/or prepend when truncation occurs (Default: "...").';
 $strTruncateQueries = 'Truncate Shown Queries';
 $strTurkish = 'Turkish';
 $strType = 'Type';
@@ -697,7 +757,7 @@ $strUnicode = 'Unicode';
 $strUnique = 'Unique';
 $strUnknown = 'unknown';
 $strUnselectAll = 'Unselect All';
-$strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';
+$strUpdComTab = 'Please see the documentation on how to update your column_comments table';
 $strUpdatePrivMessage = 'You have updated the privileges for %s.';
 $strUpdateProfileMessage = 'The profile has been updated.';
 $strUpdateQuery = 'Update Query';
@@ -719,20 +779,24 @@ $strUsersDeleted = 'The selected users have been deleted successfully.';
 $strUsersHavingAccessToDb = 'Users having access to &quot;%s&quot;';
 
 $strValidateSQL = 'Validate SQL';
-$strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary php extensions as described in the %sdocumentation%s.';
+$strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary PHP extensions as described in the %sdocumentation%s.';
 $strValue = 'Value';
 $strVar = 'Variable';
+$strVersionInformation = 'Version information';
+$strView = 'View';
 $strViewDump = 'View dump (schema) of table';
 $strViewDumpDB = 'View dump (schema) of database';
 $strViewDumpDatabases = 'View dump (schema) of databases';
+$strViewHasBeenDropped = 'View %s has been dropped';
 
-$strWebServerUploadDirectory = 'web-server upload directory';
+$strWebServerUploadDirectory = 'web server upload directory';
 $strWebServerUploadDirectoryError = 'The directory you set for upload work cannot be reached';
 $strWelcome = 'Welcome to %s';
 $strWestEuropean = 'West European';
 $strWildcard = 'wildcard';
-$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';
+$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window, or your browser\'s security settings are configured to block cross-window updates.';
 $strWithChecked = 'With selected:';
+$strWriteRequests = 'Write requests';
 $strWritingCommentNotPossible = 'Writing of comment not possible';
 $strWritingRelationNotPossible = 'Writing of relation not possible';
 $strWrongUser = 'Wrong username/password. Access denied.';
