@@ -1,15 +1,16 @@
 <?php
-/* $Id: japanese-euc.inc.php,v 2.57 2005/01/09 20:59:43 lem9 Exp $ */
+/* $Id: japanese-euc.inc.php,v 2.76.2.1 2005/06/30 18:53:58 lem9 Exp $ */
 
 /**
  * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
  *               Tadashi Jokagi <elf2000 at users.sourceforge.net>
  */
 
-$charset = 'EUC-JP';
+$charset = 'euc-jp';
+$allow_recoding = TRUE;
 $text_dir = 'ltr';
-$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
-$right_font_family = 'arial, helvetica, geneva, sans-serif';
+$left_font_family = '"MS PGochic", Osaka, verdana, arial, helvetica, geneva, sans-serif';
+$right_font_family = '"MS PGochic", Osaka, arial, helvetica, geneva, sans-serif';
 $number_thousands_separator = ',';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
@@ -22,27 +23,27 @@ $month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
 $datefmt = '%Y ǯ %B %d  %H:%M';
 $timespanfmt = '%s  %s  %s ʬ %s ';
 
-$strAPrimaryKey = '祭%sɲäޤ';
+$strAPrimaryKey = '祭 %s ɲäޤ';
 $strAbortedClients = '';
-$strAbsolutePathToDocSqlDir = 'docSQLؤХѥꤷƲ';
+$strAbsolutePathToDocSqlDir = 'docSQL ؤХѥꤷƤ';
 $strAccessDenied = 'ϵݤޤ';
 $strAccessDeniedExplanation = 'phpMyAdmin ϡMySQL С³褦ȤޤơС³䤷ޤconfig.inc.php Υۥȡ桼̾ӥѥɤåMySQL СδͤͿ줿ˤ餬뤳ȤΤ٤Ǥ';
-$strAction = '¹';
-$strAddAutoIncrement = 'AUTO_INCREMENTͤɲ';
-$strAddConstraints = 'ɲ';
+$strAction = '¹Ԥ';
+$strAddAutoIncrement = 'AUTO_INCREMENTͤɲä';
+$strAddConstraints = 'ɲä';
 $strAddDeleteColumn = 'եΡɲ/';
 $strAddDeleteRow = 'ԤΡɲ/';
-$strAddDropDatabase = 'DROP DATABASEפɲ';
-$strAddFields = '%s ĤΥեɤɲ';
+$strAddDropDatabase = 'DROP DATABASEפɲä';
+$strAddFields = '%s ĤΥեɤɲä';
 $strAddHeaderComment = 'إåإॳȤɲ (\\n ǲ)';
-$strAddIfNotExists = 'IF NOT EXISTSפɲ';
-$strAddIntoComments = 'ɲ';
-$strAddNewField = 'եɤɲ';
-$strAddPrivilegesOnDb = 'ǡ١øɲ';
-$strAddPrivilegesOnTbl = 'ơ֥øɲ';
+$strAddIfNotExists = 'IF NOT EXISTSפɲä';
+$strAddIntoComments = 'ɲä';
+$strAddNewField = 'եɤɲä';
+$strAddPrivilegesOnDb = 'ǡ١øɲä';
+$strAddPrivilegesOnTbl = 'ơ֥øɲä';
 $strAddSearchConditions = 'ʸɲäƤ("where"ʸ):';
 $strAddToIndex = ' &nbsp;%s&nbsp; 򥤥ǥåɲäޤ';
-$strAddUser = '桼ɲ';
+$strAddUser = '桼ɲä';
 $strAddUserMessage = '桼ɲäޤ';
 $strAddedColumnComment = 'Υɲäޤ';
 $strAddedColumnRelation = 'Υ졼ɲäޤ';
@@ -50,14 +51,14 @@ $strAdministration = '';
 $strAffectedRows = 'ƶ줿Կ:';
 $strAfter = 'ꥫθ %s';
 $strAfterInsertBack = '';
-$strAfterInsertNewInsert = '쥳ɤɲ';
+$strAfterInsertNewInsert = '쥳ɤɲä';
 $strAfterInsertNext = 'ιԤԽ';
 $strAfterInsertSame = 'Υڡ';
 $strAll = '';
 $strAllTableSameWidth = 'ƤΥơ֥Ʊɽޤ?';
 $strAlterOrderBy = 'ơ֥֤ξ';
 $strAnIndex = 'ǥå%sɲäƤޤ';
-$strAnalyzeTable = 'ơ֥ʬϤޤ';
+$strAnalyzeTable = 'ơ֥ʬϤ';
 $strAnd = 'AND';
 $strAny = '';
 $strAnyHost = 'ƤΥۥ';
@@ -69,7 +70,7 @@ $strAscending = '';
 $strAtBeginningOfTable = 'ơ֥Ƭ';
 $strAtEndOfTable = 'ơ֥';
 $strAttr = 'ɽ';
-$strAutodetect = 'ư';
+$strAutodetect = 'ưΤ';
 $strAutomaticLayout = 'ư쥤';
 
 $strBack = '';
@@ -79,31 +80,39 @@ $strBeginRaw = 'RAW ';
 $strBinLogEventType = '٥ȥ';
 $strBinLogInfo = '';
 $strBinLogName = '̾';
+$strBinLogOriginalPosition = 'ΰ';
 $strBinLogPosition = '';
 $strBinLogServerId = 'С ID';
 $strBinary = ' Хʥ ';
-$strBinaryDoNotEdit = ' Хʥ - ޤ';
+$strBinaryDoNotEdit = ' Хʥ - Ǥޤ';
 $strBinaryLog = 'Хʥ';
-$strBookmarkAllUsers = '٤ƤΥ桼Υ֥åޡ򥢥';
+$strBookmarkAllUsers = '٤ƤΥ桼Υ֥åޡ򥢥Ǥ';
 $strBookmarkDeleted = '֥åޡ˺ޤ';
 $strBookmarkLabel = '٥';
 $strBookmarkOptions = '֥åޡץ';
-$strBookmarkQuery = '֥åޡƤ SQL ꡼';
-$strBookmarkThis = 'SQL ꡼֥åޡ';
+$strBookmarkQuery = '֥åޡƤ SQL Ȳ';
+$strBookmarkThis = 'SQL Ȳ֥åޡ';
 $strBookmarkView = 'ɽΤ';
 $strBrowse = 'ɽ';
 $strBrowseForeignValues = 'ɽ';
+$strBufferPool = 'Хåեס';
+$strBufferPoolUsage = 'Хåեסλ';
+$strBufferReadMisses = 'ɤ߹ߥߥ';
+$strBufferReadMissesInPercent = '% ɤ߹ߥߥ';
+$strBufferWriteWaits = '񤭹Ԥ';
+$strBufferWriteWaitsInPercent = '% ν񤭹Ԥ';
 $strBulgarian = '֥륬ꥢ';
-$strBzError = ' php С Bz2 ĥƤΤ phpMyAdmin ̥׽ޤphpMyAdmin Υե졼ե <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ꤷƲBz2 ̵ǽȤˤ php ΥС夲Ʋphp Х %s ܺ١';
+$strBusyPages = 'ӥʥڡ';
+$strBzError = ' php С Bz2 ĥƤΤ phpMyAdmin ̥פǤޤphpMyAdmin Υե졼ե <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ꤷƤBz2 ̵ǽȤˤ php ΥС夲Ʋphp Х %s ܺ١';
 $strBzip = '"bzip "';
 
 $strCSVOptions = 'CSV ץ';
 $strCalendar = '';
-$strCannotLogin = 'MySQL С˥ޤ';
+$strCannotLogin = 'MySQL С˥Ǥޤ';
 $strCantLoad = 'ʤĥҤΥեǤ,<br />PHP åƤ';
-$strCantLoadRecodeIconv = 'ʸåѴԤˤȤ߹ޤƤʤ iconv ޤ GNU recode γĥɬפǤphp ˡγĥԤäƤphpMyAdminǤʸåѴ򤷤ʤˤƲ';
+$strCantLoadRecodeIconv = 'ʸåѴԤˤȤ߹ޤƤʤ iconv ޤ GNU recode γĥɬפǤphp ˡγĥԤäƤphpMyAdminǤʸåѴ򤷤ʤˤƤ';
 $strCantRenameIdxToPrimary = 'ǥå̾ PRIMARY ѹǤޤ';
-$strCantUseRecodeIconv = 'iconvlibiconvrecode_string Τɤδؿѽޤphp åƤ';
+$strCantUseRecodeIconv = 'iconvlibiconvrecode_string ΤɤδؿѤǤޤphp åƤ';
 $strCardinality = 'ǥʥƥ';
 $strCarriage = 'å꥿: \\r';
 $strCaseInsensitive = 'ѻ羮̤ʤ';
@@ -117,17 +126,17 @@ $strChangeCopyModeJustDelete = ' ... 桼ơ֥뤫ŤΤ';
 $strChangeCopyModeRevoke = ' ... ŤΤͭø򤹤٤̵ˤǺ';
 $strChangeCopyUser = 'ѹ / 桼ԡ';
 $strChangeDisplay = 'ɽեɤǲ';
-$strChangePassword = 'ѥɤѹ';
+$strChangePassword = 'ѥɤѹ򤹤';
 $strCharset = 'ʸå';
 $strCharsetOfFile = 'եʸå:';
 $strCharsets = 'ʸ';
 $strCharsetsAndCollations = 'ʸåȤȾȲ';
 $strCheckAll = 'Ƥޡ';
-$strCheckOverhead = 'Сإåɸ';
-$strCheckPrivs = 'øΥå';
+$strCheckOverhead = 'Сإåɤθ򤹤';
+$strCheckPrivs = 'øΥå򤹤';
 $strCheckPrivsLong = 'ǡ١ &quot;%s&quot; øå';
-$strCheckTable = 'ơ֥åޤ';
-$strChoosePage = 'Խڡ򤷤Ʋ';
+$strCheckTable = 'ơ֥å';
+$strChoosePage = 'Խڡ򤷤Ƥ';
 $strColComFeat = '󥳥ɽǽ';
 $strCollation = 'Ȳ';
 $strColumnNames = '()̾';
@@ -138,26 +147,28 @@ $strCommentsForTable = 'COMMENTS FOR TABLE';
 $strCompatibleHashing = 'MySQL&nbsp;4.0 ߴ';
 $strCompleteInserts = ' INSERT ʸ';
 $strCompression = '';
-$strConfigFileError = 'phpMyAdmin ե졼եɤ߹ळȤޤ! <br />ʸˡ顼ե뤬Ĥޤ<br />Υ󥯤饳ե졼եľɤ߹ǡphp Υ顼åǧƲ ξ硢ڤʸ䥻ߥ˺Ƥޤ<br />⤷Υڡ줿ƤޤԤäƤޤ';
-$strConfigureTableCoord = '%s ơ֥ΥǥʥƥꤷƲ';
+$strConfigFileError = 'phpMyAdmin ե졼եɤ߹ळȤǤޤ! <br />ʸˡ顼ե뤬Ĥޤ<br />Υ󥯤饳ե졼եľɤ߹ǡphp Υ顼åǧƤ ξ硢ڤʸ䥻ߥ˺Ƥޤ<br />⤷Υڡ줿ƤޤԤäƤޤ';
+$strConfigureTableCoord = '%s ơ֥ΥǥʥƥꤷƤ';
 $strConnectionError = '³Ǥޤ: ̵Ǥ';
 $strConnections = '³';
 $strConstraintsForDumped = '׺Ѥߥơ֥';
 $strConstraintsForTable = 'ơ֥';
 $strCookiesRequired = 'ϥåĤƤɬפޤ';
+$strCopy = 'ԡ';
 $strCopyDatabaseOK = 'ǡ١ %s  %s ˥ԡޤ';
 $strCopyTable = 'ơ֥(database<b>.</b>table)˥ԡ:';
 $strCopyTableOK = '%s ơ֥ %s ˥ԡޤ';
 $strCopyTableSameNames = 'Ʊơ֥˥ԡǤޤ!';
-$strCouldNotKill = 'phpMyAdminå%sλ뤳ȤޤǤ¿ʬ˽λƤޤ';
+$strCouldNotKill = 'phpMyAdminå%sλ뤳ȤǤޤǤ¿ʬ˽λƤޤ';
 $strCreate = '';
-$strCreateIndex = '&nbsp;%s&nbsp; Υǥåκ';
-$strCreateIndexTopic = 'ǥåκ';
-$strCreateNewDatabase = 'DBޤ';
-$strCreateNewTable = 'ߤDB˿ơ֥ %s --> ';
-$strCreatePage = 'ڡκ';
+$strCreateDatabaseBeforeCopying = 'ԡ CREATE DATABASE ';
+$strCreateIndex = '&nbsp;%s&nbsp; Υǥå';
+$strCreateIndexTopic = 'ǥå';
+$strCreateNewDatabase = ' DB ޤ';
+$strCreateNewTable = 'ߤ DB ˿ơ֥ %s --> ';
+$strCreatePage = 'ڡ';
 $strCreatePdfFeat = 'PDF ǽ';
-$strCreationDates = '//դɲ';
+$strCreationDates = '//դɲä';
 $strCriteria = 'ʹߴ';
 $strCroatian = '';
 $strCyrillic = 'ʸ';
@@ -181,6 +192,7 @@ $strDanish = 'ǥޡ';
 $strData = 'ǡ';
 $strDataDict = 'ǡ';
 $strDataOnly = 'ǡΤ';
+$strDataPages = 'ǡޤڡ';
 $strDatabase = 'ǡ١';
 $strDatabaseEmpty = 'ǡ١̾Ǥ!';
 $strDatabaseExportOptions = 'ǡ١ݡȥץ';
@@ -189,12 +201,13 @@ $strDatabaseNoTable = 'Υǡ١ϥơ֥ޤǤޤ!';
 $strDatabases = 'ǡ١';
 $strDatabasesDropped = '%s ǡ١Ϻޤ';
 $strDatabasesStats = 'ǡ١';
-$strDatabasesStatsDisable = 'פ̵';
-$strDatabasesStatsEnable = 'פ';
+$strDatabasesStatsDisable = 'פ̵ˤ';
+$strDatabasesStatsEnable = 'פĤ';
 $strDatabasesStatsHeavyTraffic = ': ǡ١פĤ MySQL  WEBСδ֤ǽŤȥեåȯ뤫⤷ޤ';
 $strDbPrivileges = 'ǡ١ ø';
 $strDbSpecific = 'ǡ١';
 $strDefault = '';
+$strDefaultEngine = '%s ϡ MySQL СΥǥեȥȥ졼󥸥Ǥ';
 $strDefaultValueHelp = 'ǥեͤΤˡХåå奨פʤ 1 ĤͤƲ, ΥեޥåȤ: a';
 $strDefragment = 'ơ֥Υǥե饰';
 $strDelOld = 'ߤΥڡϡϤ¸ߤʤơ֥˻ȤޤλȤǤ?';
@@ -204,15 +217,16 @@ $strDeleteAndFlush = '桼øɤ';
 $strDeleteAndFlushDescr = 'ϥꥢǤøɤΤǾ֤ޤ';
 $strDeleted = '򤷤ޤ';
 $strDeletedRows = '줿Կ:';
-$strDeleting = '%s ';
+$strDeleting = '%s Ǥ';
 $strDescending = '߽';
 $strDescription = '';
 $strDictionary = '';
-$strDisableForeignChecks = 'θ̵';
+$strDirtyPages = 'ʥڡ';
+$strDisableForeignChecks = 'θ̵ˤ';
 $strDisabled = '̵';
 $strDisplayFeat = 'ơ֥ɽǽ';
 $strDisplayOrder = 'ɽ:';
-$strDisplayPDF = 'PDF ޤɽ';
+$strDisplayPDF = 'PDF ޤɽ򤹤';
 $strDoAQuery = '"QUERY"¹ (磻ɥ: "%")';
 $strDoYouReally = '˼¹ԤƤɤǤ --> ';
 $strDocu = 'إ';
@@ -236,6 +250,10 @@ $strEncto = '󥳡ǥ󥰤Ѵ'; // encoding convert
 $strEnd = 'Ǹ';
 $strEndCut = 'ڤ꽪λ';
 $strEndRaw = 'RAW λ';
+$strEngineAvailable = '%s ϡ MySQL СѲǽǤ';
+$strEngineDisabled = '%s ϡ MySQL СǤ̵ˤƤޤ';
+$strEngineUnsupported = ' MySQL С %s ȥ졼󥸥򥵥ݡȤƤޤ';
+$strEngines = '󥸥';
 $strEnglish = 'Ѹ';
 $strEnglishPrivileges = ' : MySQLø̾ϱѸɽƤޤ';
 $strError = '顼';
@@ -244,11 +262,11 @@ $strEscapeWildcards = '磻ɥɡ_פȡ%פϡʸ̤˻Ѥ뤿ˡ\פǲ򤹤ɬפޤ';
 $strEstonian = 'ȥ˥';
 $strExcelEdition = 'Excel μ';
 $strExcelOptions = 'Excel ץ';
-$strExecuteBookmarked = '֥åޡ줿꡼¹';
+$strExecuteBookmarked = '֥åޡ줿Ȳ¹Ԥ';
 $strExplain = 'Explain SQL';
 $strExport = 'ݡ';
 $strExtendedInserts = 'Ĺ INSERT ʸ';
-$strExtra = 'ɲ';
+$strExtra = 'ɲä';
 
 $strFailedAttempts = 'Ԥޤ';
 $strField = 'ե';
@@ -260,7 +278,7 @@ $strFieldsEscapedBy = 'եɤΥ׵';
 $strFieldsTerminatedBy = 'եɶڤ국';
 $strFileAlreadyExists = 'ե %s ϴ˥С¸ߤޤե̾ѹ뤫񤭥ץǧƤ';
 $strFileCouldNotBeRead = 'եɤޤ';
-$strFileNameTemplate = 'ե̾ƥץ졼';
+$strFileNameTemplate = 'ե̾Υƥץ졼';
 $strFileNameTemplateHelp = '__DB__ ǡ١̾ˡ__TABLE__ ơ֥̾ˡ%sǤդ strftime ؿ%s ץֻͤˡĥȤƼưŪɲäǤ礦¾ΥƥȤ¸Ǥ礦';
 $strFileNameTemplateRemember = 'ƥץ졼ȤФ';
 $strFixed = '';
@@ -268,22 +286,29 @@ $strFlushPrivilegesNote = ': phpMyAdmin  MySQL øơ֥뤫ľܤ˥桼øޤ⤷ޥ˥奢
 $strFlushTable = 'ơ֥Υåˤ("FLUSH")';
 $strFormEmpty = 'եǤͤޤǤ';
 $strFormat = 'եޥå';
+$strFreePages = 'ե꡼ʥڡ';
 $strFullText = 'ʸ';
 $strFunction = 'ؿ';
 
 $strGenBy = '줿 by';
 $strGenTime = 'λ';
 $strGeneralRelationFeat = '졼ǽ';
+$strGenerate = '';
+$strGeneratePassword = 'ѥɤ';
 $strGeorgian = '른';
 $strGerman = 'ɥĸ';
 $strGlobal = 'Х';
 $strGlobalPrivileges = 'Хø';
 $strGlobalValue = 'Х';
-$strGo = '¹';
+$strGo = '¹Ԥ';
 $strGrantOption = '°Ѿ';
 $strGreek = 'ꥷ';
 $strGzip = '"gzip "';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Microsoft Excel 2000 ݡȥץ';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Microsoft Word 2000 ݡȥץ';
 $strHasBeenAltered = 'ѹޤ';
 $strHasBeenCreated = 'ޤ';
 $strHaveToShow = 'ɽ뤿ˡʤƤҤȤĤΥ򤷤ʤФʤޤ';
@@ -298,7 +323,7 @@ $strHungarian = 'ϥ󥬥꡼';
 $strIcelandic = 'ɸ';
 $strId = 'ID';
 $strIdxFulltext = 'ʸ';
-$strIfYouWish = 'ơ֥Υ()˥ǡɲäϡեɥꥹȤ򥫥ޤǶʬƤ';
+$strIfYouWish = 'ơ֥()˥ǡɲäϡեɰ򥫥ޤǶڤäƤ';
 $strIgnore = '̵';
 $strIgnoreInserts = 'INSERT IGNOREפѤ';
 $strIgnoringFile = 'ե̵ %s';
@@ -316,13 +341,21 @@ $strIndexWarningTable = 'ơ֥ `%s` Υǥå˴ؤ';
 $strIndexWarningTable = 'ơ֥ `%s` Υǥå˴ؤǤ';
 $strIndexWarningUnique = 'UNIQUE  INDEX ΥξȤ⡢ `%s` ꤵ٤ǤϤޤ';
 $strIndexes = 'ǥå';
+$strInnoDBAutoextendIncrement = 'ưĥɲ';
+$strInnoDBAutoextendIncrementDesc = ' 줬äѤˤʤˡưĥơ֥륹ڡΥĥ뤿ʬ̤Ǥ';
+$strInnoDBBufferPoolSize = 'Хåեѥ';
+$strInnoDBBufferPoolSizeDesc = 'InnoDB åǡȤΥơ֥Υǥå˻ȤХåեΥǤ';
+$strInnoDBDataFilePath = 'ǡե';
+$strInnoDBDataHomeDir = 'ǡۡǥ쥯ȥ';
+$strInnoDBDataHomeDirDesc = '٤Ƥ InnoDB ǡեѤΥǥ쥯ȥѥζʬǤ';
+$strInnoDBPages = 'ڡ';
 $strInnodbStat = 'InnoDB ơ';
-$strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL С⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƲ';
+$strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL С⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƤ';
 $strInsert = 'ɲ';
-$strInsertAsNewRow = 'ԤȤƤɲ';
+$strInsertAsNewRow = 'ԤȤɲä';
 $strInsertBookmarkTitle = '֥åޡΥȥϤƤ';
-$strInsertNewRow = 'Ԥɲ';
-$strInsertTextfiles = 'ơ֥˥ƥȥեɲ';
+$strInsertNewRow = 'Ԥɲä';
+$strInsertTextfiles = 'ơ֥˥ƥȥեɲä';
 $strInsertedRowId = '󥵡Ȥ ID:';
 $strInsertedRows = 'ɲä줿Կ:';
 $strInstructions = '»';
@@ -358,7 +391,7 @@ $strLinesTerminatedBy = 'Ԥνü';
 $strLinkNotFound = '󥯤Ĥޤ';
 $strLinksTo = '';
 $strLithuanian = 'ȥ˥';
-$strLoadExplanation = 'ɤμʤϥǥեȤåƤޤ줬Ԥ硢ѹ뤳Ȥޤ';
+$strLoadExplanation = 'ɤμʤϥǥեȤåƤޤ줬Ԥ硢ѹ뤳ȤǤޤ';
 $strLoadMethod = 'LOAD ';
 $strLocalhost = '';
 $strLocationTextfile = 'ƥȥեξ';
@@ -368,6 +401,7 @@ $strLogUsername = '桼̾:';
 $strLogin = '';
 $strLoginInformation = '';
 $strLogout = '';
+$strLongOperation = 'ϻ֤ޤǤʤߤޤ?';
 
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';
 $strMIME_MIMEtype = 'MIME ';
@@ -375,6 +409,7 @@ $strMIME_available_mime = 'ͭ MIME ';
 $strMIME_available_transform = 'Ѵͭ';
 $strMIME_description = '';
 $strMIME_transformation = '֥饦Ѵ';
+$strMIME_transformation_note = 'ѲǽѴץΰӤ MIME Ѵ˴ؤƤϡ%sѴ%s 򥯥åƤ';
 $strMIME_transformation_options = 'Ѵץ';
 $strMIME_without = 'åΤǰ줿MIME פϸ̤ѴؿäƤޤ';
 $strMaximumSize = '祵: %s%s';
@@ -389,6 +424,16 @@ $strMoveTableOK = 'ơ֥ %s  %s ưޤ';
 $strMoveTableSameNames = 'Ʊơ֥˰ưǤޤ!';
 $strMultilingual = '¿';
 $strMustSelectFile = '󥵡Ȥե򤹤٤Ǥ';
+$strMyISAMDataPointerSize = 'ǡݥ󥿡';
+$strMyISAMMaxExtraSortFileSize = 'ǥåѰեκ祵';
+$strMyISAMMaxSortFileSize = 'ȥեκ祵';
+$strMyISAMMaxSortFileSizeDesc = 'MyISAM ǥåκƺǻѤ뤳Ȥ줿 MySQL եκ祵Ǥ (REPAIR TABLE 桢ALTER TABLE  LOAD DATA INFILE)';
+$strMyISAMRecoverOptions = 'ư⡼';
+$strMyISAMRecoverOptionsDesc = 'å夷 MyISAM ơ֥μưѥ⡼ɤǡСưץ --myisam-recover ꤷޤ';
+$strMyISAMRepairThreads = 'ڥå';
+$strMyISAMRepairThreadsDesc = '⤷ͤ 1 ʾʤ顢MyISAM ơ֥ΥǥåϥȽνʿԤ(켫Ȥγƥǥå)ޤ';
+$strMyISAMSortBufferSize = 'ȥХåե';
+$strMyISAMSortBufferSizeDesc = 'ΥХåեϡREPAIR TABLE δ֤ MyISAM ǥå򥽡Ȥ硢ޤ CREATE INDEX  ALTER TABLE ȥǥåˡդޤ';
 $strMySQLCharset = 'MySQLʸå';
 $strMySQLConnectionCollation = 'MySQL ³Ȳ';
 $strMySQLReloaded = 'MySQL򿷤ɤ߹ߤޤ';
@@ -406,6 +451,7 @@ $strNoActivity = '%s ðʾ򤷤Ƥޤ󡣺٥򤷤Ƥ';
 $strNoDatabases = 'ǡ١';
 $strNoDatabasesSelected = 'ǡ١򤵤Ƥޤ';
 $strNoDescription = 'Ҥޤ';
+$strNoDetailsForEngine = 'Υȥ졼󥸥ˤͭʥơξܺپϤޤ';
 $strNoDropDatabases = '"DROP DATABASE"ơȥȤ϶ػߤ';
 $strNoExplain = 'Explain SQL 򥹥å';
 $strNoFrames = 'phpMyAdmin <b>ե졼</b>򥵥ݡȤ֥饦ǤѤ򤪴ᤷޤ';
@@ -417,7 +463,7 @@ $strNoPassword = 'ѥ̵';
 $strNoPermission = 'ե %s ¸ѡߥå򥦥֥СϻäƤޤ';
 $strNoPhp = 'PHP ̵';
 $strNoPrivileges = 'ø̵';
-$strNoQuery = 'SQL ꡼̵';
+$strNoQuery = 'SQL Ȳ̵';
 $strNoRights = 'øäƤʤΤǤޤ';
 $strNoRowsSelected = 'Ԥ򤵤ޤǤ';
 $strNoSpace = 'ե %s ¸ˤ϶̤ԽʬǤ';
@@ -426,7 +472,7 @@ $strNoThemeSupport = 'ơޤ򥵥ݡȤƤޤȥơޥǥ쥯ȥ %s ǧƤ';
 $strNoUsersFound = '桼ϸĤޤǤ';
 $strNoValidateSQL = 'SQL ڤ򥹥å';
 $strNone = '̵';
-$strNotNumber = 'ֹǤϤޤ';
+$strNotNumber = 'ϿͤǤϤޤ';
 $strNotOK = 'OK ǤϤޤ';
 $strNotSet = '<b>%s</b> ơ֥뤬Ĥʤ%s ޤ';
 $strNotValidNumber = ' ϹԤֹǤϤޤ ';
@@ -438,21 +484,24 @@ $strNumTables = 'ơ֥';
 $strOK = 'OK';
 $strOftenQuotation = 'Ǥץϡchar ޤ varchar եɤΤ" "ǰϤޤƤ뤳Ȥ̣ޤ';
 $strOperations = '';
-$strOptimizeTable = 'ơ֥Ŭޤ';
+$strOperator = '';
+$strOptimizeTable = 'ơ֥Ŭ';
 $strOptionalControls = 'üʸɤ߹/񤭹ߥץ';
-$strOptionally = 'ץǤ';
-$strOr = 'OR';
+$strOptionally = 'ץ';
+$strOr = 'ޤ';
 $strOverhead = 'Сإå';
 $strOverwriteExisting = 'ե뤬¸ߤϾ';
 
 $strPHP40203 = 'ʤϥޥХʸ(mbstring)ΰ˽ʥХΤ PHP 4.2.3 ȤäƤޤPHP ΥХݡ 19404 ǤphpMyAdmin Ȥʤ顢ΥС PHP Ϥᤷޤ...ȸ patch 򤢤Ƥʤưޤ';
 $strPHPVersion = 'PHP С';
 $strPageNumber = 'ڡֹ:';
+$strPagesToBeFlushed = 'եå夵줿ڡ';
 $strPaperSize = '極';
 $strPartialText = 'ʬŪʸ';
 $strPassword = 'ѥ';
 $strPasswordChanged = 'ѥɤ %s ѹޤ';
 $strPasswordEmpty = 'ѥɤǤ';
+$strPasswordHashing = 'ѥɥϥå';
 $strPasswordNotSame = 'ѥɤƱǤϤޤ';
 $strPdfDbSchema = '"%s" ǡ١ - %s Ǥο';
 $strPdfInvalidTblName = '"%s" ơ֥뤬ޤ!';
@@ -464,7 +513,7 @@ $strPersian = 'ڥ륷';
 $strPhoneBook = 'Ģ';
 $strPhp = 'PHP ɤκ';
 $strPmaDocumentation = 'phpMyAdmin Υɥ';
-$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> ɬ config եꤷƲ!';
+$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> ɬ config եꤷƤ!';
 $strPolish = 'ݡɸ';
 $strPortrait = 'ݡȥ쥤';
 $strPos1 = 'ǽ';
@@ -474,35 +523,42 @@ $strPrimaryKeyHasBeenDropped = '祭ޤ';
 $strPrimaryKeyName = '祭̾... PRIMARY ǤϤʤФޤ';
 $strPrimaryKeyWarning = '("PRIMARY"Ϥ礦ɼ祭̾ǤϤʤФޤ';
 $strPrint = '';
-$strPrintView = 'ɽ';
-$strPrintViewFull = 'ӥ塼 (ƥȹ)';
+$strPrintView = 'Ѥɽ';
+$strPrintViewFull = 'ӥ塼 (ƥȤޤ)';
 $strPrivDescAllPrivileges = 'GRANT Ƥøޤߤޤ';
 $strPrivDescAlter = '¸ߤơ֥빽¤ѹĤޤ';
+$strPrivDescAlterDb = 'ǡ١ΥǥեʸɤӾȹѹ뤳ȤƱͤ˴¸Υơ֥ι¤ѹ뤳ȤĤˤޤ';
+$strPrivDescAlterRoutine = 'ȥɥ롼ѹ˴Ĥޤ';
 $strPrivDescCreateDb = 'ǡ١ơ֥κĤޤ';
+$strPrivDescCreateRoutine = 'ȥɥ롼κĤޤ';
 $strPrivDescCreateTbl = 'ơ֥κĤޤ';
 $strPrivDescCreateTmpTable = 'ƥݥ꡼ơ֥κĤޤ';
+$strPrivDescCreateUser = '桼Ȥκ˴̾ѹĤޤ';
+$strPrivDescCreateView = 'ӥ塼κĤޤ';
 $strPrivDescDelete = 'ǡκĤޤ';
 $strPrivDescDropDb = 'ǡ١ȥơ֥κĤޤ';
 $strPrivDescDropTbl = 'ơ֥κĤޤ';
 $strPrivDescExecute = 'ȥɥץ㡼ΤĤޤ; MySQLǤǤϰ̣ޤ';
+$strPrivDescExecute5 = 'ȥɥ롼μ¹ԤĤޤ';
 $strPrivDescFile = 'ǡΥݡȡǡΥեؤΥݡȤĤޤ';
 $strPrivDescGrant = 'øơ֥Υɤʤ˥桼øɲäĤޤ';
 $strPrivDescIndex = 'ǥåκĤޤ';
 $strPrivDescInsert = 'ǡؤĤޤ';
 $strPrivDescLockTables = 'ߤΥåɤΥå󥰥ơ֥Ĥޤ';
 $strPrivDescMaxConnections = '1 ˿³ǽʿ¤ޤ';
-$strPrivDescMaxQuestions = '1 ˥С˥¤ޤ';
+$strPrivDescMaxQuestions = '1 ˥С˾Ȳ¤ޤ';
 $strPrivDescMaxUpdates = '1 ˥ơ֥롢ǡ١ФƤѹȯ륳ޥɤο¤ޤ';
-$strPrivDescProcess3 = '¾Υ桼ץ߽뤳ȤĤޤ';
-$strPrivDescProcess4 = 'ץꥹδʥɽĤޤ';
+$strPrivDescProcess3 = '¾Υ桼ץߤǤ뤳ȤĤޤ';
+$strPrivDescProcess4 = 'ץꥹδʾȲɽĤޤ';
 $strPrivDescReferences = ' MySQL СǤϰ̣ޤ';
 $strPrivDescReload = 'СΥɡåΥꥢĤޤ';
-$strPrivDescReplClient = '졼֤ޥ׵븢桼Ϳޤ';
+$strPrivDescReplClient = '졼֤ޥ׵Ǥ븢桼Ϳޤ';
 $strPrivDescReplSlave = 'ץꥱ󥹥졼֤ɬפǤ';
 $strPrivDescSelect = 'ǡɤ߽Ф';
 $strPrivDescShowDb = 'ǡ١δʥꥹȤؤΥͿޤ';
+$strPrivDescShowView = 'Ȳ SHOW CREATE VIEW μ¹ԤĤޤ';
 $strPrivDescShutdown = 'СΥåȥĤޤ';
-$strPrivDescSuper = '³ãƤ³Ĥޤ¿δϥХѿ¾桼ץνλ褦꤬ɬפǤ';
+$strPrivDescSuper = '³ãƤ³Ĥޤ¿δϥХѿ¾桼ץνλǤ褦꤬ɬפǤ';
 $strPrivDescUpdate = 'ǡνĤޤ';
 $strPrivDescUsage = 'øޤ';
 $strPrivileges = 'ø';
@@ -510,55 +566,58 @@ $strPrivilegesReloaded = 'øϥɤޤ';
 $strProcesslist = 'ץꥹ';
 $strPutColNames = 'ǽ 1 ܤ˥ե̾ɲä';
 
-$strQBE = '꡼';
+$strQBE = 'Ȳ';
 $strQBEDel = '';
 $strQBEIns = '';
-$strQueryFrame = '꡼ɥ';
-$strQueryOnDb = 'ǡ١ SQL ꡼ <b>%s</b>:';
+$strQueryFrame = 'Ȳ񥦥ɥ';
+$strQueryOnDb = 'ǡ١ SQL Ȳ <b>%s</b>:';
 $strQuerySQLHistory = 'SQL ';
-$strQueryStatistics = '<b>꡼</b>: ư %s ꡼СƤޤ';
-$strQueryTime = '꡼¹ %01.4f ';
-$strQueryType = '꡼';
-$strQueryWindowLock = 'ɥγ餳Υ꡼񤭴ޤ';
+$strQueryStatistics = '<b>Ȳ</b>: ư %s Ȳ񤬥СƤޤ';
+$strQueryTime = 'Ȳμ¹Ի %01.4f ';
+$strQueryType = 'Ȳ񥿥';
+$strQueryWindowLock = 'ɥγ餳ξȲ񤭴Ǥޤ';
 
 $strReType = 'Ƶ';
+$strReadRequests = 'ɤ߹ߥꥯȿ';
 $strReceived = '';
 $strRecords = '쥳ɿ';
 $strReferentialIntegrity = 'ܤΥå:';
 $strRefresh = '';
-$strRelationNotWorking = '졼ǽưΥ󥯥ơ֥뤬ͭˤʤäƤޤ %s%s򥯥åƸ򸫤ĤƲ';
+$strRelationNotWorking = 'phpMyAdmin ȼǽǤ졼ǽ뤿Υ󥯥ơ֥뤬ͭˤʤäƤޤ󡣤褹ˤ %s%s 򥯥åƸ򸫤ĤƤ';
 $strRelationView = '졼ɽ';
 $strRelationalSchema = '졼ʥ륹';
 $strRelations = '졼';
 $strRelationsForTable = 'RELATIONS FOR TABLE';
 $strReloadFailed = 'MySQL Υɤ˼Ԥޤ';
 $strReloadMySQL = 'MySQL Υ';
-$strReloadingThePrivileges = 'ø';
+$strReloadingThePrivileges = 'øǤ';
 $strRemoveSelectedUsers = '򤵤줿桼ޤ';
 $strRenameDatabaseOK = 'ǡ١ %s  %s ̾ѹޤ';
 $strRenameTable = 'ơ֥̾ѹ';
 $strRenameTableOK = '%s  %s ̾ѹޤ';
-$strRepairTable = 'ơ֥줷ޤ';
+$strRepairTable = 'ơ֥줹';
 $strReplace = '֤';
 $strReplaceNULLBy = 'NULL ʸ֤';
 $strReplaceTable = 'եǥơ֥֤';
 $strReset = 'ꥻå';
-$strResourceLimits = '    ꥽';
+$strResourceLimits = '꥽';
 $strRevoke = 'ѻ';
 $strRevokeAndDelete = '桼ͭø˴ƺ';
-$strRevokeAndDeleteDescr = '桼øɤޤUSAGEøΤޤޤǤ';
-$strRevokeMessage = '%søäޤ';
+$strRevokeAndDeleteDescr = '桼øɤޤ USAGE øΤޤޤǤ';
+$strRevokeMessage = '%s øäޤ';
 $strRomanian = '롼ޥ˥';
+$strRoutines = '롼';
 $strRowLength = 'ԤĹ';
 $strRowSize = ' ԤΥ ';
 $strRows = '';
 $strRowsFrom = 'Ϲ';
+$strRowsModeFlippedHorizontal = 'ʿ (žإå)';
 $strRowsModeHorizontal = 'ʿ';
 $strRowsModeOptions = ': %s : %s 󤺤ĥإå򷫤֤ɽ';
 $strRowsModeVertical = 'ľ';
 $strRowsStatistic = 'Ԥ';
-$strRunQuery = '꡼μ¹';
-$strRunSQLQuery = 'ǡ١ %s SQL ꡼¹';
+$strRunQuery = 'Ȳμ¹Ԥ';
+$strRunSQLQuery = 'ǡ١ %s SQL Ȳ¹Ԥ';
 $strRunning = '¹Ǥ %s';
 $strRussian = '';
 
@@ -566,9 +625,9 @@ $strSQL = 'SQL';
 $strSQLExportCompatibility = 'SQL ݡȸߴ';
 $strSQLExportType = 'ݡȷ';
 $strSQLOptions = 'SQL ץ';
-$strSQLParserBugMessage = 'ʤ SQL ѡǥХ򸫤Ĥ뤫⤷ޤ󡣤ʤΥ꡼ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤΥ꡼ MySQL Υޥɥ饤ȤäƻȤޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL ꡼ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
-$strSQLParserUserError = 'ʤ SQL ꡼˥顼ޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦';
-$strSQLQuery = '¹Ԥ줿 SQL ꡼';
+$strSQLParserBugMessage = 'ʤ SQL ѡΥХ򸫤뤫⤷ޤ󡣤ʤ䤤碌ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤ䤤碌 MySQL Υޥɥ饤ȤäƻȤǤޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL 䤤碌ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
+$strSQLParserUserError = 'ʤ SQL Ȳ˥顼ޤMySQL СϰʲΤ褦˥顼Фޤˤ褹Ǥ礦';
+$strSQLQuery = '¹Ԥ SQL Ȳ';
 $strSQLResult = 'SQL η';
 $strSQPBugInvalidIdentifer = 'ǧڤ̵Ǥ';
 $strSQPBugUnclosedQuote = '䤬ĤƤޤ';
@@ -577,7 +636,7 @@ $strSave = '¸';
 $strSaveOnServer = 'С %s ǥ쥯ȥ¸';
 $strScaleFactorSmall = '1 ڡ˿ɽ֤뤿ˤ礭᤮ޤ';
 $strSearch = '';
-$strSearchFormTitle = 'ǡ١θ';
+$strSearchFormTitle = 'ǡ١򸡺';
 $strSearchInTables = 'ơ֥λ:';
 $strSearchNeedle = 'ñ졢ޤ (磻ɥɤ: "%"):';
 $strSearchOption1 = '줫ñޤ';
@@ -591,13 +650,13 @@ $strSelectADb = 'ǡ١򤷤Ƥ';
 $strSelectAll = '';
 $strSelectBinaryLog = '򤷤Хʥ';
 $strSelectBinaryLog = '򤷤Хʥ';
-$strSelectFields = 'եɤ(İʾ):';
-$strSelectNumRows = '꡼';
+$strSelectFields = 'եɤ(1 İʾ):';
+$strSelectNumRows = 'Ȳ';
 $strSelectTables = 'ơ֥';
 $strSend = 'ե¸';
 $strSent = '';
 $strServer = 'С';
-$strServerChoice = 'С';
+$strServerChoice = 'С򤹤';
 $strServerNotResponding = 'Сȿޤ';
 $strServerStatus = '󥿥';
 $strServerStatusUptime = 'MySQLС %s ưǡ%s ˵ưƤޤ';
@@ -607,23 +666,24 @@ $strServerTrafficNotes = '<b>Сȥեå</b>: Υơ֥ MySQL СưƤΥͥåȥȥեå
 $strServerVars = 'Сѿ';
 $strServerVersion = 'СΥС';
 $strSessionValue = 'å';
-$strSetEnumVal = 'եɥפ"enum""set"ξͤ򤳤ΥեޥåȤȤäϤƲ: \'a\',\'b\',\'c\'...<br />Хåå"\"ϥȡ"\'"פϤȡƬ˥ХååդƲ: \'\\\\xyz\' or \'a\\\'b\'ס';
+$strSetEnumVal = 'եɥפ"enum""set"ξͤ򤳤ΥեޥåȤȤäϤƤ: \'a\',\'b\',\'c\'...<br />Хåå"\"ϥȡ"\'"פϤȡƬ˥ХååդƲ: \'\\\\xyz\' or \'a\\\'b\'ס';
 $strShow = 'ɽ';
 $strShowAll = 'ɽ';
 $strShowColor = 'ɽ';
 $strShowDatadictAs = 'ǡեޥå';
-$strShowFullQueries = 'ե륯꡼ɽ';
+$strShowFullQueries = 'եȲɽ';
 $strShowGrid = 'åɤɽ';
 $strShowPHPInfo = 'PHP ';
 $strShowTableDimension = 'ơ֥礭ɽ';
 $strShowTables = 'ơ֥ɽ';
-$strShowThisQuery = ' ¹Ԥ꡼򤳤ɽ';
-$strShowingRecords = '쥳ɽ';
+$strShowThisQuery = ' ¹ԤȲ򤳤ɽ';
+$strShowingRecords = '쥳ɤɽ';
 $strSimplifiedChinese = 'λ';
-$strSingly = '()';
+$strSingly = '(1 )';
 $strSize = '';
 $strSlovak = 'Х';
 $strSlovenian = '٥˥';
+$strSocketProblem = '(ޤϡ MySQL СΥåȤΤꤵޤ)';
 $strSort = '';
 $strSortByKey = 'ǥ';
 $strSpaceUsage = 'ǥ';
@@ -634,16 +694,18 @@ $strStatCreateTime = '';
 $strStatUpdateTime = 'ǽ';
 $strStatement = 'ơȥ';
 $strStatus = '';
+$strStorageEngine = 'ȥ졼󥸥';
+$strStorageEngines = 'ȥ졼󥸥';
 $strStrucCSV = 'CSV ǡ';
 $strStrucData = '¤ȥǡ';
-$strStrucDrop = 'DROP TABLEפɲ';
+$strStrucDrop = 'DROP TABLEפɲä';
 $strStrucExcelCSV = 'MS Excel  CSV ǡ';
 $strStrucNativeExcel = ' MS Excel ǡ';
 $strStrucOnly = '¤Τ';
 $strStructPropose = 'ơ֥빽¤γǧ';
 $strStructure = '¤';
-$strSubmit = '¹';
-$strSuccess = 'SQL ꡼˼¹Ԥޤ';
+$strSubmit = '¹Ԥ';
+$strSuccess = 'SQL Ȳ˼¹Ԥޤ';
 $strSum = '';
 $strSwedish = 'ǥ';
 $strSwitchToDatabase = 'ԡǡ١ڤؤ';
@@ -661,8 +723,9 @@ $strTableOptions = 'ơ֥륪ץ';
 $strTableStructure = 'ơ֥ι¤';
 $strTableType = 'ơ֥Υ';
 $strTables = '%sơ֥';
+$strTakeIt = 'ˤޤ';
 $strTblPrivileges = 'ơ֥ ø';
-$strTextAreaLength = ' Ĺν٤ǤΥեɤ<br /> ʤǽޤ';
+$strTextAreaLength = ' Ĺν٤ǤΥեɤ<br /> Ǥʤǽޤ';
 $strThai = '';
 $strTheContent = 'եΥǡޤ';
 $strTheContents = 'եΥǡǡ򤷤ơ֥μץޤͣʥ˰פ֤ޤ';
@@ -678,28 +741,35 @@ $strTotalUC = '';
 $strTraditionalChinese = 'Ū';
 $strTraditionalSpanish = 'Ūʥڥ';
 $strTraffic = 'ȥեå';
+$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤҤȤĤΥץϥХʥեΥե̾ǤդĤΥץϥե̾ޤơ֥Ԥե̾ǤդĤΥץ󶡤硢ҤȤĤΥץ϶ʸꤹɬפޤ';
 $strTransformation_image_jpeg__inline = 'åǽʥͥɽޤ; ץ: widthheight ԥǻ (Ψݤޤ)';
 $strTransformation_image_jpeg__link = 'βؤΥ󥯤ɽ (㤨 blob ľܥ).';
-$strTransformation_text_plain__substr = 'ʸΰΤɽޤܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0פǤ)ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...פǤ)';
-$strTransformation_text_plain__unformatted = 'HTML ɤ HTML ֤ȤɽޤHTML 񼰲ɽޤ';
+$strTransformation_image_png__inline = 'image/jpeg: inlineפ򻲾ȤƤ';
+$strTransformation_text_plain__dateformat = 'TIMETIMESTAMP뤤DATETIMEեɤǡɽѤƽ񼰲ޤ1 ܤΥץϥॹפ˲û륪եåȻ(ñ:)Ǥ(ǥե: 0)2 ܤΥץϡPHP  strftime()Ѳǽʥѥ᡼ǤΤޤޤɽǤ';
+$strTransformation_text_plain__external = 'LINUX Τ: ץꥱưɸϤեɥǡϤޤץꥱɸϤ֤ޤǥեȤ Tidy ǡ HTML ɤϤޤƥͳǡưǥեlibraries/text_plain__external.inc.phpפԽ¹ԤĤġʤФʤޤ󡣺ǽΥץϡѤץοǡ2 ܤΥץϥץΥѥ᡼Ǥ3 ܤΥץ 1 ꤵƤ硢htmlspecialchars() ѤƽϤѴǤ礦(ǥե: 1)4  ץ 1 ꤵƤ硢§ɤϤ٤ 1 Ԥ˸뤳ȤݾڤǤ礦(ǥե: 1).';
+$strTransformation_text_plain__formatted = 'եɤθν񼰤¸ޤפ˽λޤ';
+$strTransformation_text_plain__imagelink = 'ȥ󥯡ե̾ޤեɤɽޤ; ҤȤĤΥץ "http://domain.com/" Τ褦ƬǡդĤΥץϥԥߤäĤϹ⤵Ǥ';
+$strTransformation_text_plain__link = 'ե̾ޤեɡ󥯤ɽ; ҤȤܤΥץ "http://domain.com/" Τ褦Ƭ졢ܤΥץϥ󥯤ΥȥǤ';
+$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0פǤ)ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...פǤ)';
+$strTruncateQueries = 'Ȳɽڤͤ';
 $strTurkish = 'ȥ륳';
 $strType = 'եɥ';
 
 $strUkrainian = '饤ʸ';
 $strUncheckAll = 'ƤΥޡ';
 $strUnicode = '˥';
-$strUnique = 'ͣ';
+$strUnique = '';
 $strUnknown = '';
 $strUnselectAll = '';
 $strUpdComTab = 'Column_comments ơ֥Υåץ졼ˡΥɥȤ򻲾ȤƤ';
 $strUpdatePrivMessage = '%s ø򹹿ޤ';
 $strUpdateProfileMessage = 'ץե򹹿ޤ';
-$strUpdateQuery = '꡼ι';
+$strUpdateQuery = 'Ȳι';
 $strUpgrade = '%s %s ܹԤ˥åץ졼ɤ٤Ǥ';
 $strUsage = '';
 $strUseBackquotes = 'եȤǥơ֥̾ե̾Ϥ';
 $strUseHostTable = 'ۥȥơ֥Ȥ';
-$strUseTabKey = 'ͤͤޤǰܤˤTAB򡢤⤷ϤʾǤưˤCTRL+Ѥޤ';
+$strUseTabKey = 'ͤͤޤǰܤˤ TAB 򡢤⤷ϤʾǤưˤ CTRL + Ѥޤ';
 $strUseTables = 'Ȥơ֥';
 $strUseTextField = 'ƥȥեɤ';
 $strUseThisValue = 'ͤ';
@@ -713,20 +783,24 @@ $strUsersDeleted = '򤵤줿桼Ϻޤ';
 $strUsersHavingAccessToDb = '桼 &quot;%s&quot; ؤΥ¤Ƥޤ';
 
 $strValidateSQL = 'SQL θ';
-$strValidatorError = 'SQL ڵǽνޤ%sdocumentation%s˵ҤƤ褦PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ뤫åƲ';
+$strValidatorError = 'SQL θڵǽǤޤ%sdocumentation%s ˵ҤƤ褦 PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ뤫åƤ';
 $strValue = '';
 $strVar = 'ѿ';
+$strVersionInformation = 'С';
+$strView = 'ӥ塼';
 $strViewDump = 'ơ֥Υ()ɽ';
-$strViewDumpDB = 'DBΥ()ɽ';
+$strViewDumpDB = 'DB Υ()ɽ';
 $strViewDumpDatabases = 'ǡ١Υץӥ塼 ()';
+$strViewHasBeenDropped = 'ӥ塼 %s ˴ޤ';
 
-$strWebServerUploadDirectory = '֥Сǥåץ';
+$strWebServerUploadDirectory = '֥Сǥåץɤ';
 $strWebServerUploadDirectoryError = 'åץɤԤǥ쥯ȥ꤬ޤ';
 $strWelcome = '%s ؤ褦';
-$strWestEuropean = '衼åѿ';
+$strWestEuropean = '衼åѸ';
 $strWildcard = '磻ɥ';
-$strWindowNotFound = 'åȥ֥饦ɥ򹹿뤳Ȥޤ󡣶餯ʤϿƥɥĤ뤤ϡ֥饦ϡƥǥɥι֥åƤޤ';
+$strWindowNotFound = 'åȥ֥饦ɥ򹹿뤳ȤǤޤ󡣶餯ƥɥĤ뤤ϥ֥饦Υƥǡɥι֥åƤޤ';
 $strWithChecked = 'åΤ:';
+$strWriteRequests = '񤭹ߥꥯȿ';
 $strWritingCommentNotPossible = 'Ȥν񤭹ߤͭǤϤޤ';
 $strWritingRelationNotPossible = '졼ν񤭹ߤͭǤϤޤ';
 $strWrongUser = '桼̾ޤϥѥɤޤ<br />ϵݤޤ';
@@ -741,32 +815,15 @@ $strZip = '"zip "';
 
 // To translate:
 
-$strBinLogOriginalPosition = 'Original position';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
 
 $strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
 
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
+$strLatchedPages = 'Latched pages';  //to translate
 
 $strMIME_nodescription = 'Ѵˤͭޤ<br />Please ask the author, what %s does.';//to translate
-$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s';//to translate
 $strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').';//to translate
-
-$strOperator = 'Operator';  //to translate
-
-$strPasswordHashing = 'Password Hashing';  //to translate
-
-$strRowsModeFlippedHorizontal = 'horizontal (rotated headers)';//to translate
-
-$strTakeIt = 'take it';  //to translate
-$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
-$strTransformation_image_png__inline = 'See image/jpeg: inline';  //to translate
-$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().';//to translate
-$strTransformation_text_plain__external = 'LINUX Τ: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)';//to translate
-$strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.';//to translate
-$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.';  //to translate
-$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.';  //to translate
-$strTruncateQueries = 'Truncate Shown Queries';  //to translate
+$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAMơ֥˻Ѥ MAX_ROWS ץ󤬻ꤵʤΥХȻΥǥեȥݥ󥿡Ǥ';  //to translate
+$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
 
 ?>
