@@ -1,5 +1,5 @@
 <?php
-/* $Id: romanian-utf-8.inc.php,v 2.52 2004/12/28 16:34:48 nijel Exp $ */
+/* $Id: romanian-utf-8.inc.php,v 2.72 2005/06/12 10:10:02 swix Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -30,6 +30,7 @@ $strAddConstraints = 'Adauga constrangere';
 $strAddDeleteColumn = 'Adauga/Sterge coloane';
 $strAddDeleteRow = 'Adauga/Sterge criteriu';
 $strAddDropDatabase = 'Adaugare optiune STERGE BAZA DE DATE';
+$strAddFields = 'Adauga %s camp(uri)';
 $strAddHeaderComment = 'Adaugare comentariu la header (\\n inseamna delimitare de rand)';
 $strAddIfNotExists = 'Adaugare DACA NU EXISTA';
 $strAddIntoComments = 'Adaugare la comentarii';
@@ -47,6 +48,7 @@ $strAffectedRows = 'Linii afectate:';
 $strAfter = 'Dupa %s';
 $strAfterInsertBack = 'Revenire';
 $strAfterInsertNewInsert = 'Adauga o noua inregistrare';
+$strAfterInsertNext = 'Editeaza randul urmator';
 $strAfterInsertSame = 'Inapoi la aceasta pagina';
 $strAll = 'Toate';
 $strAllTableSameWidth = 'arata toate tabelele cu aceeasi marime?';
@@ -57,6 +59,7 @@ $strAnd = 'Si (And)';
 $strAny = 'Oricare';
 $strAnyHost = 'Oricare host';
 $strAnyUser = 'Oricare utilizator';
+$strApproximateCount = 'Poate fi aproximativ. Vezi FAQ 3.11';
 $strArabic = 'Arabic';
 $strArmenian = 'Armenian';
 $strAscending = 'Crescatoare';
@@ -70,8 +73,15 @@ $strBack = 'Inapoi';
 $strBaltic = 'Baltic';
 $strBeginCut = 'DE TAIAT - INCEPUT';
 $strBeginRaw = 'INCEPUT RAW';
+$strBinLogEventType = 'Tip eveniment';
+$strBinLogInfo = 'Informatie';
+$strBinLogName = 'Denumire Log';
+$strBinLogOriginalPosition = 'Pozitie originala';
+$strBinLogPosition = 'Pozitie';
+$strBinLogServerId = 'Server ID';
 $strBinary = 'Binar';
 $strBinaryDoNotEdit = 'Binar - a nu se edita';
+$strBinaryLog = 'Binary log';
 $strBookmarkAllUsers = 'Permite tuturor utilizatorilor sa acceseze acest bookmark';
 $strBookmarkDeleted = 'Eticheta a fost stearsa.';
 $strBookmarkLabel = 'Eticheta - Label';
@@ -86,6 +96,7 @@ $strBzError = 'phpMyAdmin nu a reusit sa compreseze acest dump din cauza unei ex
 $strBzip = '"bzipped"';
 
 $strCSVOptions = 'Optiuni CSV';
+$strCalendar = 'Calendar';
 $strCannotLogin = 'Nu pot face conexiunea catre serverul MySQL';
 $strCantLoad = 'nu se poate incarca %s extensia,<br />va rugam verificati configuratia PHP.';
 $strCantLoadRecodeIconv = 'Nu pot incarca extensia iconv sau recode necesar pentru conversia de caractere, configureaza PHP pentru a permite folosirea acestor extensii sau dezactiveaza conversia de caractere din phpMyAdmin.';
@@ -122,6 +133,7 @@ $strColumnPrivileges = 'Drepturi specifice de coloana';
 $strCommand = 'Comanda';
 $strComments = 'Comentarii';
 $strCommentsForTable = 'COMENTARII PENTRU TABEL';
+$strCompatibleHashing = 'Compatibil MySQL&nbsp;4.0';
 $strCompleteInserts = 'Rezolva inserarea';
 $strCompression = 'Compresie';
 $strConfigFileError = 'phpMyAdmin nu poate citi corect fisierul de configuratie!  <br />Acesta se poate intampla in cazul in care PHP nu poate gasi fisierul sau nu o poate parsa corect.  <br />Vezi configuratia fisierului apasand pe linkul de mai jos si citeste cu atentie erorile aparute ...  In cele mai multe cazuri lipsesc apostroful sau ghilimele.<br />Daca primesti o pagina goala, totul pare sa fie bine.';
@@ -131,6 +143,7 @@ $strConnections = 'Conexiuni';
 $strConstraintsForDumped = 'Restrictii pentru tabele sterse';
 $strConstraintsForTable = 'Restrictii pentru tabele';
 $strCookiesRequired = 'Trebuie sa aveti activat "cookies".';
+$strCopyDatabaseOK = 'Baza de date %s a fost copiata la %s';
 $strCopyTable = 'Copiaza tabela la (database<b>.</b>table):';
 $strCopyTableOK = 'Tabelul %s a fost copiat la %s.';
 $strCopyTableSameNames = 'Nu se poate copia tabelul pe cel existent pentru ca este acelasi';
@@ -150,6 +163,7 @@ $strCzech = 'Ceh';
 $strCzechSlovak = 'Czech-Slovak';
 
 $strDBComment = 'Comentarii referitoare la baza de date: ';
+$strDBCopy = 'Copiaza baza de date';
 $strDBGContext = 'Context';
 $strDBGContextID = 'Context ID';
 $strDBGHits = 'Afisari';
@@ -178,7 +192,9 @@ $strDatabasesStatsHeavyTraffic = 'Nota: Activarea statisticilor pentru baza de d
 $strDbPrivileges = 'Drepturi specifice de baza de date';
 $strDbSpecific = 'specific bazei de date';
 $strDefault = 'Setare de baza';
+$strDefaultEngine = '%s este motorul de stocare setat prin default pe acest server MySQL.';
 $strDefaultValueHelp = 'Pentru valorile implicite, va rugam introduceti o singura valoare, fara backslash, escape sau ghilimele, folosind formatul: a';
+$strDefragment = 'Defragmentare tablela';
 $strDelOld = 'Pagina curenta se leaga de tabele care nu mai exista. Doriti stergerea acestor legaturi?';
 $strDelayedInserts = 'Foloseste inserari intarziate';
 $strDelete = 'Sterge';
@@ -190,6 +206,7 @@ $strDeleting = 'Sterge %s';
 $strDescending = 'Descrescator';
 $strDescription = 'Descriere';
 $strDictionary = 'dictionar';
+$strDisableForeignChecks = 'Dezactivare verificari de cheie straine';
 $strDisabled = 'Dezactivat';
 $strDisplayFeat = 'Arata facilitatile';
 $strDisplayOrder = 'Ordine de afisare:';
@@ -213,12 +230,18 @@ $strEffective = 'Efectiv';
 $strEmpty = 'Goleste';
 $strEmptyResultSet = 'MySQL a dat un set de rezultate gol (ex. zero linii).';
 $strEnabled = 'Activat';
+$strEncloseInTransaction = 'Cuprinde exportare intr-o tranzactie';
 $strEnd = 'Sfarsit';
 $strEndCut = 'DE TAIAT - SFARSIT';
 $strEndRaw = 'SFARSIT RAW';
+$strEngineAvailable = '%s este disponibil pentru acest server de MySQL.';
+$strEngineDisabled = '%s a fost dezactivat pentru acest server de MySQL.';
+$strEngineUnsupported = 'Acest server MySQL nu suporta motorul de stocare %s.';
+$strEngines = 'Motoare';
 $strEnglish = 'Englez';
 $strEnglishPrivileges = ' Important: numele drepturilor de acces MySQL apar in engleza ';
 $strError = 'Eroare';
+$strEscapeWildcards = 'Wildcard-urile _ si % trebuiesc insotite de \ pentru a le aplica';
 $strEstonian = 'Estonian';
 $strExcelEdition = 'Editia Excel';
 $strExcelOptions = 'Optiuni Excel';
@@ -266,12 +289,14 @@ $strHasBeenAltered = 'a fost alterat.';
 $strHasBeenCreated = 'a fost creat.';
 $strHaveToShow = 'Trebuie sa alegi cel putin o coloana pentru a putea afisa';
 $strHebrew = 'Ebraica';
+$strHexForBinary = 'Foloseste hexadecimal pentru campuri binary';
 $strHome = 'Pagina de start';
 $strHomepageOfficial = 'Pagina oficiala phpMyAdmin';
 $strHost = 'Gazda (Host)';
 $strHostEmpty = 'Numele de gazda este gol!';
 $strHungarian = 'Unguresc';
 
+$strIcelandic = 'Islandic';
 $strId = 'ID';
 $strIdxFulltext = 'Tot textul';
 $strIfYouWish = 'In cazul in care doriti sa incarcati numai o parte a coloanelor tabelului, specificati o lista separata prin virgula.';
@@ -286,11 +311,16 @@ $strIndex = 'Index';
 $strIndexHasBeenDropped = 'Index %s a fost aruncat';
 $strIndexName = 'Nume index&nbsp;:';
 $strIndexType = 'Tip index&nbsp;:';
+$strIndexWarningMultiple = 'S-a creat mai mult de o cheie %s la coloana `%s`';
+$strIndexWarningPrimary = 'Cheile PRIMARY si INDEX nu trebuiesc setate ambele la coloana `%s`';
+$strIndexWarningTable = 'Probleme cu indexul tabelului `%s`';
+$strIndexWarningUnique = 'Cheile UNIQUE si INDEX nu trebuiesc setate ambele la coloana `%s`';
 $strIndexes = 'Indexuri';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Configurarea ta contine setarile ce baza (utilizator root fara parola). Serverul MySQL poate fi astfel vulnerabil, neaparat sa repari aceasta greseala.';
 $strInsert = 'Inserare';
 $strInsertAsNewRow = 'Insereaza ca o noua linie';
+$strInsertBookmarkTitle = 'Va rugam introduceti titlul bookmark';
 $strInsertNewRow = 'Insereaza o noua linie';
 $strInsertTextfiles = 'Insereaza fisiere de text in tabel';
 $strInsertedRowId = 'ID rand inserat:';
@@ -319,6 +349,7 @@ $strLatexContinuedCaption = 'Continuare captura tabel';
 $strLatexIncludeCaption = 'Include captura tabel';
 $strLatexLabel = 'Tasta label';
 $strLatexStructure = 'Structura tabelului __TABLE__';
+$strLatvian = 'Leton';
 $strLengthSet = 'Lungime/Setare';
 $strLimitNumRows = 'Numarul de inregistrari de pe pagina';
 $strLineFeed = 'Dezvoltare linie: \\n';
@@ -336,6 +367,7 @@ $strLogUsername = 'Nume utilizator:';
 $strLogin = 'Autentificare';
 $strLoginInformation = 'Informatii de autentificare';
 $strLogout = 'Deconectare';
+$strLongOperation = 'Aceasta operatie poate dura mult. Doriti totusi sa fie executata?';
 
 $strMIMETypesForTable = 'MIME TYPES PENTRU TABEL';
 $strMIME_MIMEtype = 'MIME-type';
@@ -349,6 +381,8 @@ $strMIME_transformation_options = 'Optiuni de transformare';
 $strMIME_transformation_options_note = 'Introduceti valorile pentru optiunile de transformare utilizand acest format: \'a\',\'b\',\'c\'...<br />Daca trebuie sa folositi backslash ("\") sau apostrof  ("\'") in aceste valori, introduceti un backslashes (ex. \'\\\\xyz\' sau \'a\\\'b\').';
 $strMIME_without = 'Tipurile MIME listate inclinat nu au o functie de transformare separata';
 $strMaximumSize = 'Marime maxima: %s%s';
+$strMbExtensionMissing = 'Nu s-a gasit extensia PHP mbstring si se pare ca folositi set de charactere multibyte. Fara extensia mbstring, phpMyAdmin nu poate diviza stringurile corect si acesta poate duce la rezultate neasteptate.';
+$strMbOverloadWarning = 'Ati activat mbstring.func_overload in configuratia PHP. Aceasta optiune nu este compatibila cu phpMyAdmin si poate duce la pierderea unor date!';
 $strModifications = 'Modificarile au fost salvate';
 $strModify = 'Modificare';
 $strModifyIndexTopic = 'Modifica un index';
@@ -358,6 +392,18 @@ $strMoveTableOK = 'Tabela %s a fost mutat la %s.';
 $strMoveTableSameNames = 'Nu se poate copia tabelul pe cel existent pentru ca este acelasi!';
 $strMultilingual = 'Poliglot';
 $strMustSelectFile = 'Trebuie sa selectezi fisierul care urmeaza sa fie inserat.';
+$strMyISAMDataPointerSize = 'Marime data pointer';
+$strMyISAMDataPointerSizeDesc = 'Marimea pointer default in byti, care este folosit de CREATE TABLE pentru tabelele MyISAM atunci cand nu este specificat nici o optiune MAX_ROWS.';
+$strMyISAMMaxExtraSortFileSize = 'Marimea maxima pentru fisierele temporare la crearea indexului';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Daca fisierul temporar utilizat pentru crearea rapida a indexului MyISAM ar fi mai mare decat daca s-ar utiliza cache-ul key. Se prefera utilizarea metodei key cache.';
+$strMyISAMMaxSortFileSize = 'Marimea maxima pentru fisierele de sortare temporare';
+$strMyISAMMaxSortFileSizeDesc = 'Marimea maxima pentru fisierul temporar care este permisa in MySQL in timpul recrearii unui index MyISAM (in timpul operatiunilor REPAIR TABLE, ALTER TABLE, sau LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Mod de recuperare automat';
+$strMyISAMRecoverOptionsDesc = 'Modul pentru recuperarea automata a tabelelor MyISAM deteriorate, setat prin optiunea startup --myisam-recover server.';
+$strMyISAMRepairThreads = 'Repara firele de executie';
+$strMyISAMRepairThreadsDesc = 'Daca aceasta valoare este mai mare decat 1, indexurile de tabel MyISAM sunt create in paralel (fiecare index in firul de executie propriu) in tipul operatiunii de reparare prin procesul de sortare.';
+$strMyISAMSortBufferSize = 'Sortare marime buffer';
+$strMyISAMSortBufferSizeDesc = 'Bufferul alocat la sortarea indexurilor MyISAM in timpul unei operatiuni REPAIR TABLE sau la crearea indexurilor cu CREATE INDEX sau ALTER TABLE.';
 $strMySQLCharset = 'Setul de caractere MySQL';
 $strMySQLReloaded = 'MySQL reincarcat.';
 $strMySQLSaid = 'MySQL zice: ';
@@ -370,9 +416,11 @@ $strName = 'Nume';
 $strNeedPrimaryKey = 'Ar trebui sa definiti un primary key pentru acest tabel.';
 $strNext = 'Urmatorul';
 $strNo = 'Nu';
+$strNoActivity = 'Nu ati avut activitate de mai mult de %s seconde, va rugam sa va autentificati din nou';
 $strNoDatabases = 'Nu sunt baze de date';
 $strNoDatabasesSelected = 'Nu este selectat nici o baza de date.';
 $strNoDescription = 'Nu exista descriere';
+$strNoDetailsForEngine = 'Nu exista informatii detaliate legate de status disponibile pentru motorul de stocare.';
 $strNoDropDatabases = 'Comenzile "DROP DATABASE" sunt dezactivate.';
 $strNoExplain = 'Sari peste explicarea SQL';
 $strNoFrames = 'phpMyAdmin are o interfata mai prietenoasa cu navigator care lucreaza cu <b>frame-uri</b>.';
@@ -386,8 +434,10 @@ $strNoPhp = 'fara cod PHP';
 $strNoPrivileges = 'Nu exista drepturi de acces';
 $strNoQuery = 'Nu exista cerere SQL!';
 $strNoRights = 'Nu detineti drepturi de acces pentru a va afla aici!';
+$strNoRowsSelected = 'Nu e nici un rand selectat';
 $strNoSpace = 'Spatiu insuficient pentru salvarea fisierului %s.';
 $strNoTablesFound = 'Nu s-a gasit nici un tabel in baza de date.';
+$strNoThemeSupport = 'Nu exista suport pentru themes, va rugam verificati configuratia si/sau designurile in directorul %s.';
 $strNoUsersFound = 'Nu s-a gasit nici un utilizator.';
 $strNoValidateSQL = 'Sari peste validarea SQL';
 $strNone = 'Nici unul(a)';
@@ -403,6 +453,7 @@ $strNumTables = 'Tabele';
 $strOK = 'E bine';
 $strOftenQuotation = 'Adesea ghilimele. OPTIONAL inseamna ca numai campurile char si varchar sunt incluse intre caracterele "incadrat intre".';
 $strOperations = 'Operatii';
+$strOperator = 'Operator';
 $strOptimizeTable = 'Optimizare tabel';
 $strOptionalControls = 'Optional. Controleaza modul in care se citeste sau se scrie un caracter special.';
 $strOptionally = 'OPTIONAL';
@@ -425,10 +476,12 @@ $strPdfNoTables = 'Nu exista tabele';
 $strPerHour = 'pe ora';
 $strPerMinute = 'pe minute';
 $strPerSecond = 'pe secunde';
+$strPersian = 'Persian';
 $strPhoneBook = 'carte de telefoane';
 $strPhp = 'Creaza cod PHP';
 $strPmaDocumentation = 'Documentatie phpMyAdmin';
 $strPmaUriError = 'Directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> TREBUIE sa fie setat in fisierul de configurare!';
+$strPolish = 'Polononez';
 $strPortrait = 'Portrait';
 $strPos1 = 'Incepe';
 $strPrevious = 'Anterior';
@@ -488,6 +541,7 @@ $strReType = 'Re-type';
 $strReceived = 'Receptionat';
 $strRecords = 'Inregistrari';
 $strReferentialIntegrity = 'Verificarea integritatii referentiei:';
+$strRefresh = 'Reincarca';
 $strRelationNotWorking = 'Optiunile aditionale pentru folosirea tabelelor intercalate (legate intre ele) au fost dezactivate. Pentru a afla de ce ...  %shere%s.';
 $strRelationView = 'Vizualizare relationala';
 $strRelationalSchema = 'Schema relationala';
@@ -510,6 +564,7 @@ $strRevoke = 'Revocare';
 $strRevokeAndDelete = 'Revocarea tuturor drepturilor active a utilizatorilor si stergerea acestora.';
 $strRevokeAndDeleteDescr = 'Utilizatorii vor avea in continuare drepturi de UTILIZARE pana ce drepturile se reincarca.';
 $strRevokeMessage = 'Drepturile tale au fost revocate pentru %s';
+$strRomanian = 'Roman';
 $strRowLength = 'Lungime linie';
 $strRowSize = ' Marime linie ';
 $strRows = 'Linie';
@@ -525,11 +580,12 @@ $strRunning = 'ruland pe %s';
 $strRussian = 'Rus';
 
 $strSQL = 'SQL';
+$strSQLExportCompatibility = 'Compatibilitate SQL export';
 $strSQLExportType = 'Modul de export';
 $strSQLOptions = 'Optiuni SQL';
 $strSQLParserBugMessage = 'Exista o posibilitate de a fi gasit un BUG in parserul SQL. Verifica atent inca o data comanda si verifica daca semnele specifice sunt corecte. O alta posibilitate ar putea fi punerea unui fisier binar in afara zonei de text. Poti incerca aceasta comanda si printr-o linie de comanda MySQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei. Daca in continuare ai probleme cu executarea comenzii, redu o parte din comanda la aceea parte care cauzeaza problema si raporteaza acesta ca un BUG in sectiunea DE TAIAT';
 $strSQLParserUserError = 'Pare sa fie o eroare in comanda SQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei';
-$strSQLQuery = 'Comansa SQL';
+$strSQLQuery = 'Comanda SQL';
 $strSQLResult = 'Rezultat SQL';
 $strSQPBugInvalidIdentifer = 'Identificator invalid';
 $strSQPBugUnclosedQuote = 'Citare neinchisa';
@@ -550,6 +606,7 @@ $strSearchType = 'Gaseste:';
 $strSecretRequired = 'Fisierul de configurare necesita e expresie de protectie secreta (blowfish_secret).';
 $strSelectADb = 'Selectati baza de date';
 $strSelectAll = 'Selecteaza tot';
+$strSelectBinaryLog = 'Selectati binary log pentru vizualizare';
 $strSelectFields = 'Selecteaza campurile (cel putin unul):';
 $strSelectNumRows = 'in comanda (in query)';
 $strSelectTables = 'Selecteaza tabele';
@@ -557,6 +614,7 @@ $strSend = 'Trimite';
 $strSent = 'Trimis';
 $strServer = 'Server';
 $strServerChoice = 'Alegerea serverului';
+$strServerNotResponding = 'Serverul nu raspunde';
 $strServerStatus = 'Informatii rulare';
 $strServerStatusUptime = 'Acest server MySQL ruleaza de %s. S-a lansat la %s.';
 $strServerTabProcesslist = 'Procese';
@@ -580,19 +638,25 @@ $strShowingRecords = 'Afiseaza inregistrari';
 $strSimplifiedChinese = 'Chineza simplificata';
 $strSingly = '(singly)';
 $strSize = 'Marime';
+$strSlovak = 'Slovac';
+$strSlovenian = 'Sloven';
 $strSort = 'Sortare';
 $strSortByKey = 'Sortare dupa tasta';
 $strSpaceUsage = 'Utilizare spatiu';
+$strSpanish = 'Spaniola';
 $strSplitWordsWithSpace = 'Cuvinte sparte de un spatiu (" ").';
 $strStatCheckTime = 'Ultima verficare';
 $strStatCreateTime = 'Creatie';
 $strStatUpdateTime = 'Ultimul update';
 $strStatement = 'Comenzi';
 $strStatus = 'Status';
+$strStorageEngine = 'Motor de stocare';
+$strStorageEngines = 'Motoare de stocare';
 $strStrucCSV = 'Date CSV';
 $strStrucData = 'Structura si date';
 $strStrucDrop = 'Adauga \'salveaza tabel\'';
 $strStrucExcelCSV = 'Date CSV pentru MS Excel';
+$strStrucNativeExcel = 'Date native MS Excel';
 $strStrucOnly = 'Numai structura';
 $strStructPropose = 'Propune structura de tabele';
 $strStructure = 'Structura';
@@ -600,6 +664,7 @@ $strSubmit = 'Trimite';
 $strSuccess = 'Comanda dumneavoastra SQL a fost executata cu succes';
 $strSum = 'Sum';
 $strSwedish = 'Suedez';
+$strSwitchToDatabase = 'Schimba la tabela copiata';
 $strSwitchToTable = 'Schimba la tabela copiata';
 
 $strTable = 'Tabel';
@@ -614,12 +679,14 @@ $strTableOptions = 'Optiuni tabel';
 $strTableStructure = 'Structura de tabel pentru tabelul';
 $strTableType = 'Tipul tabelului';
 $strTables = '%s tabele';
+$strTakeIt = 'alege';
 $strTblPrivileges = 'Drepturi specifice de tabele';
 $strTextAreaLength = ' Datorita lungimii sale, <br /> acest camp s-ar putea sa nu fie editabil';
 $strThai = 'Tailandez';
 $strTheContent = 'Continutul fisierului dumneavoastra a fost inserat.';
 $strTheContents = 'Continutul acestui fisier inlocuieste continutul tabelului selectat pentru liniile cu cheie primara identica.';
 $strTheTerminator = 'Terminatorul campurilor.';
+$strTheme = 'Sablon / Stil';
 $strThisHost = 'Acest Host';
 $strThisNotDirectory = 'Acesta nu este un director';
 $strThreadSuccessfullyKilled = 'Firul de executie %s a fost oprit cu succes.';
@@ -628,6 +695,7 @@ $strToggleScratchboard = 'dezactivare scratchboard';
 $strTotal = 'total';
 $strTotalUC = 'Total';
 $strTraditionalChinese = 'Chineza Traditionala';
+$strTraditionalSpanish = 'Spaniola traditionala';
 $strTraffic = 'Trafic';
 $strTransformation_application_octetstream__download = 'Afiseaza un link pentru descarcarea datelor binare a unui camp. Prima optiune este denumirea fisierului binar. A doua optiune este o denumire posibila pentru un rand de tabel care contine denumirea de fisier. Daca setati si o a doua optiune, trebuie sa aveti prima optiune setata ca si empty string';
 $strTransformation_image_jpeg__inline = 'Afiseaza o imagine mica clicabila ; optiuni: latime, inaltime in pixeli (metine dimensiunile originale)';
@@ -639,7 +707,6 @@ $strTransformation_text_plain__formatted = 'Mentine formatarea originala a campu
 $strTransformation_text_plain__imagelink = 'Afiseaza o imagine si un link, campul contine denumirea fisierului; prima optiune este un prefix cum ar fi "http://domain.com/", a doua optiune este latimea in pixeli, iar a treia este inaltimea.';
 $strTransformation_text_plain__link = 'Afiseaza un link, campul contine denumirea fisierului,  prima optiune este un prefix cum ar fi "http://domain.com/", a doua optiune este un titlu pentru link.';
 $strTransformation_text_plain__substr = 'Afiseaza doar o parte a firului de executie. Prima optiune este un offset pentru definirea punctului de inceput a outputului de text (Default 0). A doua optiune este un offset de text returnat. Daca este gol, returneaza textul ramas. A treia optiune defineste caracterele care vor fi atasate la output la returnarea unui substring  (Default: ...) .';
-$strTransformation_text_plain__unformatted = 'Afiseaza codul HTML ca si entitate HTML. Nu se afiseaza formatarea HTML.';
 $strTruncateQueries = 'Truncare comenzi afisate';
 $strTurkish = 'Turc';
 $strType = 'Tip';
@@ -658,6 +725,7 @@ $strUpgrade = 'Ar trebui sa reactualizati serverul %s %s la o versiune mai noua.
 $strUsage = 'Utilizare';
 $strUseBackquotes = 'Utilizati apostroful pentru numele tabelelor si a campurilor';
 $strUseHostTable = 'Utilizare tabel host';
+$strUseTabKey = 'Folositi tasta TAB pentru a trece de la o valoare la alta sau CTRL+sageti pentru a merge in oricare directie';
 $strUseTables = 'Utilizare tabele';
 $strUseTextField = 'Utilizare camp text';
 $strUseThisValue = 'Foloseste aceasta valoare';
@@ -674,9 +742,12 @@ $strValidateSQL = 'Valideaza SQL';
 $strValidatorError = 'Validatorul SQL nu poate fi initializat. Verifica daca e instalat extesnsia necesara PHP asa cum e descris in %sdocumentation%s.';
 $strValue = 'Valoare';
 $strVar = 'Variabil';
+$strVersionInformation = 'Informatii despre versiune';
+$strView = 'Vizualizare';
 $strViewDump = 'Vizualizarea schemei tabelului';
 $strViewDumpDB = 'Vizualizarea schemei bazei de date';
 $strViewDumpDatabases = 'Vizualizarea schemei bazei de date';
+$strViewHasBeenDropped = 'Vizualizarea %s a fost eliminata';
 
 $strWebServerUploadDirectory = 'director de upload al web-server-ului';
 $strWebServerUploadDirectoryError = 'Directorul setat pentru upload nu poate fi gasit';
@@ -696,54 +767,50 @@ $strYes = 'Da';
 $strZeroRemovesTheLimit = 'Observatie: Prin setarea acestor optiuni la 0 (zero) se elimina restrictia.';
 $strZip = '"arhivat"';
 
-$strOperator = 'Operator';  //to translate
-$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
-$strCalendar = 'Calendar';  //to translate
-$strRefresh = 'Refresh';  //to translate
-$strDefragment = 'Defragment table';  //to translate
-$strNoRowsSelected = 'No rows selected';  //to translate
-$strSpanish = 'Spanish';  //to translate
-$strStrucNativeExcel = 'Native MS Excel data';  //to translate
-$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
-$strServerNotResponding = 'The server is not responding';  //to translate
-$strTheme = 'Theme / Style';  //to translate
-$strTakeIt = 'take it';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
-$strIcelandic = 'Icelandic';  //to translate
-$strLatvian = 'Latvian';  //to translate
-$strPolish = 'Polish';  //to translate
-$strRomanian = 'Romanian';  //to translate
-$strSlovenian = 'Slovenian';  //to translate
-$strTraditionalSpanish = 'Traditional Spanish';  //to translate
-$strSlovak = 'Slovak';  //to translate
-$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
-$strPersian = 'Persian';  //to translate
-$strAddFields = 'Add %s field(s)';  //to translate
-$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
-$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
-$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
-$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
-$strBinLogName = 'Log name';  //to translate
-$strBinLogPosition = 'Position';  //to translate
-$strBinLogEventType = 'Event type';  //to translate
-$strBinLogServerId = 'Server ID';  //to translate
-$strBinLogOriginalPosition = 'Original position';  //to translate
-$strBinLogInfo = 'Information';  //to translate
-$strBinaryLog = 'Binary log';  //to translate
-$strSelectBinaryLog = 'Select binary log to view';  //to translate
-$strDBCopy = 'Copy database to';  //to translate
-$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
-$strSwitchToDatabase = 'Switch to copied database';  //to translate
+// To translate:
+
+$strMySQLConnectionCollation = 'MySQL connection collation'; //to translate
+
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
-$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
-$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
-$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
-$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
-$strAfterInsertNext = 'Edit next row';  //to translate
+
+$strInnoDBDataHomeDir = 'Data home directory';  //to translate
+$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
+$strInnoDBDataFilePath = 'Data files';  //to translate
+$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
+$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
+$strBufferPool = 'Buffer Pool';  //to translate
+$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
+$strDataPages = 'Pages containing data';  //to translate
+$strFreePages = 'Free pages';  //to translate
+$strBusyPages = 'Busy pages';  //to translate
+$strDirtyPages = 'Dirty pages';  //to translate
+$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
+$strLatchedPages = 'Latched pages';  //to translate
+$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
+$strReadRequests = 'Read requests';  //to translate
+$strWriteRequests = 'Write requests';  //to translate
+$strBufferReadMisses = 'Read misses';  //to translate
+$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
+$strBufferWriteWaits = 'Write waits';  //to translate
+$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
+$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
+$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
+$strHTMLWord = 'Microsoft Word 2000';  //to translate
+$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
+$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
+$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
+$strInnoDBPages = 'pages';  //to translate
+$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
 ?>
