@@ -1,5 +1,5 @@
 <?php
-/* $Id: serbian_cyrillic-utf-8.inc.php,v 2.60.2.1 2005/01/22 22:42:47 lem9 Exp $ */
+/* $Id: serbian_cyrillic-utf-8.inc.php,v 2.81 2005/06/12 10:10:02 swix Exp $ */
 
 /**
  * Translated by:
@@ -96,7 +96,15 @@ $strBookmarkThis = 'Запамти SQL-упит';
 $strBookmarkView = 'Види само';
 $strBrowse = 'Преглед';
 $strBrowseForeignValues = 'Прегледај стране вредности';
+$strBufferPool = 'Скуп прихватника';
+$strBufferPoolActivity = 'Активност скупа прихватника';
+$strBufferPoolUsage = 'Коришћење скупа прихватника';
+$strBufferReadMisses = 'Промашаји при читању';
+$strBufferReadMissesInPercent = 'Промашаји читања у %';
+$strBufferWriteWaits = 'Чекања на упис';
+$strBufferWriteWaitsInPercent = 'Чекања на упис у %';
 $strBulgarian = 'Бугарски';
+$strBusyPages = 'Заузете стране';
 $strBzError = 'phpMyAdmin није могао да компресује садржај базе због неисправне BZ2 екстензије у овој верзији PHP-а. Препоручује се да подесите <code>$cfg[\'BZipDump\']</code> директиву у вашoj phpMyAdmin конфигурационоj датотеци на <code>FALSE</code>. Ако желите да користите могућности BZ2 компресије, требало би да пређете на новију верзију PHP-а. Видите PHP извештај о грешкама %s за детаље.';
 $strBzip = '"бзип-овано"';
 
@@ -126,7 +134,7 @@ $strCharsetOfFile = 'Карактер сет датотеке:';
 $strCharsets = 'Кодне стране';
 $strCharsetsAndCollations = 'Карактер сетови и сортирање';
 $strCheckAll = 'Означи све';
-$strCheckOverhead = 'Провери прекорачења';
+$strCheckOverhead = 'Провери табеле које имају прекорачења';
 $strCheckPrivs = 'Провери привилегије';
 $strCheckPrivsLong = 'Провери привилегије за базу &quot;%s&quot;.';
 $strCheckTable = 'Провери табелу';
@@ -183,6 +191,7 @@ $strDanish = 'Дански';
 $strData = 'Подаци';
 $strDataDict = 'Речник података';
 $strDataOnly = 'Само подаци';
+$strDataPages = 'Стране са подацима';
 $strDatabase = 'База података';
 $strDatabaseEmpty = 'Име базе није задато!';
 $strDatabaseExportOptions = 'Опције за извоз базе';
@@ -197,6 +206,7 @@ $strDatabasesStatsHeavyTraffic = 'Напомена: укључивање ста
 $strDbPrivileges = 'Привилегије везане за базу';
 $strDbSpecific = 'Специфично за базу';
 $strDefault = 'Подразумевано';
+$strDefaultEngine = '%s је подразумевани погон складиштења на овом MySQL серверу.';
 $strDefaultValueHelp = 'За подразумевану вредност, унесите само једну вредност, без косих црта или наводника у овом облику: а';
 $strDefragment = 'Дефрагментирај табелу';
 $strDelOld = 'Тренутна страна има референце на табеле које више не постоје. Желите ли да обришете те референце?';
@@ -210,6 +220,7 @@ $strDeleting = 'Бришем %s';
 $strDescending = 'Опадајући';
 $strDescription = 'Опис';
 $strDictionary = 'речник';
+$strDirtyPages = 'Прљаве стране';
 $strDisableForeignChecks = 'Искључи провере страних кључева';
 $strDisabled = 'Онемогућено';
 $strDisplayFeat = 'Прикажи особине';
@@ -238,6 +249,10 @@ $strEncloseInTransaction = 'Обави извоз у трансакцији';
 $strEnd = 'Крај';
 $strEndCut = 'КРАЈ РЕЗ';
 $strEndRaw = 'КРАЈ СИРОВО';
+$strEngineAvailable = '%s је доступан на овом MySQL серверу.';
+$strEngineDisabled = '%s је онемогућен на овом MySQL серверу.';
+$strEngineUnsupported = 'Овај MySQL сервер не подржава %s погон складиштења.';
+$strEngines = 'Складиштења';
 $strEnglish = 'Енглески';
 $strEnglishPrivileges = ' Напомена: MySQL имена привилегија морају да буду на енглеском ';
 $strError = 'Грешка';
@@ -269,6 +284,7 @@ $strFlushPrivilegesNote = 'Напомена: phpMyAdmin узима привил
 $strFlushTable = 'Освежи табелу ("FLUSH")';
 $strFormEmpty = 'Недостаје вредност у обрасцу!';
 $strFormat = 'Формат';
+$strFreePages = 'Слободне стране';
 $strFullText = 'Пун текст';
 $strFunction = 'Функција';
 
@@ -285,6 +301,10 @@ $strGrantOption = 'Омогући';
 $strGreek = 'Грчки';
 $strGzip = '"гзип-овано"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Опције извоза у Microsoft Excel 2000';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Опције извоза у Microsoft Word 2000';
 $strHasBeenAltered = 'је промењен(а).';
 $strHasBeenCreated = 'је креиран(а).';
 $strHaveToShow = 'Морате изабрати бар једну колону за приказ';
@@ -316,6 +336,14 @@ $strIndexWarningPrimary = 'PRIMARY и INDEX кључеви не би треба
 $strIndexWarningTable = 'Проблем при индексирању табеле `%s`';
 $strIndexWarningUnique = 'UNIQUE и INDEX кључеви не би требали да буду истовремено постављени за колону `%s`';
 $strIndexes = 'Кључеви';
+$strInnoDBAutoextendIncrement = 'Корак аутоматског проширења';
+$strInnoDBAutoextendIncrementDesc = ' Величина корака проширења величине табела које се аутоматски проширују када се напуне.';
+$strInnoDBBufferPoolSize = 'Величина прихватника';
+$strInnoDBBufferPoolSizeDesc = 'Величина меморијског прихватника које InnoDB користи за кеширање података и индекса својих табела.';
+$strInnoDBDataFilePath = 'Датотеке са подацима';
+$strInnoDBDataHomeDir = 'Основни директоријум података';
+$strInnoDBDataHomeDirDesc = 'Заједнички део путање директоријума за све InnoDB датотеке са подацима.';
+$strInnoDBPages = 'страна';
 $strInnodbStat = 'InnoDB статус';
 $strInsecureMySQL = 'Ваша конфигурациона датотека садржи подешавања (root без лозинке) која одговарају стандардном MySQL привилегованом налогу. Ваш MySQL сервер ради са овим подешавањима, отворен је за упаде, и заиста треба да исправите овај сигурносни ризик.';
 $strInsert = 'Нови запис';
@@ -342,6 +370,7 @@ $strKorean = 'Корејски';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'LaTeX опције';
 $strLandscape = 'Положено';
+$strLatchedPages = 'Забрављене стране';
 $strLatexCaption = 'Коментар табеле';
 $strLatexContent = 'Садржај табеле __TABLE__';
 $strLatexContinued = '(настављено)';
@@ -367,6 +396,7 @@ $strLogUsername = 'Корисничко име:';
 $strLogin = 'Пријављивање';
 $strLoginInformation = 'Подаци о пријави';
 $strLogout = 'Одјављивање';
+$strLongOperation = 'Ова операција може да потраје. Да ли да наставимо?';
 
 $strMIMETypesForTable = 'MIME ТИПОВИ ЗА ТАБЕЛУ';
 $strMIME_MIMEtype = 'MIME-типови';
@@ -391,6 +421,18 @@ $strMoveTableOK = 'Табела %s је померена у %s.';
 $strMoveTableSameNames = 'Не могу да преместим табелу у саму себе!';
 $strMultilingual = 'вишејезички';
 $strMustSelectFile = 'Морате изабрати датотеку коју желите да уметнете.';
+$strMyISAMDataPointerSize = 'Величина показивача података';
+$strMyISAMDataPointerSizeDesc = 'Подразумевана величина показивача у бајтовима, користи се при CREATE TABLE за MyISAM табеле када није задата опција MAX_ROWS';
+$strMyISAMMaxExtraSortFileSize = 'Максимална величина привремених датотека при креирању индекса';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Ако би привремена датотека која се користи за брзо креирање MyISAM индекса била већа него при коришћењу кеша кључева за овде задату вредност, користи метод кеширања кључева';
+$strMyISAMMaxSortFileSize = 'Максимална величина привремених датотека за сортирање';
+$strMyISAMMaxSortFileSizeDesc = 'Максимална величина привремених датотека које MySQL сме да користи при ре-креирању MyISAM индекса (у току REPAIR TABLE, ALTER TABLE, или LOAD DATA INFILE операција).';
+$strMyISAMRecoverOptions = 'Режим аутоматског опоравка';
+$strMyISAMRecoverOptionsDesc = 'Режим аутоматског опоравка пукнутих MyISAM табела, подешен при стартовању сервера опцијом --myisam-recover.';
+$strMyISAMRepairThreads = 'Нити поправке';
+$strMyISAMRepairThreadsDesc = 'Ако је вредност већа од 1, индекси MyISAM табела се паралелно креирају (сваки индекс у сопственој нити) за време процеса поправке сортирањем.';
+$strMyISAMSortBufferSize = 'Величина прихватника за сортирање';
+$strMyISAMSortBufferSizeDesc = 'Прихватник који се алоцира при сортирању MyISAM индекса за време операције REPAIR TABLE или при креирању индекса са CREATE INDEX или ALTER TABLE.';
 $strMySQLCharset = 'MySQL сет карактера';
 $strMySQLConnectionCollation = 'Сортирање за MySQL везу';
 $strMySQLReloaded = 'MySQL поново покренут.';
@@ -408,6 +450,7 @@ $strNoActivity = 'Није било активности %s или више се
 $strNoDatabases = 'База не постоји';
 $strNoDatabasesSelected = 'Није изабрана ни једна база.';
 $strNoDescription = 'нема описа';
+$strNoDetailsForEngine = 'Нема детаљнијих информација о статусу за овај погон складиштења.';
 $strNoDropDatabases = '"DROP DATABASE" команда је онемогућена.';
 $strNoExplain = 'Прескочи објашњавање SQL-a';
 $strNoFrames = 'phpMyAdmin преферира читаче који подржавају оквире.';
@@ -451,6 +494,7 @@ $strOverwriteExisting = 'Препиши постојеће датотеке';
 $strPHP40203 = 'Користите PHP 4.2.3, који има озбиљан баг са вишебајтним стринговима (mbstring). Погледајте извештај о грешци бр. 19404. Ова верзија PHP-a се не препоручује за коришћење са phpMyAdmin.';
 $strPHPVersion = 'верзија PHP-a';
 $strPageNumber = 'Број стране:';
+$strPagesToBeFlushed = 'Стране које треба да буду усклађене';
 $strPaperSize = 'Димензије папира';
 $strPartialText = 'Део текста';
 $strPassword = 'Лозинка';
@@ -526,6 +570,7 @@ $strQueryType = 'Врста упита';
 $strQueryWindowLock = 'Не преписуј овај упит изван прозора';
 
 $strReType = 'Поновите унос';
+$strReadRequests = 'Захтеви за читање';
 $strReceived = 'Примљено';
 $strRecords = 'Записи';
 $strReferentialIntegrity = 'Провери референцијални интегритет:';
@@ -628,6 +673,7 @@ $strSingly = '(по једном пољу)';
 $strSize = 'Величина';
 $strSlovak = 'Словачки';
 $strSlovenian = 'Словеначи';
+$strSocketProblem = '(или прикључак локалног MySQL сервера није исправно подешен)';
 $strSort = 'Сортирање';
 $strSortByKey = 'Сортирај по кључу';
 $strSpaceUsage = 'Заузеће';
@@ -638,6 +684,8 @@ $strStatCreateTime = 'Направљено';
 $strStatUpdateTime = 'Последња измена';
 $strStatement = 'Име';
 $strStatus = 'Статус';
+$strStorageEngine = 'Погон складиштења';
+$strStorageEngines = 'Погони складиштења';
 $strStrucCSV = 'CSV формат';
 $strStrucData = 'Структура и подаци';
 $strStrucDrop = 'Додај \'DROP TABLE\'';
@@ -692,8 +740,7 @@ $strTransformation_text_plain__external = 'САМО LINUX: Покреће екс
 $strTransformation_text_plain__formatted = 'Чува оригинално форматирање поља. Escaping се не врши.';
 $strTransformation_text_plain__imagelink = 'Приказује слику и линк, поље садржи назив датотеке; прва опција је префикс као "http://domain.com/", друга опција је ширина у пикселима, трећа је висина.';
 $strTransformation_text_plain__link = 'Приказује линк, поље садржи назив датотеке; прва опција је префикс као "http://domain.com/", друга опција је наслов за линк.';
-$strTransformation_text_plain__substr = 'Показује само део стринга. Прва опција је офсет који дефинише где почиње излаз вашег текста (подразумевано 0). Друга опција је офсет који показује колико ће текста бити приказано. Ако је нема, сав преостали текст ће бити приказан. Трећа опција одређује који ће знаци бити додати излазу када се прикаже подстринг (подразумевано: ...) .';
-$strTransformation_text_plain__unformatted = 'Приказује HTML код као HTML ентитете. HTML форматирање се не приказује.';
+$strTransformation_text_plain__substr = 'Показује део стринга. Прва опција је број знакова које треба прескочити од почетка стринга (подразумевано 0). Друга опција је број враћених знакова (подразумевано: до краја стринга). Трећа опција је стринг који се додаје када дође до одсецања (подразумевано: ...) .';
 $strTruncateQueries = 'Прикажи скраћене упите';
 $strTurkish = 'Турски';
 $strType = 'Тип';
@@ -729,9 +776,12 @@ $strValidateSQL = 'Провери SQL';
 $strValidatorError = 'SQL валидатор није могао да буде покренут. Проверите да ли су инсталиране неопходне PHP екстензије описане у  %sдокументацији%s.';
 $strValue = 'Вредност';
 $strVar = 'Променљива';
+$strVersionInformation = 'Информације о верзији';
+$strView = 'Поглед';
 $strViewDump = 'Прикажи садржај (схему) табеле';
 $strViewDumpDB = 'Прикажи садржај (схему) базе';
 $strViewDumpDatabases = 'Прикажи садржај (схему) базе';
+$strViewHasBeenDropped = 'Поглед %s је одбачен';
 
 $strWebServerUploadDirectory = 'директоријум за слање веб сервера ';
 $strWebServerUploadDirectoryError = 'Директоријум који сте изабрали за слање није доступан';
@@ -740,6 +790,7 @@ $strWestEuropean = 'Западноевропски';
 $strWildcard = 'џокер';
 $strWindowNotFound = 'Одредишни прозор претраживача није могао да буде ажуриран. Можда сте затворили матични прозор, или ваш претраживач онемогућава ажурирање међу прозорима због сигурносних подешавања';
 $strWithChecked = 'Означено:';
+$strWriteRequests = 'Захтеви за упис';
 $strWritingCommentNotPossible = 'Писање коментара није могуће';
 $strWritingRelationNotPossible = 'Уписивање релације није могуће';
 $strWrongUser = 'Погрешно корисничко име/лозинка. Приступ одбијен.';
@@ -751,4 +802,16 @@ $strYes = 'Да';
 $strZeroRemovesTheLimit = 'Напомена: Постављање ових опција на 0 (нулу) уклања ограничења.';
 $strZip = '"зиповано"';
 
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
 ?>
