@@ -1,5 +1,5 @@
 <?php
-/* $Id: spanish-iso-8859-1.inc.php,v 2.63 2005/01/09 22:01:55 lem9 Exp $ */
+/* $Id: spanish-iso-8859-1.inc.php,v 2.83 2005/06/12 10:10:10 swix Exp $ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
@@ -17,6 +17,8 @@ $month = array('Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'O
 $datefmt = '%d-%m-%Y a las %H:%M:%S';
 $timespanfmt = '%s das, %s horas, %s minutos y %s segundos';
 
+// Daniel Hinostroza 3.4.2005: los de abajo y string = cadena de caracteres
+
 $strAPrimaryKey = 'Se aadi una clave primaria en %s';
 $strAbortedClients = 'Abortado';
 $strAbsolutePathToDocSqlDir = 'Por favor, ingrese la ruta absoluta del servidor hacia el directorio docSQL';
@@ -89,7 +91,15 @@ $strBookmarkThis = 'Guardar esta consulta en favoritos';
 $strBookmarkView = 'Solamente ver';
 $strBrowse = 'Examinar';
 $strBrowseForeignValues = 'Muestre los valores extranjeros';
+$strBufferPool = 'Total de memoria del bfer'; 
+$strBufferPoolActivity = 'Actividad del memoria (bfer) de trnsito comn';
+$strBufferPoolUsage = 'Consumo del Total de memoria del bfer'; 
+$strBufferReadMisses = 'Lea los fallos';
+$strBufferReadMissesInPercent = 'Lea los fallos en %';
+$strBufferWriteWaits = 'Escriba las esperas';
+$strBufferWriteWaitsInPercent = 'Escriba las esperas en %';
 $strBulgarian = 'Blgaro';
+$strBusyPages = 'Pginas activas'; 
 $strBzError = 'Si desea usar las opciones de compresin Bz2, deber actualizar su php a una versin ms reciente. phpMyAdmin no fue capaz de comprimir el dump debido a que est daada la extensin Bz2 en esta versin de php. Le recomendamos que cambie el parmetro <code>$cfg[\'BZipDump\']</code> en su archivo de configuracin phpMyAdmin a <code>FALSE</code>. Lea el reporte de "bugs" de php %s para mayor informacin.';
 $strBzip = '"Comprimido con bzip"';
 
@@ -119,7 +129,7 @@ $strCharsetOfFile = 'Juego de caracteres del archivo:';
 $strCharsets = 'Juegos de caracteres'; 
 $strCharsetsAndCollations = 'Juego de caracteres y sus cotejamientos (collations)'; 
 $strCheckAll = 'Revisar todos/as';
-$strCheckOverhead = 'Revise el residuo a depurar';
+$strCheckOverhead = 'Revise las tablas con residuo a depurar (overhead)';
 $strCheckPrivs = 'Revise los privilegios';
 $strCheckPrivsLong = 'Revise los privilegios para la base de datos &quot;%s&quot;.';
 $strCheckTable = 'Revisar tabla';
@@ -176,6 +186,7 @@ $strDanish = 'Dans';
 $strData = 'Datos';
 $strDataDict = 'Diccionario Datos';
 $strDataOnly = 'Solamente datos';
+$strDataPages = 'Pginas que contienen datos'; 
 $strDatabase = 'Base de datos';
 $strDatabaseEmpty = 'El nombre de la base de datos est vaca!';
 $strDatabaseExportOptions = 'Opciones de exportacin de la base de datos';
@@ -190,6 +201,7 @@ $strDatabasesStatsHeavyTraffic = 'Nota: Activando las estadsticas de la base de
 $strDbPrivileges = 'Privilegios especficos para la base de datos';
 $strDbSpecific = 'especfico para la base de datos';
 $strDefault = 'Predeterminado';
+$strDefaultEngine = '%s es el motor de almacenamiento predeterminado en este servidor MySQL.';
 $strDefaultValueHelp = 'Para valores predeterminados, por favor ingrese solamente un valor, sin "escaping backslash" ni comillas, usando este formato: a';
 $strDefragment = 'Defragmentar la tabla';
 $strDelOld = 'La pgina actual tiene referencias a tablas que ya no existen.  Desea eliminar esas referencias?';
@@ -203,6 +215,7 @@ $strDeleting = 'Borrando %s';
 $strDescending = 'Descendente';
 $strDescription = 'Descripcin';
 $strDictionary = 'diccionario';
+$strDirtyPages = 'Pginas que requieren ser depuradas'; 
 $strDisableForeignChecks = 'Deshabilitar la revisin de las llaves extranjeras (foreign keys)';
 $strDisabled = 'Deshabilitado';
 $strDisplayFeat = 'Mostrar las opciones';  //Features = opciones, componentes?
@@ -231,6 +244,10 @@ $strEncloseInTransaction = 'Incluya lo exportado en una transaccin';
 $strEnd = 'Fin';
 $strEndCut = 'FIN DEL CORTE';
 $strEndRaw = 'FIN DEL VOLCADO';
+$strEngineAvailable = '%s est disponible en este servidor MySQL.';
+$strEngineDisabled = '%s ha sido deshabilitado para este motor de almacenamiento.';
+$strEngineUnsupported = 'Este servidor MySQL no es compatible con el motor de almacenamiento %s.'; 
+$strEngines = 'Motores';
 $strEnglish = 'Ingls';
 $strEnglishPrivileges = ' Nota: Los nombres de los privilegios de MySQL estn expresados en ingls ';
 $strError = 'Error';
@@ -262,6 +279,7 @@ $strFlushPrivilegesNote = 'Nota: phpMyAdmin obtiene los privilegios de los usuar
 $strFlushTable = 'Vaciar el cach de la tabla ("FLUSH")';
 $strFormEmpty = 'Falta un valor en el formulario!';
 $strFormat = 'Formato';
+$strFreePages = 'Pginas libres'; 
 $strFullText = 'Textos completos';
 $strFunction = 'Funcin';
 
@@ -278,6 +296,10 @@ $strGrantOption = 'Conceder';
 $strGreek = 'Griego';
 $strGzip = '"Comprimido con gzip"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Opciones de exportacin Microsoft Excel 2000';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Opciones de exportacin Microsoft Word 2000';
 $strHasBeenAltered = 'fue modificada.';
 $strHasBeenCreated = 'se cre.';
 $strHaveToShow = 'Debe elegir al menos una columna para mostrar';
@@ -292,7 +314,7 @@ $strHungarian = 'Hngaro';
 $strIcelandic = 'Islands';
 $strId = 'Identificacin';
 $strIdxFulltext = 'Texto completo';
-$strIfYouWish = 'Si desea cargar solamente una de las columnas de la tabla, especifquelo, separando los campos con una coma.';
+$strIfYouWish = 'Si desea cargar solamente una de las columnas de la tabla, especifquela, separando los campos con una coma.';
 $strIgnore = 'Ignorar';
 $strIgnoreInserts = 'Use la opcin ignore inserts';
 $strIgnoringFile = 'Ignorando el archivo %s';
@@ -309,6 +331,14 @@ $strIndexWarningPrimary = 'Las claves PRIMARIA e INDICE no deben seleccionarse j
 $strIndexWarningTable = 'Problemas con los ndices de la tabla `%s`';
 $strIndexWarningUnique = 'Las claves UNICA e INDICE no deben seleccionarse juntas para la columna `%s`';
 $strIndexes = 'ndices';
+$strInnoDBAutoextendIncrement = 'Incremente el valor Autoextend'; 
+$strInnoDBAutoextendIncrementDesc = 'El tamao a incrementar para que se extienda el ancho de una tabla capaz de autoextenderse cuando se llena.'; 
+$strInnoDBBufferPoolSize = 'Tamao de la memoria (bfer) de trnsito comn';
+$strInnoDBBufferPoolSizeDesc = 'El tamao del de memoria intermedia (bfer) usado por InnoDB para almacenar, en el cache, los datos e ndices de sus tablas.';
+$strInnoDBDataFilePath = 'Archivos de datos'; 
+$strInnoDBDataHomeDir = 'Directorio raz de los datos';
+$strInnoDBDataHomeDirDesc = 'La parte constante de la ruta del directorio para todos los archivos de datos InnoDB.'; 
+$strInnoDBPages = 'pginas';
 $strInnodbStat = 'Estado del InnoDB';
 $strInsecureMySQL = 'Su archivo de configuracin contiene parmetros (root sin contrasea) que corresponden a la cuenta privilegiada predeterminada de MySQL. Su servidor de MySQL est usando estos valores, que constituyen una vulnerabilidad.  Se le recomienda corregir esta brecha de seguridad.';
 $strInsert = 'Insertar';
@@ -335,6 +365,7 @@ $strKorean = 'Coreano';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'opciones LaTeX';
 $strLandscape = 'Orientacin horizontal';
+$strLatchedPages = 'Pginas vinculadas';
 $strLatexCaption = 'Subtitulado de la tabla';
 $strLatexContent = 'Contenido de la tabla __TABLE__';
 $strLatexContinued = '(contina)';
@@ -347,11 +378,11 @@ $strLengthSet = 'Longitud/Valores*';
 $strLimitNumRows = 'registros por pgina';
 $strLineFeed = 'Retorno de carro: \\n';
 $strLinesTerminatedBy = 'Lneas terminadas en';
-$strLinkNotFound = 'Enlace no encontrado';
+$strLinkNotFound = 'No se encontr el enlace';
 $strLinksTo = 'Enlaces a';
 $strLithuanian = 'Lituano';
-$strLoadExplanation = 'El mejor mtodo es revisado en forma predeterminada, pero puede cambiarla si fracasa.';
-$strLoadMethod = 'CARGAR mtodo';
+$strLoadExplanation = 'El mejor mtodo es revisado en forma predeterminada, pero puede cambiarlo si fracasa.';
+$strLoadMethod = 'Mtodo de carga de datos';
 $strLocalhost = 'Local';
 $strLocationTextfile = 'Localizacin del archivo de texto';
 $strLogPassword = 'Contrasea:';
@@ -360,6 +391,7 @@ $strLogUsername = 'Usuario:';
 $strLogin = 'Identificacin';
 $strLoginInformation = 'Informacin acerca del login';
 $strLogout = 'Salir';
+$strLongOperation = 'Esta operacin podra tomar algn tiempo. Procedo de todas formas?';
 
 $strMIMETypesForTable = 'MIME TYPES PARA LA TABLA';
 $strMIME_MIMEtype = 'MIME-type';
@@ -373,7 +405,7 @@ $strMIME_transformation_options = 'Opciones de transformacin';
 $strMIME_transformation_options_note = 'Por favor ingrese los valores para las opciones de transformacin usando este formato: \'a\',\'b\',\'c\'...<br />Si alguna vez requiere insertar un Backslash ("\") o comilla sencilla ("\'") entre esos valores, use backslash (por ejemplo \'\\\\xyz\' o \'a\\\'b\').';
 $strMIME_without = 'MIME-types impresos en itlicas no tienen una funcin de transformacin adicional';
 $strMaximumSize = 'Tamao mximo: %s%s';
-$strMbExtensionMissing = 'No se hall la extensin PHP mbstring y al parecer usted est usando tipografa multibyte. phpMyAdmin no puede cortar los strings correctamente sin la extensin mbstring y podra dar resultados inesperados.';
+$strMbExtensionMissing = 'No se hall la extensin PHP mbstring y al parecer usted est usando tipografa multibyte. phpMyAdmin no puede cortar correctamente las cadenas de caracteres sin la extensin mbstring y podra dar resultados inesperados.';
 $strMbOverloadWarning = 'Usted ha activado mbstring.func_overload en su configuracin PHP. Esta opcin es incompatible con phpMyAdmin y podra causar la prdida de algunos datos!';
 $strModifications = 'Se han guardado las modificaciones';
 $strModify = 'Modificar';
@@ -384,6 +416,18 @@ $strMoveTableOK = 'La tabla %s ha sido movida a %s.';
 $strMoveTableSameNames = 'No es posible mover la tabla a la misma!';
 $strMultilingual = 'multilinge';
 $strMustSelectFile = 'Debe seleccionar el archivo que desea insertar.';
+$strMyISAMDataPointerSize = 'Tamao del puntero de datos';
+$strMyISAMDataPointerSizeDesc = 'El tamao predeterminado del puntero de datos en bytes, para su uso en CREATE TABLE para las tablas MyISAM cuando no se ha especificado la opcin MAX_ROWS.';
+$strMyISAMMaxExtraSortFileSize = 'Tamao mximo de los archivos temporales durante la generacin del ndice'; 
+$strMyISAMMaxExtraSortFileSizeDesc = 'Si el archivo temporal usado para la generacin rpida de ndices MyISAM fuese mayor que el uso del key cache por la cantidad especificada aqu, prefiera el mtodo key cache.';
+$strMyISAMMaxSortFileSize = 'Tamao mximo para los archivos temporales generados durante la organizacin';
+$strMyISAMMaxSortFileSizeDesc = 'El tamao mximo del archivo temporal que MySQL puede generar mientras genera un nuevo ndice MyISAM of the temporary file (durante REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Modalidad de recuperacin automtica';
+$strMyISAMRecoverOptionsDesc = 'La modalidad para la recuperacin automtica de tablas MyISAM cadas catastrficamente, como fuera determinado mediante la opcin al arranque del servidor --myisam-recover.'; 
+$strMyISAMRepairThreads = 'Reparar los threads'; 
+$strMyISAMRepairThreadsDesc = 'Si este valor es superior a 1, se generan los ndices de las tablas MyISAM en paralelo (cada ndice con su propio thread) durante el proceso Repare mediante organizacin.';
+$strMyISAMSortBufferSize = 'Organizar el tamao del bfer de memoria';
+$strMyISAMSortBufferSizeDesc = 'La cantidad de memoria que se asigna para organizar los ndices MyISAM durante la operacin REPAIR TABLE o cuando se generan ndices con CREATE INDEX o ALTER TABLE.';
 $strMySQLCharset = 'Juegos de caracteres de MySQL';
 $strMySQLConnectionCollation = 'Cotejamiento (collation) de las conexiones MySQL';
 $strMySQLReloaded = 'Reinicio de MySQL.';
@@ -401,6 +445,7 @@ $strNoActivity = 'No ha habido actividad desde hace %s o ms segundos, por favor
 $strNoDatabases = 'No hay bases de datos';
 $strNoDatabasesSelected = 'No se seleccionaron bases de datos.';
 $strNoDescription = 'Sin descripcin';
+$strNoDetailsForEngine = 'No existe informacin detallada acerca de las condiciones en que se encuentra este motor de almacenamiento.';
 $strNoDropDatabases = '"DROP DATABASE" los enunciados ("sentences") estn deshabilitados.';
 $strNoExplain = 'Saltarse la explicacin del SQL';
 $strNoFrames = 'phpMyAdmin funciona mejor con un navegador que <b>soporte marcos (frames)</b>.';
@@ -431,23 +476,24 @@ $strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultado(s)';
 $strNumTables = 'Tablas';
 
 $strOK = 'OK';
-$strOftenQuotation = 'A menudo son comillas. OPCIONALMENTE significa que nicamente los campos char y varchar estn encerrados por el caracter "comillas".';
+$strOftenQuotation = 'Usualmente son comillas. OPCIONAL significa que nicamente los campos char y varchar sern encerrados por "comillas".';
 $strOperations = 'Operaciones';
 $strOperator = 'Operador';
 $strOptimizeTable = 'Optimizar la tabla';
 $strOptionalControls = 'Es opcional. Controla el modo de escribir o leer caracteres especiales.';
-$strOptionally = 'OPCIONALMENTE';
+$strOptionally = 'OPCIONAL';
 $strOr = 'O';
 $strOverhead = 'Residuo a depurar';
 $strOverwriteExisting = 'Sobreescribir el(los) archivo(s) existente(s)';
 
-$strPHP40203 = 'Usted est usando PHP 4.2.3, el cual tiene un error de codificacin en cuanto a los "strings multi-byte" (mbstring). Lea el reporte 19404 de PHP. Esta versin de PHP no est recomendada para ser usada con phpMyAdmin.';
+$strPHP40203 = 'Usted est usando PHP 4.2.3, el cual tiene un error de codificacin en cuanto a las "cadenas de caracteres multi-byte" (mbstring). Lea el reporte 19404 de PHP. No se recomienda el uso de phpMyAdmin con esta versin de PHP.';
 $strPHPVersion = 'Versin de PHP';
 $strPageNumber = 'Nmero de pgina:';
+$strPagesToBeFlushed = 'Pginas que sern eliminadas'; 
 $strPaperSize = 'Tamao del papel';
 $strPartialText = 'Textos parciales';
 $strPassword = 'Contrasea';
-$strPasswordChanged = 'La contrasea para %s fue cambiada exitosamente.';
+$strPasswordChanged = 'La contrasea para %s se cambi exitosamente.';
 $strPasswordEmpty = 'La contrasea est vaca!';
 $strPasswordHashing = 'Hashing de la contrasea';
 $strPasswordNotSame = 'Las contraseas no coinciden!';
@@ -519,6 +565,7 @@ $strQueryType = 'Tipo de consulta';
 $strQueryWindowLock = 'No sobreescriba esta consulta desde fuera de la ventana';
 
 $strReType = 'Re-escriba';
+$strReadRequests = 'Lea las solicitudes';
 $strReceived = 'Recibido';
 $strRecords = 'Registros';
 $strReferentialIntegrity = 'Compruebe la integridad referencial:';
@@ -538,8 +585,8 @@ $strRenameTableOK = 'Tabla %s ahora se llama %s';
 $strRepairTable = 'Reparar la tabla';
 $strReplace = 'Reemplazar';
 $strReplaceNULLBy = 'Reemplace NULL con';
-$strReplaceTable = 'Reemplazar los datos de la tabla con archivo';
-$strReset = 'Reset';
+$strReplaceTable = 'Reemplazar los datos de la tabla con los del archivo';
+$strReset = 'Reiniciar';
 $strResourceLimits = 'Lmites de recursos';
 $strRevoke = 'Revocar';
 $strRevokeAndDelete = 'Revocar todos los privilegios activos de los usuarios y brrelos despus.';
@@ -621,6 +668,7 @@ $strSingly = '(solo)';
 $strSize = 'Tamao';
 $strSlovak = 'Eslovaco'; 
 $strSlovenian = 'Esloveno';
+$strSocketProblem = '(o el socket del servidor MySQL local no est configurado correctamente)';
 $strSort = 'Ordenar';
 $strSortByKey = 'Organizar segn la clave';
 $strSpaceUsage = 'Espacio utilizado';
@@ -631,16 +679,18 @@ $strStatCreateTime = 'Creacin';
 $strStatUpdateTime = 'ltima actualizacin';
 $strStatement = 'Enunciado';
 $strStatus = 'Estado actual';
+$strStorageEngine = 'Motor de almacenamiento';
+$strStorageEngines = 'Motores de almacenamiento';
 $strStrucCSV = 'Datos CSV ';
 $strStrucData = 'Estructura y datos';
-$strStrucDrop = 'Aadir DROP TABLE';
+$strStrucDrop = 'Aada DROP TABLE';
 $strStrucExcelCSV = 'CSV para datos de MS Excel';
 $strStrucNativeExcel = 'Datos de MS Excel en formato nativo';
 $strStrucOnly = 'nicamente la estructura ';
 $strStructPropose = 'Planteamiento de una estructura de tabla';
 $strStructure = 'Estructura';
 $strSubmit = 'Enviar';
-$strSuccess = 'Su consulta ha sido ejecutada con xito';
+$strSuccess = 'Su consulta se ejecut con xito';
 $strSum = 'Nmero de filas';
 $strSwedish = 'Sueco';
 $strSwitchToDatabase = 'Seleccione la base de datos copiada';
@@ -663,12 +713,12 @@ $strTblPrivileges = 'Privilegios especficos para la tabla';
 $strTextAreaLength = ' Debido a su longitud,<br /> este campo puede no ser editable ';
 $strThai = 'Tailands';
 $strTheContent = 'Se insert el contenido de su archivo.';
-$strTheContents = 'El contenido del archivo reemplaza el contenido de la tabla seleccionada para las columnas idnticas primarias o nicas.';
-$strTheTerminator = 'El terminador de los campos.';
+$strTheContents = 'El contenido del archivo reemplaza al contenido de la tabla seleccionada para las columnas idnticas primarias o nicas.';
+$strTheTerminator = 'El separador de los campos.';
 $strTheme = 'Tema / Estilo';
 $strThisHost = 'Este Host';
 $strThisNotDirectory = 'Esto no fue un directorio';
-$strThreadSuccessfullyKilled = 'El thread %s fue destruido exitosamente.';
+$strThreadSuccessfullyKilled = 'El hilo (thread) %s fue destruido exitosamente.';
 $strTime = 'Tiempo';
 $strToggleScratchboard = 'toggle scratchboard';
 $strTotal = 'total';
@@ -676,7 +726,7 @@ $strTotalUC = 'Total';
 $strTraditionalChinese = 'Chino tradicional';
 $strTraditionalSpanish = 'Espaol tradicional';
 $strTraffic = 'Trfico';
-$strTransformation_application_octetstream__download = 'Muestre un enlace para descargar los datos binarios de un campo. La primera opcin es el nombre del archivo binario.  La segunda opcin es un nombre de campo factible de una fila de la tabla que contiene el nombre del campo. Si usted aporta una segunda opcin, necesariamente deber consignar la primera opcin a un "string" vaco';
+$strTransformation_application_octetstream__download = 'Muestre un enlace para descargar los datos binarios de un campo. La primera opcin es el nombre del archivo binario.  La segunda opcin es un nombre de campo factible de una fila de la tabla que contiene el nombre del campo. Si usted aporta una segunda opcin, necesariamente deber consignar la primera opcin a una cadena de caracteres vaca';
 $strTransformation_image_jpeg__inline = 'Muestra un thumbnail que puede abrirse mediante un clic; opciones: width, height en pxeles (mantiene la proporcin original)';
 $strTransformation_image_jpeg__link = 'Muestra un enlace a esta imagen (blob download directo, i.e.).';
 $strTransformation_image_png__inline = 'Ver imagen/jpeg: inline';
@@ -685,7 +735,7 @@ $strTransformation_text_plain__external = 'LINUX SOLAMENTE: Ejecuta una aplicaci
 $strTransformation_text_plain__formatted = 'Mantiene el formato original del campo. No se puede hacer Escape.';
 $strTransformation_text_plain__imagelink = 'Muestra una imagen y un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es el ancho en pxeles, el tercero es el alto.';
 $strTransformation_text_plain__link = 'Muestra un enlace, el campo contiene el nombre del archivo; la primera opcin es un prefijo como "http://dominio.com/", la segunda opcin es un ttulo para el enlace.';
-$strTransformation_text_plain__substr = 'Solamente muestra una parte del string. La primera opcin es un offset para definir en dnde empieza el output de su texto (Predeterminado 0). La segunda opcin es un offset para definir cunto texto es retornado. Si est vaco, regresa todo el texto restante. La tercera opcin define cules chars se adjuntarn al output cuando se regrese un substring (Predeterminado: ...) .';
+$strTransformation_text_plain__substr = 'Muestra una parte de una cadena de caracteres. La primera opcin es el nmero de caracteres a pasar por alto desde el principio de la cadena de caracteres (Predeterminado: 0). La segunda opcin es el nmero de caracteres a mostrar (Predeterminado: hasta el final de la cadena de caracteres). La tercera opcin es la cadena de caracteres a adjuntar y/o anteponer cuando haya truncamiento (Predeterminado: "...").';
 $strTransformation_text_plain__unformatted = 'Muestra el cdigo HTML como entidades HTML. No se muestra formato HTML.';
 $strTruncateQueries = 'Trunque las consultas que ya se han mostrado';
 $strTurkish = 'Turco';
@@ -699,7 +749,7 @@ $strUnknown = 'desconocido';
 $strUnselectAll = 'Deseleccione todo';
 $strUpdComTab = 'Para actualizar su tabla Columna_comentarios (Column_comments), por favor revise la documentacin';
 $strUpdatePrivMessage = 'Ud. ha actualizado los privilegios para %s.';
-$strUpdateProfileMessage = 'Se ha actualizado el perfil.';
+$strUpdateProfileMessage = 'Se actualiz el perfil.';
 $strUpdateQuery = 'Modificar la consulta';
 $strUpgrade = 'Usted debera actualizar su %s a la versin %s o ms reciente.';
 $strUsage = 'Uso';
@@ -722,9 +772,12 @@ $strValidateSQL = 'Validar el SQL';
 $strValidatorError = 'El validador de SQL no pudo inicializarse. Por favor revise si ha instalado las extensiones php necesarias, como fueron descritas en la %sdocumentacin%s.';
 $strValue = 'Valor';
 $strVar = 'Variable';
+$strVersionInformation = 'Acerca de esta versin';
+$strView = 'Visualizar';
 $strViewDump = 'Mostrar el volcado esquema de la tabla';
 $strViewDumpDB = 'Ver el volcado esquema de la base de datos';
 $strViewDumpDatabases = 'Ver el dump (schema) de la base de datos';
+$strViewHasBeenDropped = 'Se descart el modo de visualizacin %s';
 
 $strWebServerUploadDirectory = 'directorio en el servidor web para subir los archivos';
 $strWebServerUploadDirectoryError = 'No est disponible el directorio que usted habilit para subir las tareas';
@@ -733,6 +786,7 @@ $strWestEuropean = 'Europea occidental';
 $strWildcard = 'comodn';
 $strWindowNotFound = 'La ventana del navegador no pudo actualizarse. Quiz cerr la ventana principal o su navegador est bloqueando las actualizaciones en ventanas mltiples debido a sus parmetros de seguridad.';
 $strWithChecked = 'Con marca:';
+$strWriteRequests = 'Escriba las solicitudes';
 $strWritingCommentNotPossible = 'No fue posible escribir el comentario';
 $strWritingRelationNotPossible = 'No fue posible escribir la relacin';
 $strWrongUser = 'Usuario/contrasea equivocado. Acceso denegado.';
@@ -744,4 +798,20 @@ $strYes = 'S';
 $strZeroRemovesTheLimit = 'Nota: si cambia los parmetros de estas opciones a 0 (cero), remueve el lmite.';
 $strZip = '"comprimido con zip"';
 
+// To translate:
+
+$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
+$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
+$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
+$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
+$strPrivDescCreateView = 'Allows creating new views.';  //to translate
+$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
+$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
+
+$strRoutines = 'Routines';  //to translate
+
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
+$strGeneratePassword = 'Generate Password';  //to translate
+$strGenerate = 'Generate';  //to translate
+$strCopy = 'Copy';  //to translate
 ?>
