@@ -1,5 +1,9 @@
 <?php
-/* $Id: swedish-iso-8859-1.inc.php,v 2.58 2004/12/30 20:38:11 lem9 Exp $ */
+/* $Id: swedish-iso-8859-1.inc.php,v 2.78.2.2 2005/06/30 19:49:02 lem9 Exp $ */
+
+/*
+ * Translated by Bjrn T. Hallberg <bjornth at users.sourceforge.net>
+ */
 
 $charset = 'iso-8859-1';
 $text_dir = 'ltr';
@@ -27,7 +31,7 @@ $strAddAutoIncrement = 'Lgg till AUTO_INCREMENT-vrde';
 $strAddConstraints = 'Lgg till restriktioner';
 $strAddDeleteColumn = 'Lgg till/ta bort fltkolumner';
 $strAddDeleteRow = 'Lgg till/ta bort villkorsrader';
-$strAddDropDatabase = 'Lgg till \'DROP DATABASE\'';
+$strAddDropDatabase = 'Lgg till DROP DATABASE';
 $strAddFields = 'Lgg till %s flt';
 $strAddHeaderComment = 'Lgg till egen kommentar i huvud (\\n delar rader)';
 $strAddIfNotExists = 'Lgg till IF NOT EXISTS';
@@ -46,6 +50,7 @@ $strAffectedRows = 'Pverkade rader:';
 $strAfter = 'Efter %s';
 $strAfterInsertBack = 'G tillbaka till fregende sida';
 $strAfterInsertNewInsert = 'Lgg till ytterligare en ny rad';
+$strAfterInsertNext = 'ndra nsta rad';
 $strAfterInsertSame = 'G tillbaka till denna sida';
 $strAll = 'Alla';
 $strAllTableSameWidth = 'Visa alla tabeller med samma bredd';
@@ -80,7 +85,7 @@ $strBinary = 'Binr';
 $strBinaryDoNotEdit = 'Binr - ndra inte';
 $strBinaryLog = 'Binr logg';
 $strBookmarkAllUsers = 'Lt varje anvndare f tillgng till detta bokmrke';
-$strBookmarkDeleted = 'Bokmrket har raderats.';
+$strBookmarkDeleted = 'Bokmrket har tagits bort.';
 $strBookmarkLabel = 'Etikett';
 $strBookmarkOptions = 'Bokmrkesalternativ';
 $strBookmarkQuery = 'Bokmrkt SQL-frga';
@@ -88,17 +93,25 @@ $strBookmarkThis = 'Skapa bokmrke fr den hr SQL-frgan';
 $strBookmarkView = 'Visa endast';
 $strBrowse = 'Visa';
 $strBrowseForeignValues = 'Visa frmmande vrden';
+$strBufferPool = 'Buffertutrymme';
+$strBufferPoolActivity = 'Buffertaktivitet';
+$strBufferPoolUsage = 'Buffertanvndning';
+$strBufferReadMisses = 'Lsmissar';
+$strBufferReadMissesInPercent = 'Lsmissar i %';
+$strBufferWriteWaits = 'Skrivvntanden';
+$strBufferWriteWaitsInPercent = 'Skrivvntanden i %';
 $strBulgarian = 'Bulgarisk';
-$strBzError = 'phpMyAdmin kunde inte komprimera SQL-satserna p grund av en trasig Bz2-utvidgning i denna php-version. Det rekommenderas starkt att stta direktivet <code>$cfg[\'BZipDump\']</code> i din phpMyAdmin-konfigurationsfil till <code>FALSE</code>. Om du vill anvnda Bz2-komprimering, br du uppgradera till en senare php-version. Se php:s buggrapport %s fr detaljer.';
+$strBusyPages = 'Upptagna sidor';
+$strBzError = 'phpMyAdmin kunde inte komprimera SQL-satserna p grund av ett trasigt Bz2-tillgg i denna PHP-version. Det rekommenderas starkt att stta direktivet <code>$cfg[\'BZipDump\']</code> i din phpMyAdmin-konfigurationsfil till <code>FALSE</code>. Om du vill anvnda Bz2-komprimering, br du uppgradera till en senare PHP-version. Se PHP:s buggrapport %s fr detaljer.';
 $strBzip = '"bzippad"';
 
 $strCSVOptions = 'CSV-alternativ';
 $strCalendar = 'Kalender';
 $strCannotLogin = 'Kan ej logga in p MySQL-server';
 $strCantLoad = 'kan inte ladda %s-tillgg,<br />var god kontrollera PHP-konfigurationen.';
-$strCantLoadRecodeIconv = 'Kan inte ladda utkningarna iconv eller recode som behvs fr teckenuppsttningsomvandling. Konfigurera php fr att tillta dessa utkningar eller stng av teckenuppsttningsomvandling i phpMyAdmin.';
+$strCantLoadRecodeIconv = 'Kan inte ladda tillggen iconv eller recode som behvs fr teckenuppsttningsomvandling. Antingen konfigurera PHP fr att tillta dessa tillgg eller stng av teckenuppsttningsomvandling i phpMyAdmin.';
 $strCantRenameIdxToPrimary = 'Kan inte byta namn p index till "PRIMARY"!';
-$strCantUseRecodeIconv = 'Kan inte anvnda funktionerna iconv, libiconv eller recode_string nr utkade rapporter ska laddas. Kontrollera din php-konfiguration.';
+$strCantUseRecodeIconv = 'Kan inte anvnda varken funktionen iconv, libiconv eller recode_string, fastn de ndvndiga tillggen verkar vara laddade. Kontrollera din PHP-konfiguration.';
 $strCardinality = 'Kardinalitet';
 $strCarriage = 'Vagnretur: \\r';
 $strCaseInsensitive = 'skiftlgesoknsligt';
@@ -133,19 +146,21 @@ $strCommentsForTable = 'KOMMENTARER FR TABELL';
 $strCompatibleHashing = 'Kompatibel med MySQL&nbsp;4.0';
 $strCompleteInserts = 'Kompletta infogningar';
 $strCompression = 'Komprimering';
-$strConfigFileError = 'phpMyAdmin kunde inte lsa din konfigurationsfil!<br />Detta kan intrffa om php hittar ett fel i den eller om php inte hittar filen.<br />Anropa konfigurationsfilen direkt mha lnken nedan och ls php:s felmeddelande(n) som du erhller. I de flesta fall saknas ett citationstecken eller ett semikolon ngonstans.<br />Om du erhller en tom sida r allt bra.';
+$strConfigFileError = 'phpMyAdmin kunde inte lsa din konfigurationsfil!<br />Detta kan intrffa om PHP hittar ett fel i den eller om PHP inte hittar filen.<br />Anropa konfigurationsfilen direkt mha lnken nedan och ls PHP:s felmeddelande(n) som du erhller. I de flesta fall saknas ett citationstecken eller ett semikolon ngonstans.<br />Om du erhller en tom sida r allt bra.';
 $strConfigureTableCoord = 'Var god ange koordinaterna fr tabellen %s';
 $strConnectionError = 'Kan ej skapa frbindelse: ogiltiga instllningar.';
 $strConnections = 'Uppkopplingar';
 $strConstraintsForDumped = 'Restriktioner fr dumpade tabeller';
 $strConstraintsForTable = 'Restriktioner fr tabell';
 $strCookiesRequired = 'Kakor (cookies) mste tilltas fr att g vidare.';
+$strCopy = 'Kopiera';
 $strCopyDatabaseOK = 'Databas %s har kopierats till %s';
 $strCopyTable = 'Kopiera tabellen till (databas<b>.</b>tabell):';
 $strCopyTableOK = 'Tabellen %s har kopierats till %s.';
 $strCopyTableSameNames = 'Kan inte kopiera tabell till samma namn!';
 $strCouldNotKill = 'phpMyAdmin kunde inte dda trd %s. Troligtvis har den redan avslutats.';
 $strCreate = 'Skapa';
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE fre kopiering';
 $strCreateIndex = 'Skapa ett index fr&nbsp;%s&nbsp;kolumn(er)';
 $strCreateIndexTopic = 'Skapa ett nytt index';
 $strCreateNewDatabase = 'Skapa ny databas';
@@ -175,6 +190,7 @@ $strDanish = 'Dansk';
 $strData = 'Data';
 $strDataDict = 'Datalexikon';
 $strDataOnly = 'Enbart data';
+$strDataPages = 'Sidor innehllande data';
 $strDatabase = 'Databas';
 $strDatabaseEmpty = 'Databasens namn r tomt!';
 $strDatabaseExportOptions = 'Exportalternativ fr databas';
@@ -189,7 +205,8 @@ $strDatabasesStatsHeavyTraffic = 'Anm: Att sl p databastatistik hr kan orsaka tu
 $strDbPrivileges = 'Databasspecifika privilegier';
 $strDbSpecific = 'databasspecifik';
 $strDefault = 'Standard';
-$strDefaultValueHelp = 'Fr standardvrden, ange endast ett enstaka vrde, utan baktstreck eller citattecken, i formatet: a';
+$strDefaultEngine = '%s r standardlagringsmotorn p denna MySQL-server.';
+$strDefaultValueHelp = 'Fr standardvrden, ange endast ett enstaka vrde, utan baktstreck eller citattecken, enligt formatet: a';
 $strDefragment = 'Defragmentera tabell';
 $strDelOld = 'Nuvarande sida har referenser till tabeller som inte lngre existerar. Vill du ta bort dessa referenser?';
 $strDelayedInserts = 'Anvnd frdrjda infogningar';
@@ -202,12 +219,13 @@ $strDeleting = 'Tar bort %s';
 $strDescending = 'Fallande';
 $strDescription = 'Beskrivning';
 $strDictionary = 'lexikon';
+$strDirtyPages = 'Orena sidor';
 $strDisableForeignChecks = 'Stng av kontroll av frmmande nycklar';
 $strDisabled = 'Avaktiverat';
 $strDisplayFeat = 'Visningsfunktionaliteter';
 $strDisplayOrder = 'Visningsordning:';
 $strDisplayPDF = 'Visa PDF-schema';
-$strDoAQuery = 'Utfr en "Query by Example" (jokertecken: "%")';
+$strDoAQuery = 'Utfr en "Query By Example" (jokertecken: "%")';
 $strDoYouReally = 'Vill du verkligen ';
 $strDocu = 'Dokumentation';
 $strDrop = 'Radera';
@@ -230,6 +248,10 @@ $strEncloseInTransaction = 'Inneslut export i en transaktion';
 $strEnd = 'Slutet';
 $strEndCut = 'SLUT URKLIPP';
 $strEndRaw = 'SLUT RTEXT';
+$strEngineAvailable = '%s r tillgnglig p denna MySQL-server.';
+$strEngineDisabled = '%s har stngts av p denna MySQL-server.';
+$strEngineUnsupported = 'Denna MySQL-server har inte std fr lagringsmotorn %s.';
+$strEngines = 'Motorer';
 $strEnglish = 'Engelsk';
 $strEnglishPrivileges = ' Obs! MySQL-privilegiumnamn anges p engelska ';
 $strError = 'Fel';
@@ -251,7 +273,7 @@ $strFieldsEmpty = ' Antalet flt r noll! ';
 $strFieldsEnclosedBy = 'Flten omges av';
 $strFieldsEscapedBy = 'Specialtecken i flt fregs av';
 $strFieldsTerminatedBy = 'Flten avslutas med';
-$strFileAlreadyExists = 'Filen %s finns redan p servern, ndra filnamnet eller kryssa i skriv ver-alternativet.';
+$strFileAlreadyExists = 'Filen %s finns redan p servern. ndra filnamnet eller kryssa i skriv ver-alternativet.';
 $strFileCouldNotBeRead = 'Filen kunde inte lsas';
 $strFileNameTemplate = 'Mall fr filnamn';
 $strFileNameTemplateHelp = 'Anvnd __DB__ fr databasnamn, __TABLE__ fr tabellnamn och %sstrftime%s-alternativ fr specificering av tid. Filndelse lggs till automagiskt. All annan text kommer att bevaras.';
@@ -261,12 +283,15 @@ $strFlushPrivilegesNote = 'Anm: phpMyAdmin hmtar anvndarnas privilegier direkt f
 $strFlushTable = 'Rensa tabell';
 $strFormEmpty = 'Vrde saknas i formulret!';
 $strFormat = 'Format';
+$strFreePages = 'Fria sidor';
 $strFullText = 'Fullstndiga texter';
 $strFunction = 'Funktion';
 
 $strGenBy = 'Genererad av';
 $strGenTime = 'Skapad';
 $strGeneralRelationFeat = 'Allmnna relationsfunktionaliteter';
+$strGenerate = 'Generera';
+$strGeneratePassword = 'Generera lsenord';
 $strGeorgian = 'Georgisk';
 $strGerman = 'Tysk';
 $strGlobal = 'global';
@@ -277,6 +302,10 @@ $strGrantOption = 'Grant';
 $strGreek = 'Grekisk';
 $strGzip = '"gzippad"';
 
+$strHTMLExcel = 'Microsoft Excel 2000';
+$strHTMLExcelOptions = 'Microsoft Excel 2000 exportalternativ';
+$strHTMLWord = 'Microsoft Word 2000';
+$strHTMLWordOptions = 'Microsoft Word 2000 exportalternativ';
 $strHasBeenAltered = 'har ndrats.';
 $strHasBeenCreated = 'har skapats.';
 $strHaveToShow = 'Du mste vlja minst en kolumn som ska visas';
@@ -293,7 +322,7 @@ $strId = 'ID';
 $strIdxFulltext = 'Heltext';
 $strIfYouWish = 'Om du vill ladda enbart ngra av tabellens kolumner, ange en kommaseparerad fltlista.';
 $strIgnore = 'Ignorera';
-$strIgnoreInserts = 'Anvnd IGNORE i insert-kommando';
+$strIgnoreInserts = 'Anvnd IGNORE i infogningar';
 $strIgnoringFile = 'Ignorerar fil %s';
 $strImportDocSQL = 'Importera docSQL-filer';
 $strImportFiles = 'Importera filer';
@@ -308,6 +337,14 @@ $strIndexWarningPrimary = 'PRIMARY- och INDEX-nycklar skall inte bda sttas fr ko
 $strIndexWarningTable = 'Problem med index fr tabell `%s`';
 $strIndexWarningUnique = 'UNIQUE- och INDEX-nycklar skall inte bda sttas fr kolumn `%s`';
 $strIndexes = 'Index';
+$strInnoDBAutoextendIncrement = 'Automatisk utkningsstorlek';
+$strInnoDBAutoextendIncrementDesc = 'Tillkningsstorleken vid automatisk utkning av tabellutrymme nr det blir fullt.';
+$strInnoDBBufferPoolSize = 'Buffertstorlek';
+$strInnoDBBufferPoolSizeDesc = 'Storleken p minnesbufferten som InnoDB anvnder fr cache av data och index till sina tabeller.';
+$strInnoDBDataFilePath = 'Datafiler';
+$strInnoDBDataHomeDir = 'Hemkatalog fr data';
+$strInnoDBDataHomeDirDesc = 'Den gemensamma delen av skvgen fr alla InnoDB-datafiler.';
+$strInnoDBPages = 'sidor';
 $strInnodbStat = 'InnoDB-status';
 $strInsecureMySQL = 'Din konfigurationsfil innehller instllningar (root-konto utan lsenord) som motsvarar MySQL:s privilegierade standardkonto. Din MySQL-server krs med denna standardinstllning och r ppen fr intrng, s du br verkligen tppa till detta skerhetshl.';
 $strInsert = 'Lgg till';
@@ -323,7 +360,7 @@ $strInternalRelations = 'Interna relationer';
 
 $strJapanese = 'Japansk';
 $strJumpToDB = 'Hoppa till databas &quot;%s&quot;.';
-$strJustDelete = 'Ta bara bort anvndarna frn privilegiumtabellerna.';
+$strJustDelete = 'Ta endast bort anvndarna frn privilegiumtabellerna.';
 $strJustDeleteDescr = 'De &quot;borttagna&quot; anvndarna kommer fortfarande kunna komma t servern som vanligt tills privilegierna laddas om.';
 
 $strKeepPass = 'ndra inte lsenordet';
@@ -334,6 +371,7 @@ $strKorean = 'Koreansk';
 $strLaTeX = 'LaTeX';
 $strLaTeXOptions = 'LaTeX-alternativ';
 $strLandscape = 'Liggande';
+$strLatchedPages = 'Lsta sidor';
 $strLatexCaption = 'Tabellrubrik';
 $strLatexContent = 'Innehll i tabell __TABLE__';
 $strLatexContinued = '(fortsttning)';
@@ -359,19 +397,22 @@ $strLogUsername = 'Anvndarnamn:';
 $strLogin = 'Logga in';
 $strLoginInformation = 'Inloggningsinformation';
 $strLogout = 'Logga ut';
+$strLongOperation = 'Denna operation kan ta lng tid. Frstt nd?';
 
 $strMIMETypesForTable = 'MIME-TYPER FR TABELL';
 $strMIME_MIMEtype = 'MIME-typ';
 $strMIME_available_mime = 'Tillgngliga MIME-typer';
 $strMIME_available_transform = 'Tillgngliga omvandlingar';
 $strMIME_description = 'Beskrivning';
-$strMIME_nodescription = 'Beskrivning fr denna omvandling finns inte tillgnglig.<br />Vnligen frga upphovsmannen vad %s gr.';
+$strMIME_nodescription = 'Ingen beskrivning fr denna omvandling finns tillgnglig.<br />Vnligen frga upphovsmannen vad %s gr.';
 $strMIME_transformation = 'Webblsaromvandling';
 $strMIME_transformation_note = 'Fr en lista med tillgngliga omvandlingsparametrar och deras MIME-typomvandlingar, klicka p %somvandlingsbeskrivningar%s';
 $strMIME_transformation_options = 'Omvandlingsparametrar';
 $strMIME_transformation_options_note = 'Ange vrdena fr omvandlingsparametrar enligt fljande format: \'a\',\'b\',\'c\'...<br />Om du behver lgga till ett baktstreck ("\") eller ett enkelcitat ("\'") i vrdena, skriv ett baktstreck fre tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
 $strMIME_without = 'Kursiverade MIME-typer har inte ngon separat omvandlingsfunktion';
 $strMaximumSize = 'Maximal storlek: %s%s';
+$strMbExtensionMissing = 'PHP-tillgget mbstring kunde inte hittas och det verkar som om du anvnder flerbitars teckenuppsttning. phpMyAdmin kan inte dela upp strngar korrekt utan tillgget mbstring, vilket kan leda till ovntade resultat.';
+$strMbOverloadWarning = 'Du har aktiverat mbstring.func_overload i din PHP-konfiguration. Detta alternativ r inkompatibelt med phpMyAdmin och kan orsaka att en del data frstrs!';
 $strModifications = 'ndringarna har sparats';
 $strModify = 'ndra';
 $strModifyIndexTopic = 'ndra ett index';
@@ -381,8 +422,20 @@ $strMoveTableOK = 'Tabellen %s har flyttats till %s.';
 $strMoveTableSameNames = 'Kan inte flytta tabell till samma namn!';
 $strMultilingual = 'flersprkig';
 $strMustSelectFile = 'Vlj filen som du vill importera.';
+$strMyISAMDataPointerSize = 'Storlek fr datapekare';
+$strMyISAMDataPointerSizeDesc = 'Standardpekarens storlek i bytes, vilken anvnds av CREATE TABLE fr MyISAM-tabeller nr inget MAX_ROWS-alternativ r specificerat.';
+$strMyISAMMaxExtraSortFileSize = 'Maximal storlek fr temporra filer vid skapande av index';
+$strMyISAMMaxExtraSortFileSizeDesc = 'Om den temporra filen som anvnds fr snabbt skapande av MyISAM-index skulle vara strre n att anvnda nyckelcachen vars storlek specificeras hr, s fredras metoden med nyckelcachen.';
+$strMyISAMMaxSortFileSize = 'Maximal storlek fr temporra sorteringsfiler';
+$strMyISAMMaxSortFileSizeDesc = 'Denna maximala storleken fr den temporra filen som MySQL r tillten att anvnda under terskapande av MyISAM-index (vid REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
+$strMyISAMRecoverOptions = 'Automatisk terstllning';
+$strMyISAMRecoverOptionsDesc = 'Instllningen fr automatisk terstllning av kraschade MyISAM-tabeller, som satts via serverns startparameter --myisam-recover.';
+$strMyISAMRepairThreads = 'Reparera trdar';
+$strMyISAMRepairThreadsDesc = 'Om detta vrde r strre n 1 skapas MyISAM-tabellindex parallellt (varje index i sin egen trd) under reparationen vid sorteringsprocess.';
+$strMyISAMSortBufferSize = 'Storlek fr sorteringsbuffert';
+$strMyISAMSortBufferSizeDesc = 'Bufferten som allokeras vid sortering av MyISAM-index under REPAIR TABLE eller vid skapande av index med CREATE INDEX eller ALTER TABLE.';
 $strMySQLCharset = 'MySQL teckenuppsttning';
-$strMySQLConnectionCollation = 'Kollation av MySQL-uppkoppling';
+$strMySQLConnectionCollation = 'Kollation fr MySQL-uppkoppling';
 $strMySQLReloaded = 'MySQL har startats om.';
 $strMySQLSaid = 'MySQL sa: ';
 $strMySQLServerProcess = 'MySQL %pma_s1% krs p %pma_s2% som %pma_s3%';
@@ -398,8 +451,9 @@ $strNoActivity = 'Ingen aktivitet sedan %s sekunder eller mer. Var god logga in
 $strNoDatabases = 'Inga databaser';
 $strNoDatabasesSelected = 'Inga databaser markerade.';
 $strNoDescription = 'Ingen beskrivning';
+$strNoDetailsForEngine = 'Det finns ingen tillgnglig detaljerad statusinformation fr denna lagringsmotor.';
 $strNoDropDatabases = '"DROP DATABASE"-instruktioner r avstngda.';
-$strNoExplain = 'Utan frklaring';
+$strNoExplain = 'Utan SQL-frklaring';
 $strNoFrames = 'phpMyAdmin fungerar tyvrr endast med webblsare som hanterar ramar.';
 $strNoIndex = 'Inga index r definierade!';
 $strNoIndexPartsDefined = 'Inga delar av index r definierade!';
@@ -410,13 +464,13 @@ $strNoPermission = 'Webbservern har inte tilltelse att spara filen %s.';
 $strNoPhp = 'Utan PHP-kod';
 $strNoPrivileges = 'Inga privilegier';
 $strNoQuery = 'Ingen SQL-frga!';
-$strNoRights = 'Du har inte tillrcklig behrighet fr att vara hr!';
+$strNoRights = 'Du har inte tillrcklig behrighet fr att vara hr nu!';
 $strNoRowsSelected = 'Inga rader valda';
 $strNoSpace = 'Otillrckligt utrymme fr att spara filen %s.';
 $strNoTablesFound = 'Inga tabeller funna i databasen.';
-$strNoThemeSupport = 'Std fr teman saknas. Kontrollera din konfiguration och/eller din katalog fr teman %s.';
+$strNoThemeSupport = 'Std fr teman saknas. Kontrollera din konfiguration och/eller dina teman i katalog %s.';
 $strNoUsersFound = 'Hittade ingen anvndare.';
-$strNoValidateSQL = 'Utan validering';
+$strNoValidateSQL = 'Utan SQL-validering';
 $strNone = 'Inget';
 $strNotNumber = 'Det r inte ett nummer!';
 $strNotOK = 'Inte OK';
@@ -426,6 +480,7 @@ $strNull = 'Null';
 $strNumSearchResultsInTable = '%s trff(ar) i tabell <i>%s</i>';
 $strNumSearchResultsTotal = '<b>Totalt:</b> <i>%s</i> trff(ar)';
 $strNumTables = 'Tabeller';
+$strNumberOfFields = 'Antal flt';
 
 $strOK = 'OK';
 $strOftenQuotation = 'Ofta citattecken. Frivilligt innebr att bara flt av typ \'char\' och \'varchar\' omges av angivet tecken.';
@@ -441,6 +496,7 @@ $strOverwriteExisting = 'Skriv ver befintlig fil(er)';
 $strPHP40203 = 'Du anvnder PHP 4.2.3, vilken har en allvarlig bugg med multi-byte-strngar (mbstring). Se PHP:s buggrapport 19404. Denna version av PHP r inte rekommenderad fr anvndning tillsammans med phpMyAdmin.';
 $strPHPVersion = 'PHP-version';
 $strPageNumber = 'Sida:';
+$strPagesToBeFlushed = 'Sidor att rensa';
 $strPaperSize = 'Pappersstorlek';
 $strPartialText = 'Avkortade texter';
 $strPassword = 'Lsenord';
@@ -472,13 +528,19 @@ $strPrintView = 'Utskriftsvnlig visning';
 $strPrintViewFull = 'Utskriftsvnlig visning (med fullstndiga texter)';
 $strPrivDescAllPrivileges = 'Inkluderar alla privilegier utom GRANT.';
 $strPrivDescAlter = 'Tillter ndring av befintliga tabellers struktur.';
+$strPrivDescAlterDb = 'Tillter ndring av befintliga tabellers struktur svl som ndring av standardteckenuppsttningen och kollationering av databaser.';
+$strPrivDescAlterRoutine = 'Tillter ndring och borttagning av lagrade rutiner.';
 $strPrivDescCreateDb = 'Tillter skapande av nya databaser och tabeller.';
+$strPrivDescCreateRoutine = 'Tillter skapande av lagrade rutiner.';
 $strPrivDescCreateTbl = 'Tillter skapande av nya tabeller.';
 $strPrivDescCreateTmpTable = 'Tillter skapande av temporra tabeller.';
+$strPrivDescCreateUser = 'Tillter skapande, borttagning och omdpning av anvndarkonton.';
+$strPrivDescCreateView = 'Tillter skapande av nya vyer.';
 $strPrivDescDelete = 'Tillter borttagning av data.';
 $strPrivDescDropDb = 'Tillter borttagning av databaser och tabeller.';
 $strPrivDescDropTbl = 'Tillter borttagning av tabeller.';
 $strPrivDescExecute = 'Tillter krning av lagrade procedurer; Har ingen verkan i denna MySQL-version.';
+$strPrivDescExecute5 = 'Tillter utfrande av lagrade rutiner.';
 $strPrivDescFile = 'Tillter import av data frn och export av data till filer.';
 $strPrivDescGrant = 'Tillter tillgg av anvndare och privilegier utan omladdning av privilegiumtabellerna.';
 $strPrivDescIndex = 'Tillter skapande och borttagning av index.';
@@ -491,12 +553,13 @@ $strPrivDescProcess3 = 'Tillter ddande av andra anvndares processer.';
 $strPrivDescProcess4 = 'Tillter visning av fullstndiga frgor i processlistan.';
 $strPrivDescReferences = 'Har ingen verkan i denna MySQL-version.';
 $strPrivDescReload = 'Tillter omladdning av serverinstllningar och rensning av serverns cache.';
-$strPrivDescReplClient = 'Ger anvndaren rtt att frga var slavarna / huvudservrarna r.';
+$strPrivDescReplClient = 'Ger anvndaren rtt att frga var slav- / huvudservrarna r.';
 $strPrivDescReplSlave = 'Ndvndig fr replikationsslavar.';
 $strPrivDescSelect = 'Tillter lsning av data.';
 $strPrivDescShowDb = 'Ger tillgng till den fullstndiga databaslistan.';
+$strPrivDescShowView = 'Tillter utfrande av SHOW CREATE VIEW-frgor.';
 $strPrivDescShutdown = 'Tillter avstngning av servern.';
-$strPrivDescSuper = 'Tillter uppkoppling, ven om maximala antalet frbindelser r ndd; Ndvndig fr de flesta administrativa funktioner, som att stta globala variabler eller dda andra anvndares trdar.';
+$strPrivDescSuper = 'Tillter uppkoppling, ven om maximala antalet frbindelser r ndd. Ndvndig fr de flesta administrativa funktioner, som att stta globala variabler eller dda andra anvndares trdar.';
 $strPrivDescUpdate = 'Tillter ndring av data.';
 $strPrivDescUsage = 'Inga privilegier.';
 $strPrivileges = 'Privilegier';
@@ -516,6 +579,7 @@ $strQueryType = 'Typ av frga';
 $strQueryWindowLock = 'Skriv inte ver denna frga utifrn detta fnster';
 
 $strReType = 'Skriv igen';
+$strReadRequests = 'Lsbegranden';
 $strReceived = 'Mottagna';
 $strRecords = 'Rader';
 $strReferentialIntegrity = 'Kontrollera referensintegritet:';
@@ -543,6 +607,7 @@ $strRevokeAndDelete = 'Upphv anvndarnas alla aktiva privilegier och ta bort anvn
 $strRevokeAndDeleteDescr = 'Anvndarna kommer fortfarande ha kvar privilegiet USAGE tills privilegierna laddas om.';
 $strRevokeMessage = 'Du har upphvt privilegierna fr %s';
 $strRomanian = 'Rumnska';
+$strRoutines = 'Rutiner';
 $strRowLength = 'Radlngd';
 $strRowSize = 'Radstorlek';
 $strRows = 'Rader';
@@ -558,6 +623,7 @@ $strRunning = 'krs p %s';
 $strRussian = 'Rysk';
 
 $strSQL = 'SQL';
+$strSQLExportCompatibility = 'SQL-export-kompatibilitet';
 $strSQLExportType = 'Export-typ';
 $strSQLOptions = 'SQL-alternativ';
 $strSQLParserBugMessage = 'Det r mjligt att du har hittat en bugg i SQL-analysatorn. Var god granska din frga noga och kontrollera att citationstecknen r korrekta och matchar varandra. En annan mjlig felorsak kan vara att du verfr en fil med binrkod som inte ligger inom citationstecken. Du kan ven testa din frga i MySQL:s kommandoradsgrnssnitt. Felmeddelandet frn MySQL-servern nedan, om det finns ngot, kan ocks hjlpa dig att analysera problemet. Om du fortfarande har problem eller om SQL-analysatorn misslyckas nr kommandoradsgrnssnittet lyckas, var vnlig reducera din inmatning av SQL-frgor till den enda frga som orsakar problem och skicka en buggrapport med datastycket i URKLIPP-sektionen nedan:';
@@ -596,7 +662,7 @@ $strServerStatus = 'Krningsinformation';
 $strServerStatusUptime = 'Denna MySQL-server har krts i %s. Den startade den %s.';
 $strServerTabProcesslist = 'Processer';
 $strServerTabVariables = 'Variabler';
-$strServerTrafficNotes = '<b>Servertrafik</b>: Dessa variabler visar statistik fr ntverkstrafiken hos denna MySQL-server sedan den startade.';
+$strServerTrafficNotes = '<b>Servertrafik</b>: Dessa tabeller visar statistik fr ntverkstrafiken hos denna MySQL-server sedan den startade.';
 $strServerVars = 'Servervariabler och instllningar';
 $strServerVersion = 'Serverversion';
 $strSessionValue = 'Sessionsvrde';
@@ -617,6 +683,7 @@ $strSingly = '(ensam)';
 $strSize = 'Storlek';
 $strSlovak = 'Slovakiska';
 $strSlovenian = 'Slovenska';
+$strSocketProblem = '(eller den lokala MySQL-serverns socket r inte korrekt konfigurerad)';
 $strSort = 'Sortering';
 $strSortByKey = 'Sortera efter nyckel';
 $strSpaceUsage = 'Utrymmesanvndning';
@@ -627,10 +694,12 @@ $strStatCreateTime = 'Skapades';
 $strStatUpdateTime = 'Senaste uppdatering';
 $strStatement = 'Uppgift';
 $strStatus = 'Status';
-$strStrucCSV = 'CSV-data';
+$strStorageEngine = 'Lagringsmotor';
+$strStorageEngines = 'Lagringsmotorer';
+$strStrucCSV = 'CSV';
 $strStrucData = 'Struktur och data';
-$strStrucDrop = 'Lgg till \'radera tabell\'';
-$strStrucExcelCSV = 'CSV fr MS Excel-data';
+$strStrucDrop = 'Lgg till DROP TABLE';
+$strStrucExcelCSV = 'CSV fr MS Excel';
 $strStrucNativeExcel = 'Naturlig MS Excel-data';
 $strStrucOnly = 'Enbart struktur';
 $strStructPropose = 'Fresl tabellstruktur';
@@ -639,7 +708,7 @@ $strSubmit = 'Snd';
 $strSuccess = 'Din SQL-frga utfrdes korrekt';
 $strSum = 'Summa';
 $strSwedish = 'Svensk';
-$strSwitchToDatabase = 'Vxla till kopierad databas';
+$strSwitchToDatabase = 'Byt till kopierad databas';
 $strSwitchToTable = 'Byt till kopierad tabell';
 
 $strTable = 'Tabell';
@@ -647,7 +716,7 @@ $strTableComments = 'Tabellkommentarer';
 $strTableEmpty = 'Tabellnamnet r tomt!';
 $strTableHasBeenDropped = 'Tabellen %s har tagits bort';
 $strTableHasBeenEmptied = 'Tabellen %s har tmts';
-$strTableHasBeenFlushed = 'Tabellen %s har rengjorts';
+$strTableHasBeenFlushed = 'Tabellen %s har rensats';
 $strTableMaintenance = 'Tabellunderhll';
 $strTableOfContents = 'Innehllsfrteckning';
 $strTableOptions = 'Tabellalternativ';
@@ -672,17 +741,17 @@ $strTotalUC = 'Totalt';
 $strTraditionalChinese = 'Traditionell kinesiska';
 $strTraditionalSpanish = 'Traditionell Spanska';
 $strTraffic = 'Trafik';
-$strTransformation_application_octetstream__download = 'Visar en lnk fr att ladda ner fltets binra data. Frsta parametern r filnamnet p den binra filen. Andra parametern r alternativt fltnamnet fr en tabellkolumn som innehller filnamn. Om du anger andra parametern s mste frsta parametern sttas till en tom strng.';
-$strTransformation_image_jpeg__inline = 'Visar en klickbar tumnagelbild; parametrar: bredd,hjd i pixlar (behller originalproportionerna)';
-$strTransformation_image_jpeg__link = 'Visar en lnk till denna bild (dvs direkt blob-nedladdning).';
+$strTransformation_application_octetstream__download = 'Visar en lnk fr att ladda ner fltets binra data. Du kan anvnda frsta parametern fr att ange filnamnet eller anvnda den andra parametern fr att ange fltnamnet fr en tabellkolumn som innehller filnamn. Om du anger andra parametern s mste frsta parametern sttas till en tom strng.';
+$strTransformation_application_octetstream__hex = 'Visar hexadecimal representation av data.';
+$strTransformation_image_jpeg__inline = 'Visar en klickbar tumnagelbild. Parametrarna r maximal bredd och hjd i pixlar. Bildens ursprungliga proportioner bibehlls.';
+$strTransformation_image_jpeg__link = 'Visar en lnk fr att ladda ner denna bild.';
 $strTransformation_image_png__inline = 'Se image/jpeg: inline';
-$strTransformation_text_plain__dateformat = 'Tar ett TIME, TIMESTAMP eller DATETIME-flt och formaterar det enligt ditt lokala datumformat. Frsta parametern r frskjutningen (i timmar) som kommer att lggas till tidsstmpeln (standardvrde: 0). Andra parametern r ett annorlunda datumformat enligt tillgngliga parametrar fr PHP:s strftime().';
-$strTransformation_text_plain__external = 'ENDAST LINUX: Startar en extern applikation och skickar fltdata till den via standard-indata. Returnerar applikationens standard-utdata. Standard r Tidy, fr att snygga till HTML-kod. Av skerhetsskl mste du manuellt redigera filen libraries/transformations/text_plain__external.inc.php och infoga verktygen du tillter ska f kras. Den frsta parametern r d numret fr det program som du vill anvnda och den andra parametern r parametrarna fr programmet. Om den tredje parametern stts till 1 kommer utdata konverteras mha htmlspecialchars() (standardvrde: 1). Om den fjrde parametern stts till 1 kommer en NOWRAP lggas till innehllscellen s att hela utdata kommer att visas utan omformatering (standardvrde: 1).';
-$strTransformation_text_plain__formatted = 'Bevarar fltets originalformatering. Utan baktstreck fre specialtecken.';
-$strTransformation_text_plain__imagelink = 'Visar en bild och en lnk, fltet innehller filnamnet; frsta parametern r ett prefix ssom "http://domain.com/", andra parametern r bredden i pixlar, tredje r hjden.';
-$strTransformation_text_plain__link = 'Visar en lnk, fltet innehller filnamnet; frsta parametern r ett prefix ssom "http://domain.com/", andra parametern r en titel fr lnken.';
-$strTransformation_text_plain__substr = 'Visar endast del av en strng. Frsta parametern specificerar var i texten utdata startar (standardvrde: 0). Andra parametern specificerar hur mycket text som returneras. Om det utelmnas, returneras all resterande text. Den tredje parametern definierar vilka tecken som kommer att lggas till i slutet p den returnerade delstrngen  (standardvrde: ...).';
-$strTransformation_text_plain__unformatted = 'Visar HTML-kod som HTML-specialtecken. HTML-formatering visas inte.';
+$strTransformation_text_plain__dateformat = 'Visar ett TIME, TIMESTAMP eller DATETIME-flt enligt ditt lokala datum-/tidsformat. Frsta parametern r frskjutningen (i timmar) som kommer att lggas till tidsstmpeln (standardvrde: 0). Anvnd andra parametern fr att ange ett annat datum-/tidsformat; se dokumentationen fr PHP:s funktion strftime().';
+$strTransformation_text_plain__external = 'ENDAST LINUX: Startar en extern applikation och skickar fltdata till den via standard-indata. Returnerar applikationens standard-utdata. Standard r Tidy, fr att snygga till HTML-kod. Av skerhetsskl mste du manuellt redigera filen libraries/transformations/text_plain__external.inc.php och infoga verktygen du vill tillta ska f kras. Den frsta parametern r d numret fr det program som du vill anvnda och den andra parametern r parametrarna fr programmet. Om den tredje parametern stts till 1 kommer utdata konverteras mha htmlspecialchars() (standardvrde: 1). Om den fjrde parametern stts till 1 kommer radbrytning att undvikas s att all utdata kommer att visas p en rad (standardvrde: 1).';
+$strTransformation_text_plain__formatted = 'Visar innehllet i fltet som det r, utan att kra det genom htmlspecialchars(). Det innebr att fltet antas innehlla korrekt HTML-kod.';
+$strTransformation_text_plain__imagelink = 'Visar en bild och en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra och tredje parametern r bredden och hjden i pixlar.';
+$strTransformation_text_plain__link = 'Visar en lnk; fltet innehller filnamnet. Frsta parametern r ett URL-prefix ssom "http://www.example.com/". Andra parametern r en titel fr lnken.';
+$strTransformation_text_plain__substr = 'Visar del av en strng. Frsta parametern r antalet tecken att hoppa ver frn brjan p strngen (standardvrde: 0). Andra parametern r antalet tecken som ska returneras (standardvrde: till slutet p strngen). Den tredje parametern r en strng som lggs till i slutet och/eller brjan nr trunkering utfrs (standardvrde: "...").';
 $strTruncateQueries = 'Korta av visade frgor';
 $strTurkish = 'Turkisk';
 $strType = 'Typ';
@@ -693,7 +762,7 @@ $strUnicode = 'Unicode';
 $strUnique = 'Unik';
 $strUnknown = 'oknd';
 $strUnselectAll = 'Avmarkera alla';
-$strUpdComTab = 'Se dokumentationen fr uppdatering av din tabell Column_comments';
+$strUpdComTab = 'Se dokumentationen fr uppdatering av din tabell column_comments';
 $strUpdatePrivMessage = 'Du har uppdaterat privilegierna fr %s.';
 $strUpdateProfileMessage = 'Profilen har uppdaterats.';
 $strUpdateQuery = 'Uppdatera frga';
@@ -715,12 +784,15 @@ $strUsersDeleted = 'De markerade anvndarna har tagits bort.';
 $strUsersHavingAccessToDb = 'Anvndare som har tillgng till &quot;%s&quot;';
 
 $strValidateSQL = 'Validera SQL-kod';
-$strValidatorError = 'SQL-validatorn kunde inte initieras. Kontrollera att du har installerat de ndvndiga PHP-utkningarna enligt %sdokumentationen%s.';
+$strValidatorError = 'SQL-validatorn kunde inte initieras. Kontrollera om du har installerat de ndvndiga PHP-tillggen enligt %sdokumentationen%s.';
 $strValue = 'Vrde';
 $strVar = 'Variabel';
+$strVersionInformation = 'Versionsinformation';
+$strView = 'Vy';
 $strViewDump = 'Visa SQL-satser fr tabellen';
 $strViewDumpDB = 'Visa SQL-satser fr databasen';
 $strViewDumpDatabases = 'Visa SQL-satser fr databaser';
+$strViewHasBeenDropped = 'Vyn %s har tagits bort';
 
 $strWebServerUploadDirectory = 'Uppladdningskatalog p webbserver';
 $strWebServerUploadDirectoryError = 'Katalogen som du konfigurerat fr uppladdning kan inte ns';
@@ -729,6 +801,7 @@ $strWestEuropean = 'Vsteuropeisk';
 $strWildcard = 'jokertecken';
 $strWindowNotFound = 'Mlfnstret kunde inte uppdateras. Orsaken kan vara att du stngt frldrafnstret eller att din webblsares skerhetsinstllningar blockerar uppdateringar mellan fnster.';
 $strWithChecked = 'Med markerade:';
+$strWriteRequests = 'Skrivbegranden';
 $strWritingCommentNotPossible = 'Skrivning av kommentar inte mjlig';
 $strWritingRelationNotPossible = 'Skrivning av relation inte mjlig';
 $strWrongUser = 'Fel anvndarnamn/lsenord. tkomst nekad.';
@@ -740,12 +813,4 @@ $strYes = 'Ja';
 $strZeroRemovesTheLimit = 'Anm: Genom att stta dessa alternativ till 0 (noll) tas begrnsningarna bort.';
 $strZip = '"zippad"';
 
-// To translate:
-$strAfterInsertNext = 'Edit next row';  //to translate
-
-$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
-$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
-
-$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
-
 ?>
