@@ -1,5 +1,5 @@
 <?php
-/* $Id: sqlparser.lib.php,v 2.27 2004/11/05 00:41:55 lem9 Exp $ */
+/* $Id: sqlparser.lib.php,v 2.34.2.1 2005/06/30 16:58:11 lem9 Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 /** SQL Parser Functions for phpMyAdmin
@@ -149,7 +149,7 @@ if ($is_minimum_common == FALSE) {
     {
         global $SQP_errorString;
         $debugstr = 'ERROR: ' . $message . "\n";
-        $debugstr .= 'CVS: $Id: sqlparser.lib.php,v 2.27 2004/11/05 00:41:55 lem9 Exp $' . "\n";
+        $debugstr .= 'CVS: $Id: sqlparser.lib.php,v 2.34.2.1 2005/06/30 16:58:11 lem9 Exp $' . "\n";
         $debugstr .= 'MySQL: '.PMA_MYSQL_STR_VERSION . "\n";
         $debugstr .= 'USR OS, AGENT, VER: ' . PMA_USR_OS . ' ' . PMA_USR_BROWSER_AGENT . ' ' . PMA_USR_BROWSER_VER . "\n";
         $debugstr .= 'PMA: ' . PMA_VERSION . "\n";
@@ -206,6 +206,7 @@ if ($is_minimum_common == FALSE) {
         global $PMA_SQPdata_column_attrib, $PMA_SQPdata_reserved_word, $PMA_SQPdata_column_type, $PMA_SQPdata_function_name,
                $PMA_SQPdata_column_attrib_cnt, $PMA_SQPdata_reserved_word_cnt, $PMA_SQPdata_column_type_cnt, $PMA_SQPdata_function_name_cnt;
         global $mysql_charsets, $mysql_collations_flat, $mysql_charsets_count, $mysql_collations_count;
+        global $PMA_SQPdata_forbidden_word, $PMA_SQPdata_forbidden_word_cnt; 
 
         // rabus: Convert all line feeds to Unix style
         $sql = str_replace("\r\n", "\n", $sql);
@@ -638,6 +639,12 @@ if ($is_minimum_common == FALSE) {
             } else {
               // Do nothing
             }
+            // check if present in the list of forbidden words
+            if ($t_suffix == '_reservedWord' && PMA_STR_binarySearchInArr($d_cur_upper, $PMA_SQPdata_forbidden_word, $PMA_SQPdata_forbidden_word_cnt)) {
+                $sql_array[$i]['forbidden'] = TRUE;
+            } else {
+                $sql_array[$i]['forbidden'] = FALSE;
+            }
             $sql_array[$i]['type'] .= $t_suffix;
           }
         } // end for
@@ -702,7 +709,8 @@ if ($is_minimum_common == FALSE) {
             'queryflags'     => array(),
             'select_expr'    => array(),
             'table_ref'      => array(),
-            'foreign_keys'   => array()
+            'foreign_keys'   => array(),
+            'create_table_fields' => array()
         );
         $subresult_empty = $subresult;
         $seek_queryend         = FALSE;
@@ -716,10 +724,10 @@ if ($is_minimum_common == FALSE) {
         // for GROUP_CONCAT( ... )
         $in_group_concat     = FALSE;
 
-/* Description of analyzer results
+/* Description of analyzer results by lem9
  *
- * lem9: db, table, column, alias
- *      ------------------------
+ * db, table, column, alias
+ * ------------------------
  *
  * Inside the $subresult array, we create ['select_expr'] and ['table_ref'] arrays.
  *
@@ -742,8 +750,8 @@ if ($is_minimum_common == FALSE) {
  * There is a debug section at the end of loop #1, if you want to
  * see the exact contents of select_expr and table_ref
  *
- * lem9: queryflags
- *       ----------
+ * queryflags
+ * ----------
  *
  * In $subresult, array 'queryflags' is filled, according to what we
  * find in the query.
@@ -757,8 +765,8 @@ if ($is_minimum_common == FALSE) {
  * ['queryflags']['join'] = 1;         for a JOIN
  * ['queryflags']['offset'] = 1;       for the presence of OFFSET 
  *
- * lem9:  query clauses
- *        -------------
+ * query clauses
+ * -------------
  *
  * The select is splitted in those clauses:
  * ['select_expr_clause']
@@ -774,20 +782,43 @@ if ($is_minimum_common == FALSE) {
  * For a SELECT, the whole query without the ORDER BY clause is put into
  * ['unsorted_query']
  *
- * lem9:   foreign keys
- *         ------------
+ * foreign keys
+ * ------------
  * The CREATE TABLE may contain FOREIGN KEY clauses, so they get
  * analyzed and ['foreign_keys'] is an array filled with
  * the constraint name, the index list,
  * the REFERENCES table name and REFERENCES index list,
  * and ON UPDATE | ON DELETE clauses
  *
- * lem9: position_of_first_select
- *       ------------------------
+ * position_of_first_select
+ * ------------------------
  *
  * The array index of the first SELECT we find. Will be used to
  * insert a SQL_CALC_FOUND_ROWS.
  *
+ * create_table_fields
+ * -------------------
+ *
+ * For now, mostly used to detect the DEFAULT CURRENT_TIMESTAMP and
+ * ON UPDATE CURRENT_TIMESTAMP clauses of the CREATE TABLE query.
+ * An array, each element is the identifier name.
+ * Note that for now, the timestamp_not_null element is created
+ * even for non-TIMESTAMP fields.
+ *
+ * Sub-elements: ['type'] which contains the column type
+ *               optional (currently they are never false but can be absent):
+ *               ['default_current_timestamp'] boolean
+ *               ['on_update_current_timestamp'] boolean
+ *               ['timestamp_not_null'] boolean
+ *
+ * section_before_limit, section_after_limit
+ * -----------------------------------------
+ * 
+ * Marks the point of the query where we can insert a LIMIT clause;
+ * so the section_before_limit will contain the left part before
+ * a possible LIMIT clause
+ *
+ *
  * End of description of analyzer results
  */
 
@@ -911,7 +942,9 @@ if ($is_minimum_common == FALSE) {
             }
 
 // ==============================================================
-            if ($arr[$i]['type'] == 'alpha_reservedWord') {
+            if ($arr[$i]['type'] == 'alpha_reservedWord'
+//             && $arr[$i]['forbidden'] == FALSE) {
+  ){
                 // We don't know what type of query yet, so run this
                 if ($subresult['querytype'] == '') {
                     $subresult['querytype'] = strtoupper($arr[$i]['data']);
@@ -947,13 +980,24 @@ if ($is_minimum_common == FALSE) {
             } // end if (type == alpha_reservedWord)
 
 // ==============================
-            if (($arr[$i]['type'] == 'quote_backtick')
-             || ($arr[$i]['type'] == 'quote_double')
-             || ($arr[$i]['type'] == 'quote_single')
-             || ($arr[$i]['type'] == 'alpha_identifier')) {
+            if ($arr[$i]['type'] == 'quote_backtick'
+             || $arr[$i]['type'] == 'quote_double'
+             || $arr[$i]['type'] == 'quote_single'
+             || $arr[$i]['type'] == 'alpha_identifier'
+             || ($arr[$i]['type'] == 'alpha_reservedWord'
+                && $arr[$i]['forbidden'] == FALSE)) {
 
                 switch ($arr[$i]['type']) {
                     case 'alpha_identifier':
+                    case 'alpha_reservedWord':
+                        // this is not a real reservedWord, because
+                        // it's not present in the list of forbidden words,
+                        // for example "storage" which can be used as 
+                        // an identifier
+                        //
+                        // TODO: avoid the pretty printing in color
+                        //       in this case
+
                         $identifier = $arr[$i]['data'];
                         break;
 
@@ -1231,8 +1275,9 @@ if ($is_minimum_common == FALSE) {
         // -------------------------------------------------------
 
 
-        // loop #2: for queryflags
-        //          ,querytype (for queries != 'SELECT')
+        // loop #2: - queryflags
+        //          - querytype (for queries != 'SELECT')
+        //          - section_before_limit, section_after_limit
         //
         // we will also need this queryflag in loop 2
         // so set it here
@@ -1240,6 +1285,9 @@ if ($is_minimum_common == FALSE) {
             $subresult['queryflags']['select_from'] = 1;
         }
 
+        $collect_section_before_limit = TRUE;
+        $section_before_limit = '';
+        $section_after_limit = '';
         $seen_reserved_word = FALSE;
         $seen_group = FALSE;
         $seen_order = FALSE;
@@ -1269,6 +1317,12 @@ if ($is_minimum_common == FALSE) {
 
            // TODO: check for punct_queryend
 
+
+           // TODO: verify C-style comments?
+           if ($arr[$i]['type'] == 'comment_ansi') {
+               $collect_section_before_limit = FALSE;
+           }
+
            if ($arr[$i]['type'] == 'alpha_reservedWord') {
                $upper_data = strtoupper($arr[$i]['data']);
                if (!$seen_reserved_word) {
@@ -1294,6 +1348,13 @@ if ($is_minimum_common == FALSE) {
                    }
                }
 
+               if ($upper_data == 'PROCEDURE') {
+                   $collect_section_before_limit = FALSE;
+               }
+               // TODO: set also to FALSE if we find
+               //      FOR UPDATE
+               //      LOCK IN SHARE MODE
+
                if ($upper_data == 'SELECT') {
                    $in_select_expr = TRUE;
                    $select_expr_clause = '';
@@ -1448,51 +1509,102 @@ if ($is_minimum_common == FALSE) {
                }
            }
 
-           // FIXME: is it correct to always add $sep ?
            if (isset($subresult['queryflags']['select_from'])
              && $subresult['queryflags']['select_from'] == 1
              && !$seen_order) {
-               $unsorted_query .= $arr[$i]['data'] . $sep;
+               $unsorted_query .= $arr[$i]['data'];
+
+               if ($arr[$i]['type'] != 'punct_bracket_open_round'
+               && $arr[$i]['type'] != 'punct_bracket_close_round'
+               && $arr[$i]['type'] != 'punct') {
+                   $unsorted_query .= $sep;
+               }
            }
 
            // clear $upper_data for next iteration
            $upper_data='';
 
+           if ($collect_section_before_limit) {
+               $section_before_limit .= $arr[$i]['data'] . $sep;
+           } else {
+               $section_after_limit .= $arr[$i]['data'] . $sep;
+           }
+
+
         } // end for $i (loop #2)
 
+
         // -----------------------------------------------------
-        // loop #3: foreign keys
+        // loop #3: foreign keys and MySQL 4.1.2+ TIMESTAMP options
         // (for now, check only the first query)
-        // (for now, identifiers must be backquoted)
+        // (for now, identifiers are assumed to be backquoted)
+
+        // If we find that we are dealing with a CREATE TABLE query,
+        // we look for the next punct_bracket_open_round, which 
+        // introduces the fields list. Then, when we find a
+        // quote_backtick, it must be a field, so we put it into
+        // the create_table_fields array. Even if this field is
+        // not a timestamp, it will be useful when logic has been
+        // added for complete field attributes analysis.
 
         $seen_foreign = FALSE;
         $seen_references = FALSE;
         $seen_constraint = FALSE;
-        $in_bracket = FALSE;
         $foreign_key_number = -1;
+        $seen_create_table = FALSE;
+        $seen_create = FALSE;
+        $in_create_table_fields = FALSE;
+        $brackets_level = 0;
+        $in_timestamp_options = FALSE;
+        $seen_default = FALSE;
 
         for ($i = 0; $i < $size; $i++) {
         // DEBUG echo "<b>" . $arr[$i]['data'] . "</b> " . $arr[$i]['type'] . "<br />";
+
             if ($arr[$i]['type'] == 'alpha_reservedWord') {
-               $upper_data = strtoupper($arr[$i]['data']);
+                $upper_data = strtoupper($arr[$i]['data']);
 
-               if ($upper_data == 'CONSTRAINT') {
-                   $foreign_key_number++;
-                   $seen_foreign = FALSE;
-                   $seen_references = FALSE;
-                   $seen_constraint = TRUE;
-               }
-               if ($upper_data == 'FOREIGN') {
-                   $seen_foreign = TRUE;
-                   $seen_references = FALSE;
-                   $seen_constraint = FALSE;
-               }
-               if ($upper_data == 'REFERENCES') {
-                   $seen_foreign = FALSE;
-                   $seen_references = TRUE;
-                   $seen_constraint = FALSE;
-               }
+                if ($upper_data == 'NOT' && $in_timestamp_options) {
+                    $create_table_fields[$current_identifier]['timestamp_not_null'] = TRUE; 
 
+                }
+
+                if ($upper_data == 'CREATE') {
+                    $seen_create = TRUE;
+                }
+
+                if ($upper_data == 'TABLE' && $seen_create) {
+                    $seen_create_table = TRUE;
+                    $create_table_fields = array();
+                }
+
+                if ($upper_data == 'CURRENT_TIMESTAMP') {
+                    if ($in_timestamp_options) {
+                        if ($seen_default) {
+                            $create_table_fields[$current_identifier]['default_current_timestamp'] = TRUE;
+                        }
+                    }
+                }
+
+                if ($upper_data == 'CONSTRAINT') {
+                    $foreign_key_number++;
+                    $seen_foreign = FALSE;
+                    $seen_references = FALSE;
+                    $seen_constraint = TRUE;
+                }
+                if ($upper_data == 'FOREIGN') {
+                    $seen_foreign = TRUE;
+                    $seen_references = FALSE;
+                    $seen_constraint = FALSE;
+                }
+                if ($upper_data == 'REFERENCES') {
+                    $seen_foreign = FALSE;
+                    $seen_references = TRUE;
+                    $seen_constraint = FALSE;
+                }
+
+
+              // Cases covered:
 
               // [ON DELETE {CASCADE | SET NULL | NO ACTION | RESTRICT}]
               // [ON UPDATE {CASCADE | SET NULL | NO ACTION | RESTRICT}]
@@ -1500,6 +1612,8 @@ if ($is_minimum_common == FALSE) {
               // but we set ['on_delete'] or ['on_cascade'] to
               // CASCADE | SET_NULL | NO_ACTION | RESTRICT
 
+              // ON UPDATE CURRENT_TIMESTAMP
+
                if ($upper_data == 'ON') {
                    unset($clause);
                    if ($arr[$i+1]['type'] == 'alpha_reservedWord') {
@@ -1529,9 +1643,14 @@ if ($is_minimum_common == FALSE) {
                               if ($arr[$i+3]['type'] == 'alpha_reservedWord') {
                                   $value = $third_upper_data . '_' . strtoupper($arr[$i+3]['data']);
                               }
+                          } elseif ($third_upper_data == 'CURRENT_TIMESTAMP') {
+                              if ($clause == 'on_update' 
+                                  && $in_timestamp_options) {
+                                  $create_table_fields[$current_identifier]['on_update_current_timestamp'] = TRUE;
+                                  $seen_default = FALSE;
+                              }
+                              
                           } else {
-                          // for example: ON UPDATE CURRENT_TIMESTAMP
-                          // which is not for a foreign key
                               $value = '';
                           }
                           if (!empty($value)) {
@@ -1541,41 +1660,84 @@ if ($is_minimum_common == FALSE) {
                    }
                }
 
-            }
+            } // end of reserved words analysis
+            
 
             if ($arr[$i]['type'] == 'punct_bracket_open_round') {
-                $in_bracket = TRUE;
+                $brackets_level++;
+                if ($seen_create_table && $brackets_level == 1) {
+                    $in_create_table_fields = TRUE;
+                }
             }
 
+            
             if ($arr[$i]['type'] == 'punct_bracket_close_round') {
-                $in_bracket = FALSE;
+                $brackets_level--;
                 if ($seen_references) {
                     $seen_references = FALSE;
                 }
+                if ($seen_create_table && $brackets_level == 0) {
+                    $in_create_table_fields = FALSE;
+                }
             }
 
-            if (($arr[$i]['type'] == 'quote_backtick')) {
+            if (($arr[$i]['type'] == 'alpha_columnAttrib')) {
+                $upper_data = strtoupper($arr[$i]['data']);
+                if ($seen_create_table && $in_create_table_fields) {
+                    if ($upper_data == 'DEFAULT') {
+                        $seen_default = TRUE;
+                    }
+                }
+            }
+
+            if (($arr[$i]['type'] == 'alpha_columnType')) {
+                $upper_data = strtoupper($arr[$i]['data']);
+                if ($seen_create_table && $in_create_table_fields && isset($current_identifier)) {
+                    $create_table_fields[$current_identifier]['type'] = $upper_data;
+                    if ($upper_data == 'TIMESTAMP') {
+                        $in_timestamp_options = TRUE;
+                    } else {
+                        $in_timestamp_options = FALSE;
+                    }
+                }
+            }
+
+            
+            if ($arr[$i]['type'] == 'quote_backtick' || $arr[$i]['type'] == 'alpha_identifier') {
+
+                if ($arr[$i]['type'] == 'quote_backtick') {
+                    // remove backquotes
+                    $identifier = str_replace('`','',$arr[$i]['data']);
+                } else {
+                    $identifier = $arr[$i]['data'];
+                }
+
+                if ($seen_create_table && $in_create_table_fields) {
+                    $current_identifier = $identifier;
+                    // warning: we set this one even for non TIMESTAMP type
+                    $create_table_fields[$current_identifier]['timestamp_not_null'] = FALSE; 
+                }
 
                 if ($seen_constraint) {
-                    // remove backquotes
-                    $identifier = str_replace('`','',$arr[$i]['data']);
                     $foreign[$foreign_key_number]['constraint'] = $identifier;
                 }
-                if ($seen_foreign && $in_bracket) {
-                    // remove backquotes
-                    $identifier = str_replace('`','',$arr[$i]['data']);
+
+                if ($seen_foreign && $brackets_level > 0) {
                     $foreign[$foreign_key_number]['index_list'][] = $identifier;
                 }
 
                 if ($seen_references) {
-                    $identifier = str_replace('`','',$arr[$i]['data']);
-                    if ($in_bracket) {
+                    // here, the first bracket level corresponds to the
+                    // bracket of CREATE TABLE
+                    // so if we are on level 2, it must be the index list
+                    // of the foreign key REFERENCES
+                    if ($brackets_level > 1) {
                         $foreign[$foreign_key_number]['ref_index_list'][] = $identifier;
                     } else {
                         // for MySQL 4.0.18, identifier is
                         // `table` or `db`.`table`
-                        // first pass will pick the db name
-                        // next pass will execute the else and pick the
+                        // the first pass will pick the db name
+                        // the next pass will execute the else and pick the
                         // db name in $db_table[0]
                         if ($arr[$i+1]['type'] == 'punct_qualifier') {
                                 $foreign[$foreign_key_number]['ref_db_name'] = $identifier;
@@ -1595,10 +1757,16 @@ if ($is_minimum_common == FALSE) {
             }
         } // end for $i (loop #3)
 
+
+        // Fill the $subresult array
+
+        if (isset($create_table_fields)) {
+            $subresult['create_table_fields'] = $create_table_fields;
+        }
+
         if (isset($foreign)) {
             $subresult['foreign_keys'] = $foreign;
         }
-        //DEBUG print_r($foreign);
 
         if (isset($select_expr_clause)) {
             $subresult['select_expr_clause'] = $select_expr_clause;
@@ -1627,6 +1795,8 @@ if ($is_minimum_common == FALSE) {
 
         if (isset($position_of_first_select)) {
             $subresult['position_of_first_select'] = $position_of_first_select;
+            $subresult['section_before_limit'] = $section_before_limit;
+            $subresult['section_after_limit'] = $section_after_limit;
         }
 
         // They are naughty and didn't have a trailing semi-colon,
@@ -1907,7 +2077,16 @@ if ($is_minimum_common == FALSE) {
                     }
                     break;
                 case 'alpha_reservedWord':
-                    $arr[$i]['data'] = strtoupper($arr[$i]['data']);
+                    // do not uppercase the reserved word if we are calling
+                    // this function in query_only mode, because we need
+                    // the original query (otherwise we get problems with
+                    // semi-reserved words like "storage" which is legal
+                    // as an identifier name)
+
+                    if ($mode != 'query_only') {
+                        $arr[$i]['data'] = strtoupper($arr[$i]['data']);
+                    }
+
                     if ((($typearr[1] != 'alpha_reservedWord')
                         || (($typearr[1] == 'alpha_reservedWord')
                             && PMA_STR_binarySearchInArr(strtoupper($arr[$i - 1]['data']), $keywords_no_newline, $keywords_no_newline_cnt)))
